pub enum HttpSignatureType {
HttpRequestHeaders,
HttpRequestQueryParams,
}Expand description
Type of SigV4 signature.
Variants
HttpRequestHeaders
A signature for a full http request should be computed, with header updates applied to the signing result.
HttpRequestQueryParams
A signature for a full http request should be computed, with query param updates applied to the signing result.
This is typically used for presigned URLs.