#[non_exhaustive]pub enum PayloadSigningOverride {
UnsignedPayload,
Precomputed(String),
StreamingUnsignedPayloadTrailer,
}Expand description
When present in the config bag, this type will signal that the default payload signing should be overridden.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsignedPayload
An unsigned payload
UnsignedPayload is used for streaming requests where the contents of the body cannot be known prior to signing
Precomputed(String)
A precomputed body checksum. The checksum should be a SHA256 checksum of the body,
lowercase hex encoded. Eg:
e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855
StreamingUnsignedPayloadTrailer
Set when a streaming body has checksum trailers.
Implementations
Sourceimpl PayloadSigningOverride
impl PayloadSigningOverride
Sourcepub fn unsigned_payload() -> Self
pub fn unsigned_payload() -> Self
Create a payload signing override that will prevent the payload from being signed.
Sourcepub fn to_signable_body(self) -> SignableBody<'static>
pub fn to_signable_body(self) -> SignableBody<'static>
Convert this type into the type used by the signer to determine how a request body should be signed.