#[non_exhaustive]pub enum RequestChecksumCalculation {
WhenSupported,
WhenRequired,
}Expand description
Determines when a checksum will be calculated for request payloads. Values are:
- RequestChecksumCalculation::WhenSupported - (default) When set, a checksum will be
calculated for all request payloads of operations modeled with the
httpChecksumtrait whererequestChecksumRequiredistrueand/or arequestAlgorithmMemberis modeled. - RequestChecksumCalculation::WhenRequired - When set, a checksum will only be calculated for
request payloads of operations modeled with the
httpChecksumtrait whererequestChecksumRequiredistrueor where a requestAlgorithmMember is modeled and supplied.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WhenSupported
Calculate request checksums when they are supported.
WhenRequired
Caulculate request checksums only when they are required.