pub struct FinalizerInterceptorContextRef<'a, I = Input, O = Output, E = Error> { /* private fields */ }Expand description
Interceptor context for finalization hooks.
This context is used by the read_after_attempt and read_after_execution hooks
that are all called upon both success and failure, and may have varying levels
of context available depending on where a failure occurred if the operation failed.
Implementations
Sourceimpl<I, O, E> FinalizerInterceptorContextRef<'_, I, O, E>
impl<I, O, E> FinalizerInterceptorContextRef<'_, I, O, E>
Sourcepub fn output_or_error(&self) -> Option<Result<&O, &OrchestratorError<E>>>
pub fn output_or_error(&self) -> Option<Result<&O, &OrchestratorError<E>>>
Returns the deserialized operation output or error.
Sourcepub fn inner(&self) -> &InterceptorContext<I, O, E>
pub fn inner(&self) -> &InterceptorContext<I, O, E>
Downgrade this wrapper struct, returning the underlying InterceptorContext.
There’s no good reason to use this unless you’re writing tests or you have to interact with an API that doesn’t support the context wrapper structs.