#[non_exhaustive]pub struct RetryPartition { /* private fields */ }Expand description
Represents the retry partition, e.g. an endpoint, a region
A retry partition created with RetryPartition::new uses built-in
token bucket and rate limiter settings, with no option for customization.
Default partitions with the same name share the same token bucket
and client rate limiter.
To customize these components, use a custom retry partition via RetryPartition::custom.
A custom partition owns its token bucket and rate limiter, which:
- Are independent from those in any default partition.
- Are not shared with other custom partitions, even if they have the same name.
To share a token bucket and rate limiter among custom partitions, either clone the custom partition itself or clone these components beforehand and pass them to each custom partition.
Implementations