pub struct BehaviorVersion { /* private fields */ }Expand description
Behavior version of the client
Over time, new best-practice behaviors are introduced. However, these behaviors might not be backwards compatible. For example, a change which introduces new default timeouts or a new retry-mode for all operations might be the ideal behavior but could break existing applications.
Implementations
Sourceimpl BehaviorVersion
impl BehaviorVersion
Sourcepub fn latest() -> BehaviorVersion
pub fn latest() -> BehaviorVersion
This method will always return the latest major version.
This is the recommend choice for customers who aren’t reliant on extremely specific behavior characteristics. For example, if you are writing a CLI app, the latest behavior major version is probably the best setting for you.
If, however, you’re writing a service that is very latency sensitive, or that has written code to tune Rust SDK behaviors, consider pinning to a specific major version.
The latest version is currently BehaviorVersion::v2025_08_07
Sourcepub fn v2025_08_07() -> BehaviorVersion
pub fn v2025_08_07() -> BehaviorVersion
Behavior version for August 7th, 2025.
This version updates the default HTTPS client to support proxy environment variables
(e.g. HTTP_PROXY, HTTPS_PROXY, NO_PROXY) by default.
Sourcepub fn v2025_01_17() -> BehaviorVersion
👎Deprecated since 1.9.0: Superseded by v2025_08_07, which enables automatic HTTP(S) proxy support from environment variables in the default HTTPS client.
pub fn v2025_01_17() -> BehaviorVersion
Behavior version for January 17th, 2025
This version updates the default HTTP client and TLS stack. SDKs shipped with a pre 1.x version of hyper and rustls originally. This behavior version updates the HTTP+TLS stack to maintained versions.
Sourcepub fn v2024_03_28() -> BehaviorVersion
👎Deprecated since 1.8.0: Superseded by v2025_01_17, which updates the default HTTPS client stack.
pub fn v2024_03_28() -> BehaviorVersion
Behavior version for March 28th, 2024.
This version enables stalled stream protection for uploads (request bodies) by default.
When a new behavior major version is released, this method will be deprecated.
Sourcepub fn v2023_11_09() -> BehaviorVersion
👎Deprecated since 1.4.0: Superseded by v2024_03_28, which enabled stalled stream protection for uploads (request bodies) by default.
pub fn v2023_11_09() -> BehaviorVersion
Behavior version for November 9th, 2023.
Sourcepub fn is_at_least(&self, other: BehaviorVersion) -> bool
pub fn is_at_least(&self, other: BehaviorVersion) -> bool
True if this version is newer or equal to the given other version.