pub struct Credentials(/* private fields */);Expand description
AWS SDK Credentials
An opaque struct representing credentials that may be used in an AWS SDK, modeled on the CRT credentials implementation.
When Credentials is dropped, its contents are zeroed in memory. Credentials uses an interior Arc to ensure
that even when cloned, credentials don’t exist in multiple memory locations.
Implementations
Sourceimpl Credentials
impl Credentials
Sourcepub fn builder() -> CredentialsBuilder
pub fn builder() -> CredentialsBuilder
Returns builder for Credentials.
Sourcepub fn new(
access_key_id: impl Into<String>,
secret_access_key: impl Into<String>,
session_token: Option<String>,
expires_after: Option<SystemTime>,
provider_name: &'static str,
) -> Credentials
pub fn new( access_key_id: impl Into<String>, secret_access_key: impl Into<String>, session_token: Option<String>, expires_after: Option<SystemTime>, provider_name: &'static str, ) -> Credentials
Creates Credentials.
This is intended to be used from a custom credentials provider implementation. It is NOT secure to hardcode credentials into your application.
Sourcepub fn access_key_id(&self) -> &str
pub fn access_key_id(&self) -> &str
Returns the access key ID.
Sourcepub fn secret_access_key(&self) -> &str
pub fn secret_access_key(&self) -> &str
Returns the secret access key.
Sourcepub fn expiry(&self) -> Option<SystemTime>
pub fn expiry(&self) -> Option<SystemTime>
Returns the time when the credentials will expire.
Sourcepub fn expiry_mut(&mut self) -> &mut Option<SystemTime>
pub fn expiry_mut(&mut self) -> &mut Option<SystemTime>
Returns a mutable reference to the time when the credentials will expire.
Sourcepub fn account_id(&self) -> Option<&AccountId>
pub fn account_id(&self) -> Option<&AccountId>
Returns the account ID.
Sourcepub fn session_token(&self) -> Option<&str>
pub fn session_token(&self) -> Option<&str>
Returns the session token.
Sourceimpl Credentials
impl Credentials
Sourcepub fn for_tests() -> Credentials
pub fn for_tests() -> Credentials
Creates a test Credentials with no session token.
Sourcepub fn for_tests_with_session_token() -> Credentials
pub fn for_tests_with_session_token() -> Credentials
Creates a test Credentials that include a session token.