pub struct Layer { /* private fields */ }Expand description
A named layer comprising a config bag
See the module docs for more documentation.
Implementations
Sourceimpl Layer
impl Layer
Sourcepub fn freeze(self) -> FrozenLayer
pub fn freeze(self) -> FrozenLayer
Converts this layer into a frozen layer that can no longer be mutated.
Sourcepub fn with_name(self, name: impl Into<Cow<'static, str>>) -> Layer
pub fn with_name(self, name: impl Into<Cow<'static, str>>) -> Layer
Changes the name of this layer.
Sourcepub fn load<T>(&self) -> <<T as Storable>::Storer as Store>::ReturnedType<'_>where
T: Storable,
pub fn load<T>(&self) -> <<T as Storable>::Storer as Store>::ReturnedType<'_>where
T: Storable,
Load a storable item from the bag
Sourcepub fn store_put<T>(&mut self, item: T) -> &mut Layerwhere
T: Storable<Storer = StoreReplace<T>>,
pub fn store_put<T>(&mut self, item: T) -> &mut Layerwhere
T: Storable<Storer = StoreReplace<T>>,
Stores item of type T into the config bag, overriding a previous value of the same type
Sourcepub fn store_or_unset<T>(&mut self, item: Option<T>) -> &mut Layerwhere
T: Storable<Storer = StoreReplace<T>>,
pub fn store_or_unset<T>(&mut self, item: Option<T>) -> &mut Layerwhere
T: Storable<Storer = StoreReplace<T>>,
Stores item of type T into the config bag, overriding a previous value of the same type,
or unsets it by passing a None
Sourcepub fn store_append<T>(&mut self, item: T) -> &mut Layerwhere
T: Storable<Storer = StoreAppend<T>>,
pub fn store_append<T>(&mut self, item: T) -> &mut Layerwhere
T: Storable<Storer = StoreAppend<T>>,
This can only be used for types that use StoreAppend
use aws_smithy_types::config_bag::{ConfigBag, Layer, Storable, StoreAppend, StoreReplace};
let mut layer_1 = Layer::new("example");
#[derive(Debug, PartialEq, Eq)]
struct Interceptor(&'static str);
impl Storable for Interceptor {
type Storer = StoreAppend<Interceptor>;
}
layer_1.store_append(Interceptor("321"));
layer_1.store_append(Interceptor("654"));
let mut layer_2 = Layer::new("second layer");
layer_2.store_append(Interceptor("987"));
let bag = ConfigBag::of_layers(vec![layer_1, layer_2]);
assert_eq!(
bag.load::<Interceptor>().collect::<Vec<_>>(),
vec![&Interceptor("987"), &Interceptor("654"), &Interceptor("321")]
);Sourcepub fn clear<T>(&mut self)where
T: Storable<Storer = StoreAppend<T>>,
pub fn clear<T>(&mut self)where
T: Storable<Storer = StoreAppend<T>>,
Clears the value of type T from the config bag
This internally marks the item of type T as cleared as opposed to wiping it out from the
config bag.