pub struct StalledStreamProtectionConfig { /* private fields */ }Expand description
Configuration for stalled stream protection.
When enabled, download streams that stall out will be cancelled.
Implementations
Sourceimpl StalledStreamProtectionConfig
impl StalledStreamProtectionConfig
Sourcepub fn enabled() -> Builder
pub fn enabled() -> Builder
Create a new config that enables stalled stream protection for both uploads and downloads.
Sourcepub fn disabled() -> StalledStreamProtectionConfig
pub fn disabled() -> StalledStreamProtectionConfig
Create a new config that disables stalled stream protection.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Return whether stalled stream protection is enabled for either uploads or downloads.
Sourcepub fn upload_enabled(&self) -> bool
pub fn upload_enabled(&self) -> bool
True if stalled stream protection is enabled for upload streams.
Sourcepub fn download_enabled(&self) -> bool
pub fn download_enabled(&self) -> bool
True if stalled stream protection is enabled for download streams.
Sourcepub fn grace_period(&self) -> Duration
pub fn grace_period(&self) -> Duration
Return the grace period for stalled stream protection.
When a stream stalls for longer than this grace period, the stream will return an error.