pub struct ErrorMetadata { /* private fields */ }Expand description
Generic Error type
For many services, Errors are modeled. However, many services only partially model errors or don’t
model errors at all. In these cases, the SDK will return this generic error type to expose the
code, message and request_id.
Implementations