#[non_exhaustive]pub struct CreateBucketOutputBuilder { /* private fields */ }Expand description
A builder for CreateBucketOutput.
Implementations
Sourceimpl CreateBucketOutputBuilder
impl CreateBucketOutputBuilder
Sourcepub fn location(self, input: impl Into<String>) -> Self
pub fn location(self, input: impl Into<String>) -> Self
A forward slash followed by the name of the bucket.
Sourcepub fn set_location(self, input: Option<String>) -> Self
pub fn set_location(self, input: Option<String>) -> Self
A forward slash followed by the name of the bucket.
Sourcepub fn get_location(&self) -> &Option<String>
pub fn get_location(&self) -> &Option<String>
A forward slash followed by the name of the bucket.
Sourcepub fn bucket_arn(self, input: impl Into<String>) -> Self
pub fn bucket_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn set_bucket_arn(self, input: Option<String>) -> Self
pub fn set_bucket_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn get_bucket_arn(&self) -> &Option<String>
pub fn get_bucket_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn build(self) -> CreateBucketOutput
pub fn build(self) -> CreateBucketOutput
Consumes the builder and constructs a CreateBucketOutput.