#[non_exhaustive]pub struct CreateBucketOutput {
pub location: Option<String>,
pub bucket_arn: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: Option<String>A forward slash followed by the name of the bucket.
bucket_arn: Option<String>The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Implementations
Sourceimpl CreateBucketOutput
impl CreateBucketOutput
Sourcepub fn bucket_arn(&self) -> Option<&str>
pub fn bucket_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourceimpl CreateBucketOutput
impl CreateBucketOutput
Sourcepub fn builder() -> CreateBucketOutputBuilder
pub fn builder() -> CreateBucketOutputBuilder
Creates a new builder-style object to manufacture CreateBucketOutput.