#[non_exhaustive]pub struct DeleteBucketIntelligentTieringConfigurationInput {
pub bucket: Option<String>,
pub id: Option<String>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
id: Option<String>The ID used to identify the S3 Intelligent-Tiering configuration.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Implementations
Sourceimpl DeleteBucketIntelligentTieringConfigurationInput
impl DeleteBucketIntelligentTieringConfigurationInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
The ID used to identify the S3 Intelligent-Tiering configuration.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourceimpl DeleteBucketIntelligentTieringConfigurationInput
impl DeleteBucketIntelligentTieringConfigurationInput
Sourcepub fn builder() -> DeleteBucketIntelligentTieringConfigurationInputBuilder
pub fn builder() -> DeleteBucketIntelligentTieringConfigurationInputBuilder
Creates a new builder-style object to manufacture DeleteBucketIntelligentTieringConfigurationInput.