#[non_exhaustive]pub struct DeleteBucketMetadataTableConfigurationInputBuilder { /* private fields */ }Expand description
A builder for DeleteBucketMetadataTableConfigurationInput.
Implementations
Sourceimpl DeleteBucketMetadataTableConfigurationInputBuilder
impl DeleteBucketMetadataTableConfigurationInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The general purpose bucket that you want to remove the metadata table configuration from.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The general purpose bucket that you want to remove the metadata table configuration from.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The general purpose bucket that you want to remove the metadata table configuration from.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The expected bucket owner of the general purpose bucket that you want to remove the metadata table configuration from.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The expected bucket owner of the general purpose bucket that you want to remove the metadata table configuration from.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The expected bucket owner of the general purpose bucket that you want to remove the metadata table configuration from.
Sourcepub fn build(
self,
) -> Result<DeleteBucketMetadataTableConfigurationInput, BuildError>
pub fn build( self, ) -> Result<DeleteBucketMetadataTableConfigurationInput, BuildError>
Consumes the builder and constructs a DeleteBucketMetadataTableConfigurationInput.
Sourceimpl DeleteBucketMetadataTableConfigurationInputBuilder
impl DeleteBucketMetadataTableConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DeleteBucketMetadataTableConfigurationOutput, SdkError<DeleteBucketMetadataTableConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DeleteBucketMetadataTableConfigurationOutput, SdkError<DeleteBucketMetadataTableConfigurationError, HttpResponse>>
Sends a request with this input using the given client.