#[non_exhaustive]pub struct DeleteObjectOutputBuilder { /* private fields */ }Expand description
A builder for DeleteObjectOutput.
Implementations
Sourceimpl DeleteObjectOutputBuilder
impl DeleteObjectOutputBuilder
Sourcepub fn delete_marker(self, input: bool) -> Self
pub fn delete_marker(self, input: bool) -> Self
Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
Sourcepub fn set_delete_marker(self, input: Option<bool>) -> Self
pub fn set_delete_marker(self, input: Option<bool>) -> Self
Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
Sourcepub fn get_delete_marker(&self) -> &Option<bool>
pub fn get_delete_marker(&self) -> &Option<bool>
Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
Returns the version ID of the delete marker created as a result of the DELETE operation.
This functionality is not supported for directory buckets.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
Returns the version ID of the delete marker created as a result of the DELETE operation.
This functionality is not supported for directory buckets.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
Returns the version ID of the delete marker created as a result of the DELETE operation.
This functionality is not supported for directory buckets.
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn build(self) -> DeleteObjectOutput
pub fn build(self) -> DeleteObjectOutput
Consumes the builder and constructs a DeleteObjectOutput.