#[non_exhaustive]pub struct DeleteObjectOutput {
pub delete_marker: Option<bool>,
pub version_id: Option<String>,
pub request_charged: Option<RequestCharged>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delete_marker: Option<bool>Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
version_id: Option<String>Returns the version ID of the delete marker created as a result of the DELETE operation.
This functionality is not supported for directory buckets.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Implementations
Sourceimpl DeleteObjectOutput
impl DeleteObjectOutput
Sourcepub fn delete_marker(&self) -> Option<bool>
pub fn delete_marker(&self) -> Option<bool>
Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
Sourcepub fn version_id(&self) -> Option<&str>
pub fn version_id(&self) -> Option<&str>
Returns the version ID of the delete marker created as a result of the DELETE operation.
This functionality is not supported for directory buckets.
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourceimpl DeleteObjectOutput
impl DeleteObjectOutput
Sourcepub fn builder() -> DeleteObjectOutputBuilder
pub fn builder() -> DeleteObjectOutputBuilder
Creates a new builder-style object to manufacture DeleteObjectOutput.