#[non_exhaustive]pub struct DeleteObjectsOutputBuilder { /* private fields */ }Expand description
A builder for DeleteObjectsOutput.
Implementations
Sourceimpl DeleteObjectsOutputBuilder
impl DeleteObjectsOutputBuilder
Sourcepub fn deleted(self, input: DeletedObject) -> Self
pub fn deleted(self, input: DeletedObject) -> Self
Appends an item to deleted.
To override the contents of this collection use set_deleted.
Container element for a successful delete. It identifies the object that was successfully deleted.
Sourcepub fn set_deleted(self, input: Option<Vec<DeletedObject>>) -> Self
pub fn set_deleted(self, input: Option<Vec<DeletedObject>>) -> Self
Container element for a successful delete. It identifies the object that was successfully deleted.
Sourcepub fn get_deleted(&self) -> &Option<Vec<DeletedObject>>
pub fn get_deleted(&self) -> &Option<Vec<DeletedObject>>
Container element for a successful delete. It identifies the object that was successfully deleted.
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn errors(self, input: Error) -> Self
pub fn errors(self, input: Error) -> Self
Appends an item to errors.
To override the contents of this collection use set_errors.
Container for a failed delete action that describes the object that Amazon S3 attempted to delete and the error it encountered.
Sourcepub fn set_errors(self, input: Option<Vec<Error>>) -> Self
pub fn set_errors(self, input: Option<Vec<Error>>) -> Self
Container for a failed delete action that describes the object that Amazon S3 attempted to delete and the error it encountered.
Sourcepub fn get_errors(&self) -> &Option<Vec<Error>>
pub fn get_errors(&self) -> &Option<Vec<Error>>
Container for a failed delete action that describes the object that Amazon S3 attempted to delete and the error it encountered.
Sourcepub fn build(self) -> DeleteObjectsOutput
pub fn build(self) -> DeleteObjectsOutput
Consumes the builder and constructs a DeleteObjectsOutput.