#[non_exhaustive]pub struct DeleteObjectsOutput {
pub deleted: Option<Vec<DeletedObject>>,
pub request_charged: Option<RequestCharged>,
pub errors: Option<Vec<Error>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deleted: Option<Vec<DeletedObject>>Container element for a successful delete. It identifies the object that was successfully deleted.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
errors: Option<Vec<Error>>Container for a failed delete action that describes the object that Amazon S3 attempted to delete and the error it encountered.
Implementations
Sourceimpl DeleteObjectsOutput
impl DeleteObjectsOutput
Sourcepub fn deleted(&self) -> &[DeletedObject]
pub fn deleted(&self) -> &[DeletedObject]
Container element for a successful delete. It identifies the object that was successfully deleted.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .deleted.is_none().
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourceimpl DeleteObjectsOutput
impl DeleteObjectsOutput
Sourcepub fn builder() -> DeleteObjectsOutputBuilder
pub fn builder() -> DeleteObjectsOutputBuilder
Creates a new builder-style object to manufacture DeleteObjectsOutput.