pub struct GetBucketAbacFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBucketAbac.
Returns the attribute-based access control (ABAC) property of the general purpose bucket. If ABAC is enabled on your bucket, you can use tags on the bucket for access control. For more information, see Enabling ABAC in general purpose buckets.
Implementations
Sourceimpl GetBucketAbacFluentBuilder
impl GetBucketAbacFluentBuilder
Sourcepub fn as_input(&self) -> &GetBucketAbacInputBuilder
pub fn as_input(&self) -> &GetBucketAbacInputBuilder
Access the GetBucketAbac as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBucketAbacOutput, SdkError<GetBucketAbacError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBucketAbacOutput, SdkError<GetBucketAbacError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBucketAbacOutput, GetBucketAbacError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBucketAbacOutput, GetBucketAbacError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the general purpose bucket.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the general purpose bucket.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The Amazon Web Services account ID of the general purpose bucket's owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The Amazon Web Services account ID of the general purpose bucket's owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The Amazon Web Services account ID of the general purpose bucket's owner.