pub struct GetBucketLifecycleConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBucketLifecycleConfiguration.
Returns the lifecycle configuration information set on the bucket. For information about lifecycle configuration, see Object Lifecycle Management.
Bucket lifecycle configuration now supports specifying a lifecycle rule using an object key name prefix, one or more object tags, object size, or any combination of these. Accordingly, this section describes the latest API, which is compatible with the new functionality. The previous version of the API supported filtering based only on an object key name prefix, which is supported for general purpose buckets for backward compatibility. For the related API description, see GetBucketLifecycle.
Lifecyle configurations for directory buckets only support expiring objects and cancelling multipart uploads. Expiring of versioned objects, transitions and tag filters are not supported.
- Permissions
-
-
General purpose bucket permissions - By default, all Amazon S3 resources are private, including buckets, objects, and related subresources (for example, lifecycle configuration and website configuration). Only the resource owner (that is, the Amazon Web Services account that created it) can access the resource. The resource owner can optionally grant access permissions to others by writing an access policy. For this operation, a user must have the
s3:GetLifecycleConfigurationpermission.For more information about permissions, see Managing Access Permissions to Your Amazon S3 Resources.
-
Directory bucket permissions - You must have the
s3express:GetLifecycleConfigurationpermission in an IAM identity-based policy to use this operation. Cross-account access to this API operation isn't supported. The resource owner can optionally grant access permissions to others by creating a role or user for them as long as they are within the same account as the owner and resource.For more information about directory bucket policies and permissions, see Authorizing Regional endpoint APIs with IAM in the Amazon S3 User Guide.
Directory buckets - For directory buckets, you must make requests for this API operation to the Regional endpoint. These endpoints support path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name. Virtual-hosted-style requests aren't supported. For more information about endpoints in Availability Zones, see Regional and Zonal endpoints for directory buckets in Availability Zones in the Amazon S3 User Guide. For more information about endpoints in Local Zones, see Concepts for directory buckets in Local Zones in the Amazon S3 User Guide.
-
- HTTP Host header syntax
-
Directory buckets - The HTTP Host header syntax is
s3express-control.region.amazonaws.com.
GetBucketLifecycleConfiguration has the following special error:
-
Error code:
NoSuchLifecycleConfiguration-
Description: The lifecycle configuration does not exist.
-
HTTP Status Code: 404 Not Found
-
SOAP Fault Code Prefix: Client
-
The following operations are related to GetBucketLifecycleConfiguration:
You must URL encode any signed header values that contain spaces. For example, if your header value is my file.txt, containing two spaces after my, you must URL encode this value to my%20%20file.txt.
Implementations
Sourceimpl GetBucketLifecycleConfigurationFluentBuilder
impl GetBucketLifecycleConfigurationFluentBuilder
Sourcepub fn as_input(&self) -> &GetBucketLifecycleConfigurationInputBuilder
pub fn as_input(&self) -> &GetBucketLifecycleConfigurationInputBuilder
Access the GetBucketLifecycleConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBucketLifecycleConfigurationOutput, SdkError<GetBucketLifecycleConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBucketLifecycleConfigurationOutput, SdkError<GetBucketLifecycleConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBucketLifecycleConfigurationOutput, GetBucketLifecycleConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBucketLifecycleConfigurationOutput, GetBucketLifecycleConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket for which to get the lifecycle information.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket for which to get the lifecycle information.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket for which to get the lifecycle information.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.