#[non_exhaustive]pub struct GetBucketLifecycleConfigurationOutputBuilder { /* private fields */ }Expand description
A builder for GetBucketLifecycleConfigurationOutput.
Implementations
Sourceimpl GetBucketLifecycleConfigurationOutputBuilder
impl GetBucketLifecycleConfigurationOutputBuilder
Sourcepub fn rules(self, input: LifecycleRule) -> Self
pub fn rules(self, input: LifecycleRule) -> Self
Appends an item to rules.
To override the contents of this collection use set_rules.
Container for a lifecycle rule.
Sourcepub fn set_rules(self, input: Option<Vec<LifecycleRule>>) -> Self
pub fn set_rules(self, input: Option<Vec<LifecycleRule>>) -> Self
Container for a lifecycle rule.
Sourcepub fn get_rules(&self) -> &Option<Vec<LifecycleRule>>
pub fn get_rules(&self) -> &Option<Vec<LifecycleRule>>
Container for a lifecycle rule.
Sourcepub fn transition_default_minimum_object_size(
self,
input: TransitionDefaultMinimumObjectSize,
) -> Self
pub fn transition_default_minimum_object_size( self, input: TransitionDefaultMinimumObjectSize, ) -> Self
Indicates which default minimum object size behavior is applied to the lifecycle configuration.
This parameter applies to general purpose buckets only. It isn't supported for directory bucket lifecycle configurations.
-
all_storage_classes_128K- Objects smaller than 128 KB will not transition to any storage class by default. -
varies_by_storage_class- Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
Sourcepub fn set_transition_default_minimum_object_size(
self,
input: Option<TransitionDefaultMinimumObjectSize>,
) -> Self
pub fn set_transition_default_minimum_object_size( self, input: Option<TransitionDefaultMinimumObjectSize>, ) -> Self
Indicates which default minimum object size behavior is applied to the lifecycle configuration.
This parameter applies to general purpose buckets only. It isn't supported for directory bucket lifecycle configurations.
-
all_storage_classes_128K- Objects smaller than 128 KB will not transition to any storage class by default. -
varies_by_storage_class- Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
Sourcepub fn get_transition_default_minimum_object_size(
&self,
) -> &Option<TransitionDefaultMinimumObjectSize>
pub fn get_transition_default_minimum_object_size( &self, ) -> &Option<TransitionDefaultMinimumObjectSize>
Indicates which default minimum object size behavior is applied to the lifecycle configuration.
This parameter applies to general purpose buckets only. It isn't supported for directory bucket lifecycle configurations.
-
all_storage_classes_128K- Objects smaller than 128 KB will not transition to any storage class by default. -
varies_by_storage_class- Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
Sourcepub fn build(self) -> GetBucketLifecycleConfigurationOutput
pub fn build(self) -> GetBucketLifecycleConfigurationOutput
Consumes the builder and constructs a GetBucketLifecycleConfigurationOutput.