#[non_exhaustive]pub struct GetBucketMetadataTableConfigurationOutputBuilder { /* private fields */ }Expand description
A builder for GetBucketMetadataTableConfigurationOutput.
Implementations
Sourceimpl GetBucketMetadataTableConfigurationOutputBuilder
impl GetBucketMetadataTableConfigurationOutputBuilder
Sourcepub fn get_bucket_metadata_table_configuration_result(
self,
input: GetBucketMetadataTableConfigurationResult,
) -> Self
pub fn get_bucket_metadata_table_configuration_result( self, input: GetBucketMetadataTableConfigurationResult, ) -> Self
The metadata table configuration for the general purpose bucket.
Sourcepub fn set_get_bucket_metadata_table_configuration_result(
self,
input: Option<GetBucketMetadataTableConfigurationResult>,
) -> Self
pub fn set_get_bucket_metadata_table_configuration_result( self, input: Option<GetBucketMetadataTableConfigurationResult>, ) -> Self
The metadata table configuration for the general purpose bucket.
Sourcepub fn get_get_bucket_metadata_table_configuration_result(
&self,
) -> &Option<GetBucketMetadataTableConfigurationResult>
pub fn get_get_bucket_metadata_table_configuration_result( &self, ) -> &Option<GetBucketMetadataTableConfigurationResult>
The metadata table configuration for the general purpose bucket.
Sourcepub fn build(self) -> GetBucketMetadataTableConfigurationOutput
pub fn build(self) -> GetBucketMetadataTableConfigurationOutput
Consumes the builder and constructs a GetBucketMetadataTableConfigurationOutput.