pub struct GetBucketOwnershipControlsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBucketOwnershipControls.
This operation is not supported for directory buckets.
Retrieves OwnershipControls for an Amazon S3 bucket. To use this operation, you must have the s3:GetBucketOwnershipControls permission. For more information about Amazon S3 permissions, see Specifying permissions in a policy.
A bucket doesn't have OwnershipControls settings in the following cases:
-
The bucket was created before the
BucketOwnerEnforcedownership setting was introduced and you've never explicitly applied this value -
You've manually deleted the bucket ownership control value using the
DeleteBucketOwnershipControlsAPI operation.
By default, Amazon S3 sets OwnershipControls for all newly created buckets.
For information about Amazon S3 Object Ownership, see Using Object Ownership.
The following operations are related to GetBucketOwnershipControls:
-
PutBucketOwnershipControls -
DeleteBucketOwnershipControls
You must URL encode any signed header values that contain spaces. For example, if your header value is my file.txt, containing two spaces after my, you must URL encode this value to my%20%20file.txt.
Implementations
Sourceimpl GetBucketOwnershipControlsFluentBuilder
impl GetBucketOwnershipControlsFluentBuilder
Sourcepub fn as_input(&self) -> &GetBucketOwnershipControlsInputBuilder
pub fn as_input(&self) -> &GetBucketOwnershipControlsInputBuilder
Access the GetBucketOwnershipControls as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBucketOwnershipControlsOutput, SdkError<GetBucketOwnershipControlsError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBucketOwnershipControlsOutput, SdkError<GetBucketOwnershipControlsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBucketOwnershipControlsOutput, GetBucketOwnershipControlsError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBucketOwnershipControlsOutput, GetBucketOwnershipControlsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the Amazon S3 bucket whose OwnershipControls you want to retrieve.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the Amazon S3 bucket whose OwnershipControls you want to retrieve.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the Amazon S3 bucket whose OwnershipControls you want to retrieve.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).