#[non_exhaustive]pub struct GetBucketReplicationOutputBuilder { /* private fields */ }Expand description
A builder for GetBucketReplicationOutput.
Implementations
Sourceimpl GetBucketReplicationOutputBuilder
impl GetBucketReplicationOutputBuilder
Sourcepub fn replication_configuration(self, input: ReplicationConfiguration) -> Self
pub fn replication_configuration(self, input: ReplicationConfiguration) -> Self
A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB.
Sourcepub fn set_replication_configuration(
self,
input: Option<ReplicationConfiguration>,
) -> Self
pub fn set_replication_configuration( self, input: Option<ReplicationConfiguration>, ) -> Self
A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB.
Sourcepub fn get_replication_configuration(&self) -> &Option<ReplicationConfiguration>
pub fn get_replication_configuration(&self) -> &Option<ReplicationConfiguration>
A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB.
Sourcepub fn build(self) -> GetBucketReplicationOutput
pub fn build(self) -> GetBucketReplicationOutput
Consumes the builder and constructs a GetBucketReplicationOutput.