#[non_exhaustive]pub struct GetBucketWebsiteOutput {
pub redirect_all_requests_to: Option<RedirectAllRequestsTo>,
pub index_document: Option<IndexDocument>,
pub error_document: Option<ErrorDocument>,
pub routing_rules: Option<Vec<RoutingRule>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.redirect_all_requests_to: Option<RedirectAllRequestsTo>Specifies the redirect behavior of all requests to a website endpoint of an Amazon S3 bucket.
index_document: Option<IndexDocument>The name of the index document for the website (for example index.html).
error_document: Option<ErrorDocument>The object key name of the website error document to use for 4XX class errors.
routing_rules: Option<Vec<RoutingRule>>Rules that define when a redirect is applied and the redirect behavior.
Implementations
Sourceimpl GetBucketWebsiteOutput
impl GetBucketWebsiteOutput
Sourcepub fn redirect_all_requests_to(&self) -> Option<&RedirectAllRequestsTo>
pub fn redirect_all_requests_to(&self) -> Option<&RedirectAllRequestsTo>
Specifies the redirect behavior of all requests to a website endpoint of an Amazon S3 bucket.
Sourcepub fn index_document(&self) -> Option<&IndexDocument>
pub fn index_document(&self) -> Option<&IndexDocument>
The name of the index document for the website (for example index.html).
Sourcepub fn error_document(&self) -> Option<&ErrorDocument>
pub fn error_document(&self) -> Option<&ErrorDocument>
The object key name of the website error document to use for 4XX class errors.
Sourcepub fn routing_rules(&self) -> &[RoutingRule]
pub fn routing_rules(&self) -> &[RoutingRule]
Rules that define when a redirect is applied and the redirect behavior.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .routing_rules.is_none().
Sourceimpl GetBucketWebsiteOutput
impl GetBucketWebsiteOutput
Sourcepub fn builder() -> GetBucketWebsiteOutputBuilder
pub fn builder() -> GetBucketWebsiteOutputBuilder
Creates a new builder-style object to manufacture GetBucketWebsiteOutput.