#[non_exhaustive]pub struct GetObjectAclOutputBuilder { /* private fields */ }Expand description
A builder for GetObjectAclOutput.
Implementations
Sourceimpl GetObjectAclOutputBuilder
impl GetObjectAclOutputBuilder
Sourcepub fn grants(self, input: Grant) -> Self
pub fn grants(self, input: Grant) -> Self
Appends an item to grants.
To override the contents of this collection use set_grants.
A list of grants.
Sourcepub fn set_grants(self, input: Option<Vec<Grant>>) -> Self
pub fn set_grants(self, input: Option<Vec<Grant>>) -> Self
A list of grants.
Sourcepub fn get_grants(&self) -> &Option<Vec<Grant>>
pub fn get_grants(&self) -> &Option<Vec<Grant>>
A list of grants.
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn build(self) -> GetObjectAclOutput
pub fn build(self) -> GetObjectAclOutput
Consumes the builder and constructs a GetObjectAclOutput.