#[non_exhaustive]pub struct GetObjectAclOutput {
pub owner: Option<Owner>,
pub grants: Option<Vec<Grant>>,
pub request_charged: Option<RequestCharged>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.owner: Option<Owner>Container for the bucket owner's ID.
grants: Option<Vec<Grant>>A list of grants.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Implementations
Sourceimpl GetObjectAclOutput
impl GetObjectAclOutput
Sourcepub fn grants(&self) -> &[Grant]
pub fn grants(&self) -> &[Grant]
A list of grants.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .grants.is_none().
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourceimpl GetObjectAclOutput
impl GetObjectAclOutput
Sourcepub fn builder() -> GetObjectAclOutputBuilder
pub fn builder() -> GetObjectAclOutputBuilder
Creates a new builder-style object to manufacture GetObjectAclOutput.