#[non_exhaustive]pub struct GetObjectAttributesOutput {
pub delete_marker: Option<bool>,
pub last_modified: Option<DateTime>,
pub version_id: Option<String>,
pub request_charged: Option<RequestCharged>,
pub e_tag: Option<String>,
pub checksum: Option<Checksum>,
pub object_parts: Option<GetObjectAttributesParts>,
pub storage_class: Option<StorageClass>,
pub object_size: Option<i64>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delete_marker: Option<bool>Specifies whether the object retrieved was (true) or was not (false) a delete marker. If false, this response header does not appear in the response. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
last_modified: Option<DateTime>Date and time when the object was last modified.
version_id: Option<String>The version ID of the object.
This functionality is not supported for directory buckets.
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
e_tag: Option<String>An ETag is an opaque identifier assigned by a web server to a specific version of a resource found at a URL.
checksum: Option<Checksum>The checksum or digest of the object.
object_parts: Option<GetObjectAttributesParts>A collection of parts associated with a multipart upload.
storage_class: Option<StorageClass>Provides the storage class information of the object. Amazon S3 returns this header for all objects except for S3 Standard storage class objects.
For more information, see Storage Classes.
Directory buckets - Directory buckets only support EXPRESS_ONEZONE (the S3 Express One Zone storage class) in Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent Access storage class) in Dedicated Local Zones.
object_size: Option<i64>The size of the object in bytes.
Implementations
Sourceimpl GetObjectAttributesOutput
impl GetObjectAttributesOutput
Sourcepub fn delete_marker(&self) -> Option<bool>
pub fn delete_marker(&self) -> Option<bool>
Specifies whether the object retrieved was (true) or was not (false) a delete marker. If false, this response header does not appear in the response. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
Sourcepub fn last_modified(&self) -> Option<&DateTime>
pub fn last_modified(&self) -> Option<&DateTime>
Date and time when the object was last modified.
Sourcepub fn version_id(&self) -> Option<&str>
pub fn version_id(&self) -> Option<&str>
The version ID of the object.
This functionality is not supported for directory buckets.
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn e_tag(&self) -> Option<&str>
pub fn e_tag(&self) -> Option<&str>
An ETag is an opaque identifier assigned by a web server to a specific version of a resource found at a URL.
Sourcepub fn object_parts(&self) -> Option<&GetObjectAttributesParts>
pub fn object_parts(&self) -> Option<&GetObjectAttributesParts>
A collection of parts associated with a multipart upload.
Sourcepub fn storage_class(&self) -> Option<&StorageClass>
pub fn storage_class(&self) -> Option<&StorageClass>
Provides the storage class information of the object. Amazon S3 returns this header for all objects except for S3 Standard storage class objects.
For more information, see Storage Classes.
Directory buckets - Directory buckets only support EXPRESS_ONEZONE (the S3 Express One Zone storage class) in Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent Access storage class) in Dedicated Local Zones.
Sourcepub fn object_size(&self) -> Option<i64>
pub fn object_size(&self) -> Option<i64>
The size of the object in bytes.
Sourceimpl GetObjectAttributesOutput
impl GetObjectAttributesOutput
Sourcepub fn builder() -> GetObjectAttributesOutputBuilder
pub fn builder() -> GetObjectAttributesOutputBuilder
Creates a new builder-style object to manufacture GetObjectAttributesOutput.