Struct GetObjectTorrentOutputBuilder

#[non_exhaustive]
pub struct GetObjectTorrentOutputBuilder { /* private fields */ }
A builder for GetObjectTorrentOutput.

Implementations

Source

impl GetObjectTorrentOutputBuilder

pub fn body(self, input: ByteStream) -> Self

A Bencoded dictionary as defined by the BitTorrent specification

pub fn set_body(self, input: Option<ByteStream>) -> Self

A Bencoded dictionary as defined by the BitTorrent specification

pub fn get_body(&self) -> &Option<ByteStream>

A Bencoded dictionary as defined by the BitTorrent specification

pub fn request_charged(self, input: RequestCharged) -> Self

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

pub fn get_request_charged(&self) -> &Option<RequestCharged>

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

pub fn build(self) -> GetObjectTorrentOutput

Consumes the builder and constructs a GetObjectTorrentOutput.