Struct GetObjectTorrentOutput

#[non_exhaustive]
pub struct GetObjectTorrentOutput { pub body: ByteStream, pub request_charged: Option<RequestCharged>, /* private fields */ }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
body: ByteStream

A Bencoded dictionary as defined by the BitTorrent specification

request_charged: Option<RequestCharged>

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Implementations

Source

impl GetObjectTorrentOutput

pub fn body(&self) -> &ByteStream

A Bencoded dictionary as defined by the BitTorrent specification

pub fn request_charged(&self) -> Option<&RequestCharged>

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Source

impl GetObjectTorrentOutput

pub fn builder() -> GetObjectTorrentOutputBuilder

Creates a new builder-style object to manufacture GetObjectTorrentOutput.