pub struct GetPublicAccessBlockFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetPublicAccessBlock.
This operation is not supported for directory buckets.
Retrieves the PublicAccessBlock configuration for an Amazon S3 bucket. This operation returns the bucket-level configuration only. To understand the effective public access behavior, you must also consider account-level settings (which may inherit from organization-level policies). To use this operation, you must have the s3:GetBucketPublicAccessBlock permission. For more information about Amazon S3 permissions, see Specifying Permissions in a Policy.
When Amazon S3 evaluates the PublicAccessBlock configuration for a bucket or an object, it checks the PublicAccessBlock configuration for both the bucket (or the bucket that contains the object) and the bucket owner's account. Account-level settings automatically inherit from organization-level policies when present. If the PublicAccessBlock settings are different between the bucket and the account, Amazon S3 uses the most restrictive combination of the bucket-level and account-level settings.
For more information about when Amazon S3 considers a bucket or an object public, see The Meaning of "Public".
The following operations are related to GetPublicAccessBlock:
You must URL encode any signed header values that contain spaces. For example, if your header value is my file.txt, containing two spaces after my, you must URL encode this value to my%20%20file.txt.
Implementations
Sourceimpl GetPublicAccessBlockFluentBuilder
impl GetPublicAccessBlockFluentBuilder
Sourcepub fn as_input(&self) -> &GetPublicAccessBlockInputBuilder
pub fn as_input(&self) -> &GetPublicAccessBlockInputBuilder
Access the GetPublicAccessBlock as a reference.
Sourcepub async fn send(
self,
) -> Result<GetPublicAccessBlockOutput, SdkError<GetPublicAccessBlockError, HttpResponse>>
pub async fn send( self, ) -> Result<GetPublicAccessBlockOutput, SdkError<GetPublicAccessBlockError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetPublicAccessBlockOutput, GetPublicAccessBlockError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetPublicAccessBlockOutput, GetPublicAccessBlockError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to retrieve.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to retrieve.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to retrieve.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).