#[non_exhaustive]pub struct HeadBucketOutputBuilder { /* private fields */ }Expand description
A builder for HeadBucketOutput.
Implementations
Sourceimpl HeadBucketOutputBuilder
impl HeadBucketOutputBuilder
Sourcepub fn bucket_arn(self, input: impl Into<String>) -> Self
pub fn bucket_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn set_bucket_arn(self, input: Option<String>) -> Self
pub fn set_bucket_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn get_bucket_arn(&self) -> &Option<String>
pub fn get_bucket_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn bucket_location_type(self, input: LocationType) -> Self
pub fn bucket_location_type(self, input: LocationType) -> Self
The type of location where the bucket is created.
This functionality is only supported by directory buckets.
Sourcepub fn set_bucket_location_type(self, input: Option<LocationType>) -> Self
pub fn set_bucket_location_type(self, input: Option<LocationType>) -> Self
The type of location where the bucket is created.
This functionality is only supported by directory buckets.
Sourcepub fn get_bucket_location_type(&self) -> &Option<LocationType>
pub fn get_bucket_location_type(&self) -> &Option<LocationType>
The type of location where the bucket is created.
This functionality is only supported by directory buckets.
Sourcepub fn bucket_location_name(self, input: impl Into<String>) -> Self
pub fn bucket_location_name(self, input: impl Into<String>) -> Self
The name of the location where the bucket will be created.
For directory buckets, the Zone ID of the Availability Zone or the Local Zone where the bucket is created. An example Zone ID value for an Availability Zone is usw2-az1.
This functionality is only supported by directory buckets.
Sourcepub fn set_bucket_location_name(self, input: Option<String>) -> Self
pub fn set_bucket_location_name(self, input: Option<String>) -> Self
The name of the location where the bucket will be created.
For directory buckets, the Zone ID of the Availability Zone or the Local Zone where the bucket is created. An example Zone ID value for an Availability Zone is usw2-az1.
This functionality is only supported by directory buckets.
Sourcepub fn get_bucket_location_name(&self) -> &Option<String>
pub fn get_bucket_location_name(&self) -> &Option<String>
The name of the location where the bucket will be created.
For directory buckets, the Zone ID of the Availability Zone or the Local Zone where the bucket is created. An example Zone ID value for an Availability Zone is usw2-az1.
This functionality is only supported by directory buckets.
Sourcepub fn bucket_region(self, input: impl Into<String>) -> Self
pub fn bucket_region(self, input: impl Into<String>) -> Self
The Region that the bucket is located.
Sourcepub fn set_bucket_region(self, input: Option<String>) -> Self
pub fn set_bucket_region(self, input: Option<String>) -> Self
The Region that the bucket is located.
Sourcepub fn get_bucket_region(&self) -> &Option<String>
pub fn get_bucket_region(&self) -> &Option<String>
The Region that the bucket is located.
Sourcepub fn access_point_alias(self, input: bool) -> Self
pub fn access_point_alias(self, input: bool) -> Self
Indicates whether the bucket name used in the request is an access point alias.
For directory buckets, the value of this field is false.
Sourcepub fn set_access_point_alias(self, input: Option<bool>) -> Self
pub fn set_access_point_alias(self, input: Option<bool>) -> Self
Indicates whether the bucket name used in the request is an access point alias.
For directory buckets, the value of this field is false.
Sourcepub fn get_access_point_alias(&self) -> &Option<bool>
pub fn get_access_point_alias(&self) -> &Option<bool>
Indicates whether the bucket name used in the request is an access point alias.
For directory buckets, the value of this field is false.
Sourcepub fn build(self) -> HeadBucketOutput
pub fn build(self) -> HeadBucketOutput
Consumes the builder and constructs a HeadBucketOutput.