#[non_exhaustive]pub struct ListBucketIntelligentTieringConfigurationsInput {
pub bucket: Option<String>,
pub continuation_token: Option<String>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
continuation_token: Option<String>The ContinuationToken that represents a placeholder from where this request should begin.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Implementations
Sourceimpl ListBucketIntelligentTieringConfigurationsInput
impl ListBucketIntelligentTieringConfigurationsInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
The ContinuationToken that represents a placeholder from where this request should begin.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourceimpl ListBucketIntelligentTieringConfigurationsInput
impl ListBucketIntelligentTieringConfigurationsInput
Sourcepub fn builder() -> ListBucketIntelligentTieringConfigurationsInputBuilder
pub fn builder() -> ListBucketIntelligentTieringConfigurationsInputBuilder
Creates a new builder-style object to manufacture ListBucketIntelligentTieringConfigurationsInput.