#[non_exhaustive]pub struct ListBucketIntelligentTieringConfigurationsOutput {
pub is_truncated: Option<bool>,
pub continuation_token: Option<String>,
pub next_continuation_token: Option<String>,
pub intelligent_tiering_configuration_list: Option<Vec<IntelligentTieringConfiguration>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_truncated: Option<bool>Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
continuation_token: Option<String>The ContinuationToken that represents a placeholder from where this request should begin.
next_continuation_token: Option<String>The marker used to continue this inventory configuration listing. Use the NextContinuationToken from this response to continue the listing in a subsequent request. The continuation token is an opaque value that Amazon S3 understands.
intelligent_tiering_configuration_list: Option<Vec<IntelligentTieringConfiguration>>The list of S3 Intelligent-Tiering configurations for a bucket.
Implementations
Sourceimpl ListBucketIntelligentTieringConfigurationsOutput
impl ListBucketIntelligentTieringConfigurationsOutput
Sourcepub fn is_truncated(&self) -> Option<bool>
pub fn is_truncated(&self) -> Option<bool>
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
The ContinuationToken that represents a placeholder from where this request should begin.
Sourcepub fn next_continuation_token(&self) -> Option<&str>
pub fn next_continuation_token(&self) -> Option<&str>
The marker used to continue this inventory configuration listing. Use the NextContinuationToken from this response to continue the listing in a subsequent request. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn intelligent_tiering_configuration_list(
&self,
) -> &[IntelligentTieringConfiguration]
pub fn intelligent_tiering_configuration_list( &self, ) -> &[IntelligentTieringConfiguration]
The list of S3 Intelligent-Tiering configurations for a bucket.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .intelligent_tiering_configuration_list.is_none().
Sourceimpl ListBucketIntelligentTieringConfigurationsOutput
impl ListBucketIntelligentTieringConfigurationsOutput
Sourcepub fn builder() -> ListBucketIntelligentTieringConfigurationsOutputBuilder
pub fn builder() -> ListBucketIntelligentTieringConfigurationsOutputBuilder
Creates a new builder-style object to manufacture ListBucketIntelligentTieringConfigurationsOutput.