#[non_exhaustive]pub struct ListBucketMetricsConfigurationsInputBuilder { /* private fields */ }Expand description
A builder for ListBucketMetricsConfigurationsInput.
Implementations
Sourceimpl ListBucketMetricsConfigurationsInputBuilder
impl ListBucketMetricsConfigurationsInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket containing the metrics configurations to retrieve.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket containing the metrics configurations to retrieve.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket containing the metrics configurations to retrieve.
Sourcepub fn continuation_token(self, input: impl Into<String>) -> Self
pub fn continuation_token(self, input: impl Into<String>) -> Self
The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn set_continuation_token(self, input: Option<String>) -> Self
pub fn set_continuation_token(self, input: Option<String>) -> Self
The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn build(self) -> Result<ListBucketMetricsConfigurationsInput, BuildError>
pub fn build(self) -> Result<ListBucketMetricsConfigurationsInput, BuildError>
Consumes the builder and constructs a ListBucketMetricsConfigurationsInput.
Sourceimpl ListBucketMetricsConfigurationsInputBuilder
impl ListBucketMetricsConfigurationsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListBucketMetricsConfigurationsOutput, SdkError<ListBucketMetricsConfigurationsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListBucketMetricsConfigurationsOutput, SdkError<ListBucketMetricsConfigurationsError, HttpResponse>>
Sends a request with this input using the given client.