#[non_exhaustive]pub struct ListBucketMetricsConfigurationsOutputBuilder { /* private fields */ }Expand description
A builder for ListBucketMetricsConfigurationsOutput.
Implementations
Sourceimpl ListBucketMetricsConfigurationsOutputBuilder
impl ListBucketMetricsConfigurationsOutputBuilder
Sourcepub fn is_truncated(self, input: bool) -> Self
pub fn is_truncated(self, input: bool) -> Self
Indicates whether the returned list of metrics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn set_is_truncated(self, input: Option<bool>) -> Self
pub fn set_is_truncated(self, input: Option<bool>) -> Self
Indicates whether the returned list of metrics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn get_is_truncated(&self) -> &Option<bool>
pub fn get_is_truncated(&self) -> &Option<bool>
Indicates whether the returned list of metrics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn continuation_token(self, input: impl Into<String>) -> Self
pub fn continuation_token(self, input: impl Into<String>) -> Self
The marker that is used as a starting point for this metrics configuration list response. This value is present if it was sent in the request.
Sourcepub fn set_continuation_token(self, input: Option<String>) -> Self
pub fn set_continuation_token(self, input: Option<String>) -> Self
The marker that is used as a starting point for this metrics configuration list response. This value is present if it was sent in the request.
Sourcepub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
The marker that is used as a starting point for this metrics configuration list response. This value is present if it was sent in the request.
Sourcepub fn next_continuation_token(self, input: impl Into<String>) -> Self
pub fn next_continuation_token(self, input: impl Into<String>) -> Self
The marker used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn set_next_continuation_token(self, input: Option<String>) -> Self
pub fn set_next_continuation_token(self, input: Option<String>) -> Self
The marker used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn get_next_continuation_token(&self) -> &Option<String>
pub fn get_next_continuation_token(&self) -> &Option<String>
The marker used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn metrics_configuration_list(self, input: MetricsConfiguration) -> Self
pub fn metrics_configuration_list(self, input: MetricsConfiguration) -> Self
Appends an item to metrics_configuration_list.
To override the contents of this collection use set_metrics_configuration_list.
The list of metrics configurations for a bucket.
Sourcepub fn set_metrics_configuration_list(
self,
input: Option<Vec<MetricsConfiguration>>,
) -> Self
pub fn set_metrics_configuration_list( self, input: Option<Vec<MetricsConfiguration>>, ) -> Self
The list of metrics configurations for a bucket.
Sourcepub fn get_metrics_configuration_list(
&self,
) -> &Option<Vec<MetricsConfiguration>>
pub fn get_metrics_configuration_list( &self, ) -> &Option<Vec<MetricsConfiguration>>
The list of metrics configurations for a bucket.
Sourcepub fn build(self) -> ListBucketMetricsConfigurationsOutput
pub fn build(self) -> ListBucketMetricsConfigurationsOutput
Consumes the builder and constructs a ListBucketMetricsConfigurationsOutput.