#[non_exhaustive]pub struct ListBucketMetricsConfigurationsInput {
pub bucket: Option<String>,
pub continuation_token: Option<String>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the bucket containing the metrics configurations to retrieve.
continuation_token: Option<String>The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Implementations
Sourceimpl ListBucketMetricsConfigurationsInput
impl ListBucketMetricsConfigurationsInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the bucket containing the metrics configurations to retrieve.
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourceimpl ListBucketMetricsConfigurationsInput
impl ListBucketMetricsConfigurationsInput
Sourcepub fn builder() -> ListBucketMetricsConfigurationsInputBuilder
pub fn builder() -> ListBucketMetricsConfigurationsInputBuilder
Creates a new builder-style object to manufacture ListBucketMetricsConfigurationsInput.