#[non_exhaustive]pub struct ListBucketMetricsConfigurationsOutput {
pub is_truncated: Option<bool>,
pub continuation_token: Option<String>,
pub next_continuation_token: Option<String>,
pub metrics_configuration_list: Option<Vec<MetricsConfiguration>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_truncated: Option<bool>Indicates whether the returned list of metrics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
continuation_token: Option<String>The marker that is used as a starting point for this metrics configuration list response. This value is present if it was sent in the request.
next_continuation_token: Option<String>The marker used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
metrics_configuration_list: Option<Vec<MetricsConfiguration>>The list of metrics configurations for a bucket.
Implementations
Sourceimpl ListBucketMetricsConfigurationsOutput
impl ListBucketMetricsConfigurationsOutput
Sourcepub fn is_truncated(&self) -> Option<bool>
pub fn is_truncated(&self) -> Option<bool>
Indicates whether the returned list of metrics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
The marker that is used as a starting point for this metrics configuration list response. This value is present if it was sent in the request.
Sourcepub fn next_continuation_token(&self) -> Option<&str>
pub fn next_continuation_token(&self) -> Option<&str>
The marker used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands.
Sourcepub fn metrics_configuration_list(&self) -> &[MetricsConfiguration]
pub fn metrics_configuration_list(&self) -> &[MetricsConfiguration]
The list of metrics configurations for a bucket.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .metrics_configuration_list.is_none().
Sourceimpl ListBucketMetricsConfigurationsOutput
impl ListBucketMetricsConfigurationsOutput
Sourcepub fn builder() -> ListBucketMetricsConfigurationsOutputBuilder
pub fn builder() -> ListBucketMetricsConfigurationsOutputBuilder
Creates a new builder-style object to manufacture ListBucketMetricsConfigurationsOutput.