#[non_exhaustive]pub struct ListBucketsOutput {
pub buckets: Option<Vec<Bucket>>,
pub owner: Option<Owner>,
pub continuation_token: Option<String>,
pub prefix: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.buckets: Option<Vec<Bucket>>The list of buckets owned by the requester.
owner: Option<Owner>The owner of the buckets listed.
continuation_token: Option<String>ContinuationToken is included in the response when there are more buckets that can be listed with pagination. The next ListBuckets request to Amazon S3 can be continued with this ContinuationToken. ContinuationToken is obfuscated and is not a real bucket.
prefix: Option<String>If Prefix was sent with the request, it is included in the response.
All bucket names in the response begin with the specified bucket name prefix.
Implementations
Sourceimpl ListBucketsOutput
impl ListBucketsOutput
Sourcepub fn buckets(&self) -> &[Bucket]
pub fn buckets(&self) -> &[Bucket]
The list of buckets owned by the requester.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .buckets.is_none().
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
ContinuationToken is included in the response when there are more buckets that can be listed with pagination. The next ListBuckets request to Amazon S3 can be continued with this ContinuationToken. ContinuationToken is obfuscated and is not a real bucket.
Sourceimpl ListBucketsOutput
impl ListBucketsOutput
Sourcepub fn builder() -> ListBucketsOutputBuilder
pub fn builder() -> ListBucketsOutputBuilder
Creates a new builder-style object to manufacture ListBucketsOutput.