#[non_exhaustive]pub struct ListDirectoryBucketsInput {
pub continuation_token: Option<String>,
pub max_directory_buckets: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.continuation_token: Option<String>ContinuationToken indicates to Amazon S3 that the list is being continued on buckets in this account with a token. ContinuationToken is obfuscated and is not a real bucket name. You can use this ContinuationToken for the pagination of the list results.
max_directory_buckets: Option<i32>Maximum number of buckets to be returned in response. When the number is more than the count of buckets that are owned by an Amazon Web Services account, return all the buckets in response.
Implementations
Sourceimpl ListDirectoryBucketsInput
impl ListDirectoryBucketsInput
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
ContinuationToken indicates to Amazon S3 that the list is being continued on buckets in this account with a token. ContinuationToken is obfuscated and is not a real bucket name. You can use this ContinuationToken for the pagination of the list results.
Sourcepub fn max_directory_buckets(&self) -> Option<i32>
pub fn max_directory_buckets(&self) -> Option<i32>
Maximum number of buckets to be returned in response. When the number is more than the count of buckets that are owned by an Amazon Web Services account, return all the buckets in response.
Sourceimpl ListDirectoryBucketsInput
impl ListDirectoryBucketsInput
Sourcepub fn builder() -> ListDirectoryBucketsInputBuilder
pub fn builder() -> ListDirectoryBucketsInputBuilder
Creates a new builder-style object to manufacture ListDirectoryBucketsInput.