#[non_exhaustive]pub struct ListDirectoryBucketsOutput {
pub buckets: Option<Vec<Bucket>>,
pub continuation_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.buckets: Option<Vec<Bucket>>The list of buckets owned by the requester.
continuation_token: Option<String>If ContinuationToken was sent with the request, it is included in the response. You can use the returned ContinuationToken for pagination of the list response.
Implementations
Sourceimpl ListDirectoryBucketsOutput
impl ListDirectoryBucketsOutput
Sourcepub fn buckets(&self) -> &[Bucket]
pub fn buckets(&self) -> &[Bucket]
The list of buckets owned by the requester.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .buckets.is_none().
Sourcepub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
If ContinuationToken was sent with the request, it is included in the response. You can use the returned ContinuationToken for pagination of the list response.
Sourceimpl ListDirectoryBucketsOutput
impl ListDirectoryBucketsOutput
Sourcepub fn builder() -> ListDirectoryBucketsOutputBuilder
pub fn builder() -> ListDirectoryBucketsOutputBuilder
Creates a new builder-style object to manufacture ListDirectoryBucketsOutput.