pub struct PutBucketAbacFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutBucketAbac.
Sets the attribute-based access control (ABAC) property of the general purpose bucket. You must have s3:PutBucketABAC permission to perform this action. When you enable ABAC, you can use tags for access control on your buckets. Additionally, when ABAC is enabled, you must use the TagResource and UntagResource actions to manage tags on your buckets. You can nolonger use the PutBucketTagging and DeleteBucketTagging actions to tag your bucket. For more information, see Enabling ABAC in general purpose buckets.
Implementations
Sourceimpl PutBucketAbacFluentBuilder
impl PutBucketAbacFluentBuilder
Sourcepub fn as_input(&self) -> &PutBucketAbacInputBuilder
pub fn as_input(&self) -> &PutBucketAbacInputBuilder
Access the PutBucketAbac as a reference.
Sourcepub async fn send(
self,
) -> Result<PutBucketAbacOutput, SdkError<PutBucketAbacError, HttpResponse>>
pub async fn send( self, ) -> Result<PutBucketAbacOutput, SdkError<PutBucketAbacError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PutBucketAbacOutput, PutBucketAbacError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutBucketAbacOutput, PutBucketAbacError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the general purpose bucket.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the general purpose bucket.
Sourcepub fn content_md5(self, input: impl Into<String>) -> Self
pub fn content_md5(self, input: impl Into<String>) -> Self
The MD5 hash of the PutBucketAbac request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Sourcepub fn set_content_md5(self, input: Option<String>) -> Self
pub fn set_content_md5(self, input: Option<String>) -> Self
The MD5 hash of the PutBucketAbac request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Sourcepub fn get_content_md5(&self) -> &Option<String>
pub fn get_content_md5(&self) -> &Option<String>
The MD5 hash of the PutBucketAbac request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Sourcepub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
pub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
pub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The Amazon Web Services account ID of the general purpose bucket's owner.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The Amazon Web Services account ID of the general purpose bucket's owner.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The Amazon Web Services account ID of the general purpose bucket's owner.
Sourcepub fn abac_status(self, input: AbacStatus) -> Self
pub fn abac_status(self, input: AbacStatus) -> Self
The ABAC status of the general purpose bucket. When ABAC is enabled for the general purpose bucket, you can use tags to manage access to the general purpose buckets as well as for cost tracking purposes. When ABAC is disabled for the general purpose buckets, you can only use tags for cost tracking purposes. For more information, see Using tags with S3 general purpose buckets.
Sourcepub fn set_abac_status(self, input: Option<AbacStatus>) -> Self
pub fn set_abac_status(self, input: Option<AbacStatus>) -> Self
The ABAC status of the general purpose bucket. When ABAC is enabled for the general purpose bucket, you can use tags to manage access to the general purpose buckets as well as for cost tracking purposes. When ABAC is disabled for the general purpose buckets, you can only use tags for cost tracking purposes. For more information, see Using tags with S3 general purpose buckets.
Sourcepub fn get_abac_status(&self) -> &Option<AbacStatus>
pub fn get_abac_status(&self) -> &Option<AbacStatus>
The ABAC status of the general purpose bucket. When ABAC is enabled for the general purpose bucket, you can use tags to manage access to the general purpose buckets as well as for cost tracking purposes. When ABAC is disabled for the general purpose buckets, you can only use tags for cost tracking purposes. For more information, see Using tags with S3 general purpose buckets.