#[non_exhaustive]pub struct PutBucketAbacInput {
pub bucket: Option<String>,
pub content_md5: Option<String>,
pub checksum_algorithm: Option<ChecksumAlgorithm>,
pub expected_bucket_owner: Option<String>,
pub abac_status: Option<AbacStatus>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the general purpose bucket.
content_md5: Option<String>The MD5 hash of the PutBucketAbac request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
checksum_algorithm: Option<ChecksumAlgorithm>Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see Checking object integrity in the Amazon S3 User Guide.
expected_bucket_owner: Option<String>The Amazon Web Services account ID of the general purpose bucket's owner.
abac_status: Option<AbacStatus>The ABAC status of the general purpose bucket. When ABAC is enabled for the general purpose bucket, you can use tags to manage access to the general purpose buckets as well as for cost tracking purposes. When ABAC is disabled for the general purpose buckets, you can only use tags for cost tracking purposes. For more information, see Using tags with S3 general purpose buckets.
Implementations
Sourceimpl PutBucketAbacInput
impl PutBucketAbacInput
Sourcepub fn content_md5(&self) -> Option<&str>
pub fn content_md5(&self) -> Option<&str>
The MD5 hash of the PutBucketAbac request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Sourcepub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
pub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The Amazon Web Services account ID of the general purpose bucket's owner.
Sourcepub fn abac_status(&self) -> Option<&AbacStatus>
pub fn abac_status(&self) -> Option<&AbacStatus>
The ABAC status of the general purpose bucket. When ABAC is enabled for the general purpose bucket, you can use tags to manage access to the general purpose buckets as well as for cost tracking purposes. When ABAC is disabled for the general purpose buckets, you can only use tags for cost tracking purposes. For more information, see Using tags with S3 general purpose buckets.
Sourceimpl PutBucketAbacInput
impl PutBucketAbacInput
Sourcepub fn builder() -> PutBucketAbacInputBuilder
pub fn builder() -> PutBucketAbacInputBuilder
Creates a new builder-style object to manufacture PutBucketAbacInput.