#[non_exhaustive]pub struct PutBucketAccelerateConfigurationInput {
pub bucket: Option<String>,
pub accelerate_configuration: Option<AccelerateConfiguration>,
pub expected_bucket_owner: Option<String>,
pub checksum_algorithm: Option<ChecksumAlgorithm>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the bucket for which the accelerate configuration is set.
accelerate_configuration: Option<AccelerateConfiguration>Container for setting the transfer acceleration state.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
checksum_algorithm: Option<ChecksumAlgorithm>Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Implementations
Sourceimpl PutBucketAccelerateConfigurationInput
impl PutBucketAccelerateConfigurationInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the bucket for which the accelerate configuration is set.
Sourcepub fn accelerate_configuration(&self) -> Option<&AccelerateConfiguration>
pub fn accelerate_configuration(&self) -> Option<&AccelerateConfiguration>
Container for setting the transfer acceleration state.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
pub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Sourceimpl PutBucketAccelerateConfigurationInput
impl PutBucketAccelerateConfigurationInput
Sourcepub fn builder() -> PutBucketAccelerateConfigurationInputBuilder
pub fn builder() -> PutBucketAccelerateConfigurationInputBuilder
Creates a new builder-style object to manufacture PutBucketAccelerateConfigurationInput.