#[non_exhaustive]pub struct PutBucketInventoryConfigurationInputBuilder { /* private fields */ }Expand description
A builder for PutBucketInventoryConfigurationInput.
Implementations
Sourceimpl PutBucketInventoryConfigurationInputBuilder
impl PutBucketInventoryConfigurationInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket where the inventory configuration will be stored.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket where the inventory configuration will be stored.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket where the inventory configuration will be stored.
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The ID used to identify the inventory configuration.
This field is required.Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
The ID used to identify the inventory configuration.
Sourcepub fn inventory_configuration(self, input: InventoryConfiguration) -> Self
pub fn inventory_configuration(self, input: InventoryConfiguration) -> Self
Specifies the inventory configuration.
This field is required.Sourcepub fn set_inventory_configuration(
self,
input: Option<InventoryConfiguration>,
) -> Self
pub fn set_inventory_configuration( self, input: Option<InventoryConfiguration>, ) -> Self
Specifies the inventory configuration.
Sourcepub fn get_inventory_configuration(&self) -> &Option<InventoryConfiguration>
pub fn get_inventory_configuration(&self) -> &Option<InventoryConfiguration>
Specifies the inventory configuration.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn build(self) -> Result<PutBucketInventoryConfigurationInput, BuildError>
pub fn build(self) -> Result<PutBucketInventoryConfigurationInput, BuildError>
Consumes the builder and constructs a PutBucketInventoryConfigurationInput.
Sourceimpl PutBucketInventoryConfigurationInputBuilder
impl PutBucketInventoryConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<PutBucketInventoryConfigurationOutput, SdkError<PutBucketInventoryConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<PutBucketInventoryConfigurationOutput, SdkError<PutBucketInventoryConfigurationError, HttpResponse>>
Sends a request with this input using the given client.