#[non_exhaustive]pub struct PutBucketOwnershipControlsInput {
pub bucket: Option<String>,
pub content_md5: Option<String>,
pub expected_bucket_owner: Option<String>,
pub ownership_controls: Option<OwnershipControls>,
pub checksum_algorithm: Option<ChecksumAlgorithm>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the Amazon S3 bucket whose OwnershipControls you want to set.
content_md5: Option<String>The MD5 hash of the OwnershipControls request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
ownership_controls: Option<OwnershipControls>The OwnershipControls (BucketOwnerEnforced, BucketOwnerPreferred, or ObjectWriter) that you want to apply to this Amazon S3 bucket.
checksum_algorithm: Option<ChecksumAlgorithm>Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum-algorithm header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Implementations
Sourceimpl PutBucketOwnershipControlsInput
impl PutBucketOwnershipControlsInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the Amazon S3 bucket whose OwnershipControls you want to set.
Sourcepub fn content_md5(&self) -> Option<&str>
pub fn content_md5(&self) -> Option<&str>
The MD5 hash of the OwnershipControls request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourcepub fn ownership_controls(&self) -> Option<&OwnershipControls>
pub fn ownership_controls(&self) -> Option<&OwnershipControls>
The OwnershipControls (BucketOwnerEnforced, BucketOwnerPreferred, or ObjectWriter) that you want to apply to this Amazon S3 bucket.
Sourcepub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
pub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum-algorithm header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Sourceimpl PutBucketOwnershipControlsInput
impl PutBucketOwnershipControlsInput
Sourcepub fn builder() -> PutBucketOwnershipControlsInputBuilder
pub fn builder() -> PutBucketOwnershipControlsInputBuilder
Creates a new builder-style object to manufacture PutBucketOwnershipControlsInput.