#[non_exhaustive]pub struct PutObjectLegalHoldOutputBuilder { /* private fields */ }Expand description
A builder for PutObjectLegalHoldOutput.
Implementations
Sourceimpl PutObjectLegalHoldOutputBuilder
impl PutObjectLegalHoldOutputBuilder
Sourcepub fn request_charged(self, input: RequestCharged) -> Self
pub fn request_charged(self, input: RequestCharged) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
pub fn set_request_charged(self, input: Option<RequestCharged>) -> Self
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn get_request_charged(&self) -> &Option<RequestCharged>
pub fn get_request_charged(&self) -> &Option<RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn build(self) -> PutObjectLegalHoldOutput
pub fn build(self) -> PutObjectLegalHoldOutput
Consumes the builder and constructs a PutObjectLegalHoldOutput.