#[non_exhaustive]pub struct PutPublicAccessBlockInput {
pub bucket: Option<String>,
pub content_md5: Option<String>,
pub checksum_algorithm: Option<ChecksumAlgorithm>,
pub public_access_block_configuration: Option<PublicAccessBlockConfiguration>,
pub expected_bucket_owner: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: Option<String>The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to set.
content_md5: Option<String>The MD5 hash of the PutPublicAccessBlock request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
checksum_algorithm: Option<ChecksumAlgorithm>Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
public_access_block_configuration: Option<PublicAccessBlockConfiguration>The PublicAccessBlock configuration that you want to apply to this Amazon S3 bucket. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see The Meaning of "Public" in the Amazon S3 User Guide.
expected_bucket_owner: Option<String>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Implementations
Sourceimpl PutPublicAccessBlockInput
impl PutPublicAccessBlockInput
Sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to set.
Sourcepub fn content_md5(&self) -> Option<&str>
pub fn content_md5(&self) -> Option<&str>
The MD5 hash of the PutPublicAccessBlock request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
Sourcepub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
pub fn checksum_algorithm(&self) -> Option<&ChecksumAlgorithm>
Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Sourcepub fn public_access_block_configuration(
&self,
) -> Option<&PublicAccessBlockConfiguration>
pub fn public_access_block_configuration( &self, ) -> Option<&PublicAccessBlockConfiguration>
The PublicAccessBlock configuration that you want to apply to this Amazon S3 bucket. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see The Meaning of "Public" in the Amazon S3 User Guide.
Sourcepub fn expected_bucket_owner(&self) -> Option<&str>
pub fn expected_bucket_owner(&self) -> Option<&str>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Sourceimpl PutPublicAccessBlockInput
impl PutPublicAccessBlockInput
Sourcepub fn builder() -> PutPublicAccessBlockInputBuilder
pub fn builder() -> PutPublicAccessBlockInputBuilder
Creates a new builder-style object to manufacture PutPublicAccessBlockInput.