Struct RenameObjectInputBuilder

#[non_exhaustive]
pub struct RenameObjectInputBuilder { /* private fields */ }
A builder for RenameObjectInput.

Implementations

Source

impl RenameObjectInputBuilder

pub fn bucket(self, input: impl Into<String>) -> Self

The bucket name of the directory bucket containing the object.

You must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Availability Zone. Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

This field is required.
pub fn set_bucket(self, input: Option<String>) -> Self

The bucket name of the directory bucket containing the object.

You must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Availability Zone. Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

pub fn get_bucket(&self) -> &Option<String>

The bucket name of the directory bucket containing the object.

You must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Availability Zone. Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

pub fn key(self, input: impl Into<String>) -> Self

Key name of the object to rename.

This field is required.
pub fn set_key(self, input: Option<String>) -> Self

Key name of the object to rename.

pub fn get_key(&self) -> &Option<String>

Key name of the object to rename.

pub fn rename_source(self, input: impl Into<String>) -> Self

Specifies the source for the rename operation. The value must be URL encoded.

This field is required.
pub fn set_rename_source(self, input: Option<String>) -> Self

Specifies the source for the rename operation. The value must be URL encoded.

pub fn get_rename_source(&self) -> &Option<String>

Specifies the source for the rename operation. The value must be URL encoded.

pub fn destination_if_match(self, input: impl Into<String>) -> Self

Renames the object only if the ETag (entity tag) value provided during the operation matches the ETag of the object in S3. The If-Match header field makes the request method conditional on ETags. If the ETag values do not match, the operation returns a 412 Precondition Failed error.

Expects the ETag value as a string.

pub fn set_destination_if_match(self, input: Option<String>) -> Self

Renames the object only if the ETag (entity tag) value provided during the operation matches the ETag of the object in S3. The If-Match header field makes the request method conditional on ETags. If the ETag values do not match, the operation returns a 412 Precondition Failed error.

Expects the ETag value as a string.

pub fn get_destination_if_match(&self) -> &Option<String>

Renames the object only if the ETag (entity tag) value provided during the operation matches the ETag of the object in S3. The If-Match header field makes the request method conditional on ETags. If the ETag values do not match, the operation returns a 412 Precondition Failed error.

Expects the ETag value as a string.

pub fn destination_if_none_match(self, input: impl Into<String>) -> Self

Renames the object only if the destination does not already exist in the specified directory bucket. If the object does exist when you send a request with If-None-Match:*, the S3 API will return a 412 Precondition Failed error, preventing an overwrite. The If-None-Match header prevents overwrites of existing data by validating that there's not an object with the same key name already in your directory bucket.

Expects the * character (asterisk).

pub fn set_destination_if_none_match(self, input: Option<String>) -> Self

Renames the object only if the destination does not already exist in the specified directory bucket. If the object does exist when you send a request with If-None-Match:*, the S3 API will return a 412 Precondition Failed error, preventing an overwrite. The If-None-Match header prevents overwrites of existing data by validating that there's not an object with the same key name already in your directory bucket.

Expects the * character (asterisk).

pub fn get_destination_if_none_match(&self) -> &Option<String>

Renames the object only if the destination does not already exist in the specified directory bucket. If the object does exist when you send a request with If-None-Match:*, the S3 API will return a 412 Precondition Failed error, preventing an overwrite. The If-None-Match header prevents overwrites of existing data by validating that there's not an object with the same key name already in your directory bucket.

Expects the * character (asterisk).

pub fn destination_if_modified_since(self, input: DateTime) -> Self

Renames the object if the destination exists and if it has been modified since the specified time.

pub fn set_destination_if_modified_since(self, input: Option<DateTime>) -> Self

Renames the object if the destination exists and if it has been modified since the specified time.

pub fn get_destination_if_modified_since(&self) -> &Option<DateTime>

Renames the object if the destination exists and if it has been modified since the specified time.

pub fn destination_if_unmodified_since(self, input: DateTime) -> Self

Renames the object if it hasn't been modified since the specified time.

pub fn set_destination_if_unmodified_since( self, input: Option<DateTime>, ) -> Self

Renames the object if it hasn't been modified since the specified time.

pub fn get_destination_if_unmodified_since(&self) -> &Option<DateTime>

Renames the object if it hasn't been modified since the specified time.

pub fn source_if_match(self, input: impl Into<String>) -> Self

Renames the object if the source exists and if its entity tag (ETag) matches the specified ETag.

pub fn set_source_if_match(self, input: Option<String>) -> Self

Renames the object if the source exists and if its entity tag (ETag) matches the specified ETag.

pub fn get_source_if_match(&self) -> &Option<String>

Renames the object if the source exists and if its entity tag (ETag) matches the specified ETag.

pub fn source_if_none_match(self, input: impl Into<String>) -> Self

Renames the object if the source exists and if its entity tag (ETag) is different than the specified ETag. If an asterisk (*) character is provided, the operation will fail and return a 412 Precondition Failed error.

pub fn set_source_if_none_match(self, input: Option<String>) -> Self

Renames the object if the source exists and if its entity tag (ETag) is different than the specified ETag. If an asterisk (*) character is provided, the operation will fail and return a 412 Precondition Failed error.

pub fn get_source_if_none_match(&self) -> &Option<String>

Renames the object if the source exists and if its entity tag (ETag) is different than the specified ETag. If an asterisk (*) character is provided, the operation will fail and return a 412 Precondition Failed error.

pub fn source_if_modified_since(self, input: DateTime) -> Self

Renames the object if the source exists and if it has been modified since the specified time.

pub fn set_source_if_modified_since(self, input: Option<DateTime>) -> Self

Renames the object if the source exists and if it has been modified since the specified time.

pub fn get_source_if_modified_since(&self) -> &Option<DateTime>

Renames the object if the source exists and if it has been modified since the specified time.

pub fn source_if_unmodified_since(self, input: DateTime) -> Self

Renames the object if the source exists and hasn't been modified since the specified time.

pub fn set_source_if_unmodified_since(self, input: Option<DateTime>) -> Self

Renames the object if the source exists and hasn't been modified since the specified time.

pub fn get_source_if_unmodified_since(&self) -> &Option<DateTime>

Renames the object if the source exists and hasn't been modified since the specified time.

pub fn client_token(self, input: impl Into<String>) -> Self

A unique string with a max of 64 ASCII characters in the ASCII range of 33 - 126.

RenameObject supports idempotency using a client token. To make an idempotent API request using RenameObject, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails and an IdempotentParameterMismatch error is returned.

pub fn set_client_token(self, input: Option<String>) -> Self

A unique string with a max of 64 ASCII characters in the ASCII range of 33 - 126.

RenameObject supports idempotency using a client token. To make an idempotent API request using RenameObject, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails and an IdempotentParameterMismatch error is returned.

pub fn get_client_token(&self) -> &Option<String>

A unique string with a max of 64 ASCII characters in the ASCII range of 33 - 126.

RenameObject supports idempotency using a client token. To make an idempotent API request using RenameObject, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails and an IdempotentParameterMismatch error is returned.

pub fn build(self) -> Result<RenameObjectInput, BuildError>

Consumes the builder and constructs a RenameObjectInput.

Source

impl RenameObjectInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<RenameObjectOutput, SdkError<RenameObjectError, HttpResponse>>

Sends a request with this input using the given client.