#[non_exhaustive]pub struct RestoreObjectOutput {
pub request_charged: Option<RequestCharged>,
pub restore_output_path: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
restore_output_path: Option<String>Indicates the path in the provided S3 output location where Select results will be restored to.
Implementations
Sourceimpl RestoreObjectOutput
impl RestoreObjectOutput
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourcepub fn restore_output_path(&self) -> Option<&str>
pub fn restore_output_path(&self) -> Option<&str>
Indicates the path in the provided S3 output location where Select results will be restored to.
Sourceimpl RestoreObjectOutput
impl RestoreObjectOutput
Sourcepub fn builder() -> RestoreObjectOutputBuilder
pub fn builder() -> RestoreObjectOutputBuilder
Creates a new builder-style object to manufacture RestoreObjectOutput.