#[non_exhaustive]pub struct UploadPartCopyOutput {
pub copy_source_version_id: Option<String>,
pub copy_part_result: Option<CopyPartResult>,
pub server_side_encryption: Option<ServerSideEncryption>,
pub sse_customer_algorithm: Option<String>,
pub sse_customer_key_md5: Option<String>,
pub ssekms_key_id: Option<String>,
pub bucket_key_enabled: Option<bool>,
pub request_charged: Option<RequestCharged>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.copy_source_version_id: Option<String>The version of the source object that was copied, if you have enabled versioning on the source bucket.
This functionality is not supported when the source object is in a directory bucket.
copy_part_result: Option<CopyPartResult>Container for all response elements.
server_side_encryption: Option<ServerSideEncryption>The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
When accessing data stored in Amazon FSx file systems using S3 access points, the only valid server side encryption option is aws:fsx.
sse_customer_algorithm: Option<String>If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that's used.
This functionality is not supported for directory buckets.
sse_customer_key_md5: Option<String>If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
This functionality is not supported for directory buckets.
ssekms_key_id: Option<String>If present, indicates the ID of the KMS key that was used for object encryption.
bucket_key_enabled: Option<bool>Indicates whether the multipart upload uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
request_charged: Option<RequestCharged>If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Implementations
Sourceimpl UploadPartCopyOutput
impl UploadPartCopyOutput
Sourcepub fn copy_source_version_id(&self) -> Option<&str>
pub fn copy_source_version_id(&self) -> Option<&str>
The version of the source object that was copied, if you have enabled versioning on the source bucket.
This functionality is not supported when the source object is in a directory bucket.
Sourcepub fn copy_part_result(&self) -> Option<&CopyPartResult>
pub fn copy_part_result(&self) -> Option<&CopyPartResult>
Container for all response elements.
Sourcepub fn server_side_encryption(&self) -> Option<&ServerSideEncryption>
pub fn server_side_encryption(&self) -> Option<&ServerSideEncryption>
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
When accessing data stored in Amazon FSx file systems using S3 access points, the only valid server side encryption option is aws:fsx.
Sourcepub fn sse_customer_algorithm(&self) -> Option<&str>
pub fn sse_customer_algorithm(&self) -> Option<&str>
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that's used.
This functionality is not supported for directory buckets.
Sourcepub fn sse_customer_key_md5(&self) -> Option<&str>
pub fn sse_customer_key_md5(&self) -> Option<&str>
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
This functionality is not supported for directory buckets.
Sourcepub fn ssekms_key_id(&self) -> Option<&str>
pub fn ssekms_key_id(&self) -> Option<&str>
If present, indicates the ID of the KMS key that was used for object encryption.
Sourcepub fn bucket_key_enabled(&self) -> Option<bool>
pub fn bucket_key_enabled(&self) -> Option<bool>
Indicates whether the multipart upload uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
Sourcepub fn request_charged(&self) -> Option<&RequestCharged>
pub fn request_charged(&self) -> Option<&RequestCharged>
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
This functionality is not supported for directory buckets.
Sourceimpl UploadPartCopyOutput
impl UploadPartCopyOutput
Sourcepub fn builder() -> UploadPartCopyOutputBuilder
pub fn builder() -> UploadPartCopyOutputBuilder
Creates a new builder-style object to manufacture UploadPartCopyOutput.