Struct PresignedRequest

#[non_exhaustive]
pub struct PresignedRequest { /* private fields */ }
Represents a presigned request. This only includes the HTTP request method, URI, and headers.

This struct has conversion convenience functions:

Implementations

Source

impl PresignedRequest

pub fn method(&self) -> &str

Returns the HTTP request method.

pub fn uri(&self) -> &str

Returns the HTTP request URI.

pub fn headers(&self) -> impl Iterator<Item = (&str, &str)>

Returns any HTTP headers that need to go along with the request, except for Host, which should be sent based on the endpoint in the URI by the HTTP client rather than added directly.

pub fn make_http_02x_request<B>(&self, body: B) -> Request<B>

👎Deprecated: Prefer the make_http_1x_request() instead by enabling the http-1x feature.

Given a body, produce an http::Request from this PresignedRequest

pub fn into_http_02x_request<B>(self, body: B) -> Request<B>

👎Deprecated: Prefer the into_http_1x_request instead by enabling the http-1x feature.

Converts this PresignedRequest directly into an http request.