Struct PresigningConfig

#[non_exhaustive]
pub struct PresigningConfig { /* private fields */ }
Presigning config values required for creating a presigned request.

Implementations

Source

impl PresigningConfig

pub fn expires_in( expires_in: Duration, ) -> Result<PresigningConfig, PresigningConfigError>

Creates a PresigningConfig with the given expires_in duration.

The expires_in duration is the total amount of time the presigned request should be valid for. Other config values are defaulted.

Credential expiration time takes priority over the expires_in value. If the credentials used to sign the request expire before the presigned request is set to expire, then the presigned request will become invalid.

pub fn builder() -> PresigningConfigBuilder

Creates a new builder for creating a PresigningConfig.

pub fn expires(&self) -> Duration

Returns the amount of time the presigned request should be valid for.

pub fn start_time(&self) -> SystemTime

Returns the start time. The presigned request will be valid between this and the end time produced by adding the expires() value to it.