#[non_exhaustive]pub struct AnalyticsS3BucketDestinationBuilder { /* private fields */ }Expand description
A builder for AnalyticsS3BucketDestination.
Implementations
Sourceimpl AnalyticsS3BucketDestinationBuilder
impl AnalyticsS3BucketDestinationBuilder
Sourcepub fn format(self, input: AnalyticsS3ExportFileFormat) -> Self
pub fn format(self, input: AnalyticsS3ExportFileFormat) -> Self
Specifies the file format used when exporting data to Amazon S3.
This field is required.Sourcepub fn set_format(self, input: Option<AnalyticsS3ExportFileFormat>) -> Self
pub fn set_format(self, input: Option<AnalyticsS3ExportFileFormat>) -> Self
Specifies the file format used when exporting data to Amazon S3.
Sourcepub fn get_format(&self) -> &Option<AnalyticsS3ExportFileFormat>
pub fn get_format(&self) -> &Option<AnalyticsS3ExportFileFormat>
Specifies the file format used when exporting data to Amazon S3.
Sourcepub fn bucket_account_id(self, input: impl Into<String>) -> Self
pub fn bucket_account_id(self, input: impl Into<String>) -> Self
The account ID that owns the destination S3 bucket. If no account ID is provided, the owner is not validated before exporting data.
Although this value is optional, we strongly recommend that you set it to help prevent problems if the destination bucket ownership changes.
Sourcepub fn set_bucket_account_id(self, input: Option<String>) -> Self
pub fn set_bucket_account_id(self, input: Option<String>) -> Self
The account ID that owns the destination S3 bucket. If no account ID is provided, the owner is not validated before exporting data.
Although this value is optional, we strongly recommend that you set it to help prevent problems if the destination bucket ownership changes.
Sourcepub fn get_bucket_account_id(&self) -> &Option<String>
pub fn get_bucket_account_id(&self) -> &Option<String>
The account ID that owns the destination S3 bucket. If no account ID is provided, the owner is not validated before exporting data.
Although this value is optional, we strongly recommend that you set it to help prevent problems if the destination bucket ownership changes.
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the bucket to which data is exported.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the bucket to which data is exported.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the bucket to which data is exported.
Sourcepub fn prefix(self, input: impl Into<String>) -> Self
pub fn prefix(self, input: impl Into<String>) -> Self
The prefix to use when exporting data. The prefix is prepended to all results.
Sourcepub fn set_prefix(self, input: Option<String>) -> Self
pub fn set_prefix(self, input: Option<String>) -> Self
The prefix to use when exporting data. The prefix is prepended to all results.
Sourcepub fn get_prefix(&self) -> &Option<String>
pub fn get_prefix(&self) -> &Option<String>
The prefix to use when exporting data. The prefix is prepended to all results.
Sourcepub fn build(self) -> Result<AnalyticsS3BucketDestination, BuildError>
pub fn build(self) -> Result<AnalyticsS3BucketDestination, BuildError>
Consumes the builder and constructs a AnalyticsS3BucketDestination.
This method will fail if any of the following fields are not set: