#[non_exhaustive]pub struct BucketBuilder { /* private fields */ }Expand description
A builder for Bucket.
Implementations
Sourceimpl BucketBuilder
impl BucketBuilder
Sourcepub fn creation_date(self, input: DateTime) -> Self
pub fn creation_date(self, input: DateTime) -> Self
Date the bucket was created. This date can change when making changes to your bucket, such as editing its bucket policy.
Sourcepub fn set_creation_date(self, input: Option<DateTime>) -> Self
pub fn set_creation_date(self, input: Option<DateTime>) -> Self
Date the bucket was created. This date can change when making changes to your bucket, such as editing its bucket policy.
Sourcepub fn get_creation_date(&self) -> &Option<DateTime>
pub fn get_creation_date(&self) -> &Option<DateTime>
Date the bucket was created. This date can change when making changes to your bucket, such as editing its bucket policy.
Sourcepub fn bucket_region(self, input: impl Into<String>) -> Self
pub fn bucket_region(self, input: impl Into<String>) -> Self
BucketRegion indicates the Amazon Web Services region where the bucket is located. If the request contains at least one valid parameter, it is included in the response.
Sourcepub fn set_bucket_region(self, input: Option<String>) -> Self
pub fn set_bucket_region(self, input: Option<String>) -> Self
BucketRegion indicates the Amazon Web Services region where the bucket is located. If the request contains at least one valid parameter, it is included in the response.
Sourcepub fn get_bucket_region(&self) -> &Option<String>
pub fn get_bucket_region(&self) -> &Option<String>
BucketRegion indicates the Amazon Web Services region where the bucket is located. If the request contains at least one valid parameter, it is included in the response.
Sourcepub fn bucket_arn(self, input: impl Into<String>) -> Self
pub fn bucket_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn set_bucket_arn(self, input: Option<String>) -> Self
pub fn set_bucket_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.
Sourcepub fn get_bucket_arn(&self) -> &Option<String>
pub fn get_bucket_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.