#[non_exhaustive]pub struct CopyPartResultBuilder { /* private fields */ }Expand description
A builder for CopyPartResult.
Implementations
Sourceimpl CopyPartResultBuilder
impl CopyPartResultBuilder
Sourcepub fn last_modified(self, input: DateTime) -> Self
pub fn last_modified(self, input: DateTime) -> Self
Date and time at which the object was uploaded.
Sourcepub fn set_last_modified(self, input: Option<DateTime>) -> Self
pub fn set_last_modified(self, input: Option<DateTime>) -> Self
Date and time at which the object was uploaded.
Sourcepub fn get_last_modified(&self) -> &Option<DateTime>
pub fn get_last_modified(&self) -> &Option<DateTime>
Date and time at which the object was uploaded.
Sourcepub fn checksum_crc32(self, input: impl Into<String>) -> Self
pub fn checksum_crc32(self, input: impl Into<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_crc32(self, input: Option<String>) -> Self
pub fn set_checksum_crc32(self, input: Option<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_crc32(&self) -> &Option<String>
pub fn get_checksum_crc32(&self) -> &Option<String>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
pub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32C checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
pub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32C checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_crc32_c(&self) -> &Option<String>
pub fn get_checksum_crc32_c(&self) -> &Option<String>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32C checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
pub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
pub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_crc64_nvme(&self) -> &Option<String>
pub fn get_checksum_crc64_nvme(&self) -> &Option<String>
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha1(self, input: impl Into<String>) -> Self
pub fn checksum_sha1(self, input: impl Into<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA1 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_sha1(self, input: Option<String>) -> Self
pub fn set_checksum_sha1(self, input: Option<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA1 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_sha1(&self) -> &Option<String>
pub fn get_checksum_sha1(&self) -> &Option<String>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA1 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha256(self, input: impl Into<String>) -> Self
pub fn checksum_sha256(self, input: impl Into<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA256 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_sha256(self, input: Option<String>) -> Self
pub fn set_checksum_sha256(self, input: Option<String>) -> Self
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA256 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_sha256(&self) -> &Option<String>
pub fn get_checksum_sha256(&self) -> &Option<String>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA256 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn build(self) -> CopyPartResult
pub fn build(self) -> CopyPartResult
Consumes the builder and constructs a CopyPartResult.