#[non_exhaustive]pub struct CsvInputBuilder { /* private fields */ }Expand description
A builder for CsvInput.
Implementations
Sourceimpl CsvInputBuilder
impl CsvInputBuilder
Sourcepub fn file_header_info(self, input: FileHeaderInfo) -> Self
pub fn file_header_info(self, input: FileHeaderInfo) -> Self
Describes the first line of input. Valid values are:
-
NONE: First line is not a header. -
IGNORE: First line is a header, but you can't use the header values to indicate the column in an expression. You can use column position (such as _1, _2, …) to indicate the column (SELECT s._1 FROM OBJECT s). -
Use: First line is a header, and you can use the header value to identify a column in an expression (SELECT "name" FROM OBJECT).
Sourcepub fn set_file_header_info(self, input: Option<FileHeaderInfo>) -> Self
pub fn set_file_header_info(self, input: Option<FileHeaderInfo>) -> Self
Describes the first line of input. Valid values are:
-
NONE: First line is not a header. -
IGNORE: First line is a header, but you can't use the header values to indicate the column in an expression. You can use column position (such as _1, _2, …) to indicate the column (SELECT s._1 FROM OBJECT s). -
Use: First line is a header, and you can use the header value to identify a column in an expression (SELECT "name" FROM OBJECT).
Sourcepub fn get_file_header_info(&self) -> &Option<FileHeaderInfo>
pub fn get_file_header_info(&self) -> &Option<FileHeaderInfo>
Describes the first line of input. Valid values are:
-
NONE: First line is not a header. -
IGNORE: First line is a header, but you can't use the header values to indicate the column in an expression. You can use column position (such as _1, _2, …) to indicate the column (SELECT s._1 FROM OBJECT s). -
Use: First line is a header, and you can use the header value to identify a column in an expression (SELECT "name" FROM OBJECT).
Sourcepub fn comments(self, input: impl Into<String>) -> Self
pub fn comments(self, input: impl Into<String>) -> Self
A single character used to indicate that a row should be ignored when the character is present at the start of that row. You can specify any character to indicate a comment line. The default character is #.
Default: #
Sourcepub fn set_comments(self, input: Option<String>) -> Self
pub fn set_comments(self, input: Option<String>) -> Self
A single character used to indicate that a row should be ignored when the character is present at the start of that row. You can specify any character to indicate a comment line. The default character is #.
Default: #
Sourcepub fn get_comments(&self) -> &Option<String>
pub fn get_comments(&self) -> &Option<String>
A single character used to indicate that a row should be ignored when the character is present at the start of that row. You can specify any character to indicate a comment line. The default character is #.
Default: #
Sourcepub fn quote_escape_character(self, input: impl Into<String>) -> Self
pub fn quote_escape_character(self, input: impl Into<String>) -> Self
A single character used for escaping the quotation mark character inside an already escaped value. For example, the value """ a , b """ is parsed as " a , b ".
Sourcepub fn set_quote_escape_character(self, input: Option<String>) -> Self
pub fn set_quote_escape_character(self, input: Option<String>) -> Self
A single character used for escaping the quotation mark character inside an already escaped value. For example, the value """ a , b """ is parsed as " a , b ".
Sourcepub fn get_quote_escape_character(&self) -> &Option<String>
pub fn get_quote_escape_character(&self) -> &Option<String>
A single character used for escaping the quotation mark character inside an already escaped value. For example, the value """ a , b """ is parsed as " a , b ".
Sourcepub fn record_delimiter(self, input: impl Into<String>) -> Self
pub fn record_delimiter(self, input: impl Into<String>) -> Self
A single character used to separate individual records in the input. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn set_record_delimiter(self, input: Option<String>) -> Self
pub fn set_record_delimiter(self, input: Option<String>) -> Self
A single character used to separate individual records in the input. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn get_record_delimiter(&self) -> &Option<String>
pub fn get_record_delimiter(&self) -> &Option<String>
A single character used to separate individual records in the input. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn field_delimiter(self, input: impl Into<String>) -> Self
pub fn field_delimiter(self, input: impl Into<String>) -> Self
A single character used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn set_field_delimiter(self, input: Option<String>) -> Self
pub fn set_field_delimiter(self, input: Option<String>) -> Self
A single character used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn get_field_delimiter(&self) -> &Option<String>
pub fn get_field_delimiter(&self) -> &Option<String>
A single character used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn quote_character(self, input: impl Into<String>) -> Self
pub fn quote_character(self, input: impl Into<String>) -> Self
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Type: String
Default: "
Ancestors: CSV
Sourcepub fn set_quote_character(self, input: Option<String>) -> Self
pub fn set_quote_character(self, input: Option<String>) -> Self
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Type: String
Default: "
Ancestors: CSV
Sourcepub fn get_quote_character(&self) -> &Option<String>
pub fn get_quote_character(&self) -> &Option<String>
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Type: String
Default: "
Ancestors: CSV
Sourcepub fn allow_quoted_record_delimiter(self, input: bool) -> Self
pub fn allow_quoted_record_delimiter(self, input: bool) -> Self
Specifies that CSV field values may contain quoted record delimiters and such records should be allowed. Default value is FALSE. Setting this value to TRUE may lower performance.
Sourcepub fn set_allow_quoted_record_delimiter(self, input: Option<bool>) -> Self
pub fn set_allow_quoted_record_delimiter(self, input: Option<bool>) -> Self
Specifies that CSV field values may contain quoted record delimiters and such records should be allowed. Default value is FALSE. Setting this value to TRUE may lower performance.
Sourcepub fn get_allow_quoted_record_delimiter(&self) -> &Option<bool>
pub fn get_allow_quoted_record_delimiter(&self) -> &Option<bool>
Specifies that CSV field values may contain quoted record delimiters and such records should be allowed. Default value is FALSE. Setting this value to TRUE may lower performance.