#[non_exhaustive]pub struct CsvOutputBuilder { /* private fields */ }Expand description
A builder for CsvOutput.
Implementations
Sourceimpl CsvOutputBuilder
impl CsvOutputBuilder
Sourcepub fn quote_fields(self, input: QuoteFields) -> Self
pub fn quote_fields(self, input: QuoteFields) -> Self
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
Sourcepub fn set_quote_fields(self, input: Option<QuoteFields>) -> Self
pub fn set_quote_fields(self, input: Option<QuoteFields>) -> Self
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
Sourcepub fn get_quote_fields(&self) -> &Option<QuoteFields>
pub fn get_quote_fields(&self) -> &Option<QuoteFields>
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
Sourcepub fn quote_escape_character(self, input: impl Into<String>) -> Self
pub fn quote_escape_character(self, input: impl Into<String>) -> Self
The single character used for escaping the quote character inside an already escaped value.
Sourcepub fn set_quote_escape_character(self, input: Option<String>) -> Self
pub fn set_quote_escape_character(self, input: Option<String>) -> Self
The single character used for escaping the quote character inside an already escaped value.
Sourcepub fn get_quote_escape_character(&self) -> &Option<String>
pub fn get_quote_escape_character(&self) -> &Option<String>
The single character used for escaping the quote character inside an already escaped value.
Sourcepub fn record_delimiter(self, input: impl Into<String>) -> Self
pub fn record_delimiter(self, input: impl Into<String>) -> Self
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn set_record_delimiter(self, input: Option<String>) -> Self
pub fn set_record_delimiter(self, input: Option<String>) -> Self
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn get_record_delimiter(&self) -> &Option<String>
pub fn get_record_delimiter(&self) -> &Option<String>
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn field_delimiter(self, input: impl Into<String>) -> Self
pub fn field_delimiter(self, input: impl Into<String>) -> Self
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn set_field_delimiter(self, input: Option<String>) -> Self
pub fn set_field_delimiter(self, input: Option<String>) -> Self
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn get_field_delimiter(&self) -> &Option<String>
pub fn get_field_delimiter(&self) -> &Option<String>
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn quote_character(self, input: impl Into<String>) -> Self
pub fn quote_character(self, input: impl Into<String>) -> Self
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Sourcepub fn set_quote_character(self, input: Option<String>) -> Self
pub fn set_quote_character(self, input: Option<String>) -> Self
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Sourcepub fn get_quote_character(&self) -> &Option<String>
pub fn get_quote_character(&self) -> &Option<String>
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".