#[non_exhaustive]pub struct DeleteBuilder { /* private fields */ }Expand description
A builder for Delete.
Implementations
Sourceimpl DeleteBuilder
impl DeleteBuilder
Sourcepub fn objects(self, input: ObjectIdentifier) -> Self
pub fn objects(self, input: ObjectIdentifier) -> Self
Appends an item to objects.
To override the contents of this collection use set_objects.
The object to delete.
Directory buckets - For directory buckets, an object that's composed entirely of whitespace characters is not supported by the DeleteObjects API operation. The request will receive a 400 Bad Request error and none of the objects in the request will be deleted.
Sourcepub fn set_objects(self, input: Option<Vec<ObjectIdentifier>>) -> Self
pub fn set_objects(self, input: Option<Vec<ObjectIdentifier>>) -> Self
The object to delete.
Directory buckets - For directory buckets, an object that's composed entirely of whitespace characters is not supported by the DeleteObjects API operation. The request will receive a 400 Bad Request error and none of the objects in the request will be deleted.
Sourcepub fn get_objects(&self) -> &Option<Vec<ObjectIdentifier>>
pub fn get_objects(&self) -> &Option<Vec<ObjectIdentifier>>
The object to delete.
Directory buckets - For directory buckets, an object that's composed entirely of whitespace characters is not supported by the DeleteObjects API operation. The request will receive a 400 Bad Request error and none of the objects in the request will be deleted.
Sourcepub fn quiet(self, input: bool) -> Self
pub fn quiet(self, input: bool) -> Self
Element to enable quiet mode for the request. When you add this element, you must set its value to true.
Sourcepub fn set_quiet(self, input: Option<bool>) -> Self
pub fn set_quiet(self, input: Option<bool>) -> Self
Element to enable quiet mode for the request. When you add this element, you must set its value to true.