#[non_exhaustive]pub struct DestinationBuilder { /* private fields */ }Expand description
A builder for Destination.
Implementations
Sourceimpl DestinationBuilder
impl DestinationBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
Sourcepub fn account(self, input: impl Into<String>) -> Self
pub fn account(self, input: impl Into<String>) -> Self
Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to change replica ownership to the Amazon Web Services account that owns the destination bucket by specifying the AccessControlTranslation property, this is the account ID of the destination bucket owner. For more information, see Replication Additional Configuration: Changing the Replica Owner in the Amazon S3 User Guide.
Sourcepub fn set_account(self, input: Option<String>) -> Self
pub fn set_account(self, input: Option<String>) -> Self
Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to change replica ownership to the Amazon Web Services account that owns the destination bucket by specifying the AccessControlTranslation property, this is the account ID of the destination bucket owner. For more information, see Replication Additional Configuration: Changing the Replica Owner in the Amazon S3 User Guide.
Sourcepub fn get_account(&self) -> &Option<String>
pub fn get_account(&self) -> &Option<String>
Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to change replica ownership to the Amazon Web Services account that owns the destination bucket by specifying the AccessControlTranslation property, this is the account ID of the destination bucket owner. For more information, see Replication Additional Configuration: Changing the Replica Owner in the Amazon S3 User Guide.
Sourcepub fn storage_class(self, input: StorageClass) -> Self
pub fn storage_class(self, input: StorageClass) -> Self
The storage class to use when replicating objects, such as S3 Standard or reduced redundancy. By default, Amazon S3 uses the storage class of the source object to create the object replica.
For valid values, see the StorageClass element of the PUT Bucket replication action in the Amazon S3 API Reference.
FSX_OPENZFS is not an accepted value when replicating objects.
Sourcepub fn set_storage_class(self, input: Option<StorageClass>) -> Self
pub fn set_storage_class(self, input: Option<StorageClass>) -> Self
The storage class to use when replicating objects, such as S3 Standard or reduced redundancy. By default, Amazon S3 uses the storage class of the source object to create the object replica.
For valid values, see the StorageClass element of the PUT Bucket replication action in the Amazon S3 API Reference.
FSX_OPENZFS is not an accepted value when replicating objects.
Sourcepub fn get_storage_class(&self) -> &Option<StorageClass>
pub fn get_storage_class(&self) -> &Option<StorageClass>
The storage class to use when replicating objects, such as S3 Standard or reduced redundancy. By default, Amazon S3 uses the storage class of the source object to create the object replica.
For valid values, see the StorageClass element of the PUT Bucket replication action in the Amazon S3 API Reference.
FSX_OPENZFS is not an accepted value when replicating objects.
Sourcepub fn access_control_translation(self, input: AccessControlTranslation) -> Self
pub fn access_control_translation(self, input: AccessControlTranslation) -> Self
Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the Amazon Web Services account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same Amazon Web Services account that owns the source object.
Sourcepub fn set_access_control_translation(
self,
input: Option<AccessControlTranslation>,
) -> Self
pub fn set_access_control_translation( self, input: Option<AccessControlTranslation>, ) -> Self
Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the Amazon Web Services account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same Amazon Web Services account that owns the source object.
Sourcepub fn get_access_control_translation(
&self,
) -> &Option<AccessControlTranslation>
pub fn get_access_control_translation( &self, ) -> &Option<AccessControlTranslation>
Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the Amazon Web Services account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same Amazon Web Services account that owns the source object.
Sourcepub fn encryption_configuration(self, input: EncryptionConfiguration) -> Self
pub fn encryption_configuration(self, input: EncryptionConfiguration) -> Self
A container that provides information about encryption. If SourceSelectionCriteria is specified, you must specify this element.
Sourcepub fn set_encryption_configuration(
self,
input: Option<EncryptionConfiguration>,
) -> Self
pub fn set_encryption_configuration( self, input: Option<EncryptionConfiguration>, ) -> Self
A container that provides information about encryption. If SourceSelectionCriteria is specified, you must specify this element.
Sourcepub fn get_encryption_configuration(&self) -> &Option<EncryptionConfiguration>
pub fn get_encryption_configuration(&self) -> &Option<EncryptionConfiguration>
A container that provides information about encryption. If SourceSelectionCriteria is specified, you must specify this element.
Sourcepub fn replication_time(self, input: ReplicationTime) -> Self
pub fn replication_time(self, input: ReplicationTime) -> Self
A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a Metrics block.
Sourcepub fn set_replication_time(self, input: Option<ReplicationTime>) -> Self
pub fn set_replication_time(self, input: Option<ReplicationTime>) -> Self
A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a Metrics block.
Sourcepub fn get_replication_time(&self) -> &Option<ReplicationTime>
pub fn get_replication_time(&self) -> &Option<ReplicationTime>
A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a Metrics block.
Sourcepub fn metrics(self, input: Metrics) -> Self
pub fn metrics(self, input: Metrics) -> Self
A container specifying replication metrics-related settings enabling replication metrics and events.
Sourcepub fn set_metrics(self, input: Option<Metrics>) -> Self
pub fn set_metrics(self, input: Option<Metrics>) -> Self
A container specifying replication metrics-related settings enabling replication metrics and events.
Sourcepub fn get_metrics(&self) -> &Option<Metrics>
pub fn get_metrics(&self) -> &Option<Metrics>
A container specifying replication metrics-related settings enabling replication metrics and events.
Sourcepub fn build(self) -> Result<Destination, BuildError>
pub fn build(self) -> Result<Destination, BuildError>
Consumes the builder and constructs a Destination.
This method will fail if any of the following fields are not set: