#[non_exhaustive]pub struct DestinationResultBuilder { /* private fields */ }Expand description
A builder for DestinationResult.
Implementations
Sourceimpl DestinationResultBuilder
impl DestinationResultBuilder
Sourcepub fn table_bucket_type(self, input: S3TablesBucketType) -> Self
pub fn table_bucket_type(self, input: S3TablesBucketType) -> Self
The type of the table bucket where the metadata configuration is stored. The aws value indicates an Amazon Web Services managed table bucket, and the customer value indicates a customer-managed table bucket. V2 metadata configurations are stored in Amazon Web Services managed table buckets, and V1 metadata configurations are stored in customer-managed table buckets.
Sourcepub fn set_table_bucket_type(self, input: Option<S3TablesBucketType>) -> Self
pub fn set_table_bucket_type(self, input: Option<S3TablesBucketType>) -> Self
The type of the table bucket where the metadata configuration is stored. The aws value indicates an Amazon Web Services managed table bucket, and the customer value indicates a customer-managed table bucket. V2 metadata configurations are stored in Amazon Web Services managed table buckets, and V1 metadata configurations are stored in customer-managed table buckets.
Sourcepub fn get_table_bucket_type(&self) -> &Option<S3TablesBucketType>
pub fn get_table_bucket_type(&self) -> &Option<S3TablesBucketType>
The type of the table bucket where the metadata configuration is stored. The aws value indicates an Amazon Web Services managed table bucket, and the customer value indicates a customer-managed table bucket. V2 metadata configurations are stored in Amazon Web Services managed table buckets, and V1 metadata configurations are stored in customer-managed table buckets.
Sourcepub fn table_bucket_arn(self, input: impl Into<String>) -> Self
pub fn table_bucket_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the table bucket where the metadata configuration is stored.
Sourcepub fn set_table_bucket_arn(self, input: Option<String>) -> Self
pub fn set_table_bucket_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the table bucket where the metadata configuration is stored.
Sourcepub fn get_table_bucket_arn(&self) -> &Option<String>
pub fn get_table_bucket_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the table bucket where the metadata configuration is stored.
Sourcepub fn table_namespace(self, input: impl Into<String>) -> Self
pub fn table_namespace(self, input: impl Into<String>) -> Self
The namespace in the table bucket where the metadata tables for a metadata configuration are stored.
Sourcepub fn set_table_namespace(self, input: Option<String>) -> Self
pub fn set_table_namespace(self, input: Option<String>) -> Self
The namespace in the table bucket where the metadata tables for a metadata configuration are stored.
Sourcepub fn get_table_namespace(&self) -> &Option<String>
pub fn get_table_namespace(&self) -> &Option<String>
The namespace in the table bucket where the metadata tables for a metadata configuration are stored.
Sourcepub fn build(self) -> DestinationResult
pub fn build(self) -> DestinationResult
Consumes the builder and constructs a DestinationResult.