#[non_exhaustive]pub struct EncryptionBuilder { /* private fields */ }Expand description
A builder for Encryption.
Implementations
Sourceimpl EncryptionBuilder
impl EncryptionBuilder
Sourcepub fn encryption_type(self, input: ServerSideEncryption) -> Self
pub fn encryption_type(self, input: ServerSideEncryption) -> Self
The server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256, aws:kms).
Sourcepub fn set_encryption_type(self, input: Option<ServerSideEncryption>) -> Self
pub fn set_encryption_type(self, input: Option<ServerSideEncryption>) -> Self
The server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256, aws:kms).
Sourcepub fn get_encryption_type(&self) -> &Option<ServerSideEncryption>
pub fn get_encryption_type(&self) -> &Option<ServerSideEncryption>
The server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256, aws:kms).
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
If the encryption type is aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
If the encryption type is aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
If the encryption type is aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn kms_context(self, input: impl Into<String>) -> Self
pub fn kms_context(self, input: impl Into<String>) -> Self
If the encryption type is aws:kms, this optional value can be used to specify the encryption context for the restore results.
Sourcepub fn set_kms_context(self, input: Option<String>) -> Self
pub fn set_kms_context(self, input: Option<String>) -> Self
If the encryption type is aws:kms, this optional value can be used to specify the encryption context for the restore results.
Sourcepub fn get_kms_context(&self) -> &Option<String>
pub fn get_kms_context(&self) -> &Option<String>
If the encryption type is aws:kms, this optional value can be used to specify the encryption context for the restore results.
Sourcepub fn build(self) -> Result<Encryption, BuildError>
pub fn build(self) -> Result<Encryption, BuildError>
Consumes the builder and constructs a Encryption.
This method will fail if any of the following fields are not set: