#[non_exhaustive]pub struct EncryptionConfigurationBuilder { /* private fields */ }Expand description
A builder for EncryptionConfiguration.
Implementations
Sourceimpl EncryptionConfigurationBuilder
impl EncryptionConfigurationBuilder
Sourcepub fn replica_kms_key_id(self, input: impl Into<String>) -> Self
pub fn replica_kms_key_id(self, input: impl Into<String>) -> Self
Specifies the ID (Key ARN or Alias ARN) of the customer managed Amazon Web Services KMS key stored in Amazon Web Services Key Management Service (KMS) for the destination bucket. Amazon S3 uses this key to encrypt replica objects. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in Amazon Web Services KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn set_replica_kms_key_id(self, input: Option<String>) -> Self
pub fn set_replica_kms_key_id(self, input: Option<String>) -> Self
Specifies the ID (Key ARN or Alias ARN) of the customer managed Amazon Web Services KMS key stored in Amazon Web Services Key Management Service (KMS) for the destination bucket. Amazon S3 uses this key to encrypt replica objects. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in Amazon Web Services KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn get_replica_kms_key_id(&self) -> &Option<String>
pub fn get_replica_kms_key_id(&self) -> &Option<String>
Specifies the ID (Key ARN or Alias ARN) of the customer managed Amazon Web Services KMS key stored in Amazon Web Services Key Management Service (KMS) for the destination bucket. Amazon S3 uses this key to encrypt replica objects. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in Amazon Web Services KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn build(self) -> EncryptionConfiguration
pub fn build(self) -> EncryptionConfiguration
Consumes the builder and constructs a EncryptionConfiguration.