#[non_exhaustive]pub struct GetBucketMetadataTableConfigurationResultBuilder { /* private fields */ }Expand description
A builder for GetBucketMetadataTableConfigurationResult.
Implementations
Sourceimpl GetBucketMetadataTableConfigurationResultBuilder
impl GetBucketMetadataTableConfigurationResultBuilder
Sourcepub fn metadata_table_configuration_result(
self,
input: MetadataTableConfigurationResult,
) -> Self
pub fn metadata_table_configuration_result( self, input: MetadataTableConfigurationResult, ) -> Self
The V1 S3 Metadata configuration for a general purpose bucket.
This field is required.Sourcepub fn set_metadata_table_configuration_result(
self,
input: Option<MetadataTableConfigurationResult>,
) -> Self
pub fn set_metadata_table_configuration_result( self, input: Option<MetadataTableConfigurationResult>, ) -> Self
The V1 S3 Metadata configuration for a general purpose bucket.
Sourcepub fn get_metadata_table_configuration_result(
&self,
) -> &Option<MetadataTableConfigurationResult>
pub fn get_metadata_table_configuration_result( &self, ) -> &Option<MetadataTableConfigurationResult>
The V1 S3 Metadata configuration for a general purpose bucket.
Sourcepub fn status(self, input: impl Into<String>) -> Self
pub fn status(self, input: impl Into<String>) -> Self
The status of the metadata table. The status values are:
-
CREATING- The metadata table is in the process of being created in the specified table bucket. -
ACTIVE- The metadata table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the metadata table, or Amazon S3 is unable to deliver records. SeeErrorDetailsfor details.
Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The status of the metadata table. The status values are:
-
CREATING- The metadata table is in the process of being created in the specified table bucket. -
ACTIVE- The metadata table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the metadata table, or Amazon S3 is unable to deliver records. SeeErrorDetailsfor details.
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The status of the metadata table. The status values are:
-
CREATING- The metadata table is in the process of being created in the specified table bucket. -
ACTIVE- The metadata table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the metadata table, or Amazon S3 is unable to deliver records. SeeErrorDetailsfor details.
Sourcepub fn error(self, input: ErrorDetails) -> Self
pub fn error(self, input: ErrorDetails) -> Self
If the CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
Sourcepub fn set_error(self, input: Option<ErrorDetails>) -> Self
pub fn set_error(self, input: Option<ErrorDetails>) -> Self
If the CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
Sourcepub fn get_error(&self) -> &Option<ErrorDetails>
pub fn get_error(&self) -> &Option<ErrorDetails>
If the CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
Sourcepub fn build(
self,
) -> Result<GetBucketMetadataTableConfigurationResult, BuildError>
pub fn build( self, ) -> Result<GetBucketMetadataTableConfigurationResult, BuildError>
Consumes the builder and constructs a GetBucketMetadataTableConfigurationResult.
This method will fail if any of the following fields are not set: