#[non_exhaustive]pub struct IndexDocumentBuilder { /* private fields */ }Expand description
A builder for IndexDocument.
Implementations
Sourceimpl IndexDocumentBuilder
impl IndexDocumentBuilder
Sourcepub fn suffix(self, input: impl Into<String>) -> Self
pub fn suffix(self, input: impl Into<String>) -> Self
A suffix that is appended to a request that is for a directory on the website endpoint. (For example, if the suffix is index.html and you make a request to samplebucket/images/, the data that is returned will be for the object with the key name images/index.html.) The suffix must not be empty and must not include a slash character.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourcepub fn set_suffix(self, input: Option<String>) -> Self
pub fn set_suffix(self, input: Option<String>) -> Self
A suffix that is appended to a request that is for a directory on the website endpoint. (For example, if the suffix is index.html and you make a request to samplebucket/images/, the data that is returned will be for the object with the key name images/index.html.) The suffix must not be empty and must not include a slash character.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourcepub fn get_suffix(&self) -> &Option<String>
pub fn get_suffix(&self) -> &Option<String>
A suffix that is appended to a request that is for a directory on the website endpoint. (For example, if the suffix is index.html and you make a request to samplebucket/images/, the data that is returned will be for the object with the key name images/index.html.) The suffix must not be empty and must not include a slash character.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourcepub fn build(self) -> Result<IndexDocument, BuildError>
pub fn build(self) -> Result<IndexDocument, BuildError>
Consumes the builder and constructs a IndexDocument.
This method will fail if any of the following fields are not set: