#[non_exhaustive]pub struct JournalTableConfigurationResultBuilder { /* private fields */ }Expand description
A builder for JournalTableConfigurationResult.
Implementations
Sourceimpl JournalTableConfigurationResultBuilder
impl JournalTableConfigurationResultBuilder
Sourcepub fn table_status(self, input: impl Into<String>) -> Self
pub fn table_status(self, input: impl Into<String>) -> Self
The status of the journal table. The status values are:
-
CREATING- The journal table is in the process of being created in the specified table bucket. -
ACTIVE- The journal table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the journal table, or Amazon S3 is unable to deliver records.
Sourcepub fn set_table_status(self, input: Option<String>) -> Self
pub fn set_table_status(self, input: Option<String>) -> Self
The status of the journal table. The status values are:
-
CREATING- The journal table is in the process of being created in the specified table bucket. -
ACTIVE- The journal table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the journal table, or Amazon S3 is unable to deliver records.
Sourcepub fn get_table_status(&self) -> &Option<String>
pub fn get_table_status(&self) -> &Option<String>
The status of the journal table. The status values are:
-
CREATING- The journal table is in the process of being created in the specified table bucket. -
ACTIVE- The journal table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the journal table, or Amazon S3 is unable to deliver records.
Sourcepub fn error(self, input: ErrorDetails) -> Self
pub fn error(self, input: ErrorDetails) -> Self
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn set_error(self, input: Option<ErrorDetails>) -> Self
pub fn set_error(self, input: Option<ErrorDetails>) -> Self
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn get_error(&self) -> &Option<ErrorDetails>
pub fn get_error(&self) -> &Option<ErrorDetails>
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the journal table.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the journal table.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the journal table.
Sourcepub fn table_arn(self, input: impl Into<String>) -> Self
pub fn table_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) for the journal table.
Sourcepub fn set_table_arn(self, input: Option<String>) -> Self
pub fn set_table_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) for the journal table.
Sourcepub fn get_table_arn(&self) -> &Option<String>
pub fn get_table_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) for the journal table.
Sourcepub fn record_expiration(self, input: RecordExpiration) -> Self
pub fn record_expiration(self, input: RecordExpiration) -> Self
The journal table record expiration settings for the journal table.
This field is required.Sourcepub fn set_record_expiration(self, input: Option<RecordExpiration>) -> Self
pub fn set_record_expiration(self, input: Option<RecordExpiration>) -> Self
The journal table record expiration settings for the journal table.
Sourcepub fn get_record_expiration(&self) -> &Option<RecordExpiration>
pub fn get_record_expiration(&self) -> &Option<RecordExpiration>
The journal table record expiration settings for the journal table.
Sourcepub fn build(self) -> Result<JournalTableConfigurationResult, BuildError>
pub fn build(self) -> Result<JournalTableConfigurationResult, BuildError>
Consumes the builder and constructs a JournalTableConfigurationResult.
This method will fail if any of the following fields are not set: