#[non_exhaustive]pub struct JsonOutputBuilder { /* private fields */ }Expand description
A builder for JsonOutput.
Implementations
Sourceimpl JsonOutputBuilder
impl JsonOutputBuilder
Sourcepub fn record_delimiter(self, input: impl Into<String>) -> Self
pub fn record_delimiter(self, input: impl Into<String>) -> Self
The value used to separate individual records in the output. If no value is specified, Amazon S3 uses a newline character ('\n').
Sourcepub fn set_record_delimiter(self, input: Option<String>) -> Self
pub fn set_record_delimiter(self, input: Option<String>) -> Self
The value used to separate individual records in the output. If no value is specified, Amazon S3 uses a newline character ('\n').
Sourcepub fn get_record_delimiter(&self) -> &Option<String>
pub fn get_record_delimiter(&self) -> &Option<String>
The value used to separate individual records in the output. If no value is specified, Amazon S3 uses a newline character ('\n').
Sourcepub fn build(self) -> JsonOutput
pub fn build(self) -> JsonOutput
Consumes the builder and constructs a JsonOutput.