#[non_exhaustive]pub struct LifecycleExpirationBuilder { /* private fields */ }Expand description
A builder for LifecycleExpiration.
Implementations
Sourceimpl LifecycleExpirationBuilder
impl LifecycleExpirationBuilder
Sourcepub fn date(self, input: DateTime) -> Self
pub fn date(self, input: DateTime) -> Self
Indicates at what date the object is to be moved or deleted. The date value must conform to the ISO 8601 format. The time is always midnight UTC.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn set_date(self, input: Option<DateTime>) -> Self
pub fn set_date(self, input: Option<DateTime>) -> Self
Indicates at what date the object is to be moved or deleted. The date value must conform to the ISO 8601 format. The time is always midnight UTC.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn get_date(&self) -> &Option<DateTime>
pub fn get_date(&self) -> &Option<DateTime>
Indicates at what date the object is to be moved or deleted. The date value must conform to the ISO 8601 format. The time is always midnight UTC.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn days(self, input: i32) -> Self
pub fn days(self, input: i32) -> Self
Indicates the lifetime, in days, of the objects that are subject to the rule. The value must be a non-zero positive integer.
Sourcepub fn set_days(self, input: Option<i32>) -> Self
pub fn set_days(self, input: Option<i32>) -> Self
Indicates the lifetime, in days, of the objects that are subject to the rule. The value must be a non-zero positive integer.
Sourcepub fn get_days(&self) -> &Option<i32>
pub fn get_days(&self) -> &Option<i32>
Indicates the lifetime, in days, of the objects that are subject to the rule. The value must be a non-zero positive integer.
Sourcepub fn expired_object_delete_marker(self, input: bool) -> Self
pub fn expired_object_delete_marker(self, input: bool) -> Self
Indicates whether Amazon S3 will remove a delete marker with no noncurrent versions. If set to true, the delete marker will be expired; if set to false the policy takes no action. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn set_expired_object_delete_marker(self, input: Option<bool>) -> Self
pub fn set_expired_object_delete_marker(self, input: Option<bool>) -> Self
Indicates whether Amazon S3 will remove a delete marker with no noncurrent versions. If set to true, the delete marker will be expired; if set to false the policy takes no action. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn get_expired_object_delete_marker(&self) -> &Option<bool>
pub fn get_expired_object_delete_marker(&self) -> &Option<bool>
Indicates whether Amazon S3 will remove a delete marker with no noncurrent versions. If set to true, the delete marker will be expired; if set to false the policy takes no action. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn build(self) -> LifecycleExpiration
pub fn build(self) -> LifecycleExpiration
Consumes the builder and constructs a LifecycleExpiration.