#[non_exhaustive]pub struct MetadataTableConfigurationResultBuilder { /* private fields */ }Expand description
A builder for MetadataTableConfigurationResult.
Implementations
Sourceimpl MetadataTableConfigurationResultBuilder
impl MetadataTableConfigurationResultBuilder
Sourcepub fn s3_tables_destination_result(
self,
input: S3TablesDestinationResult,
) -> Self
pub fn s3_tables_destination_result( self, input: S3TablesDestinationResult, ) -> Self
The destination information for the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn set_s3_tables_destination_result(
self,
input: Option<S3TablesDestinationResult>,
) -> Self
pub fn set_s3_tables_destination_result( self, input: Option<S3TablesDestinationResult>, ) -> Self
The destination information for the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn get_s3_tables_destination_result(
&self,
) -> &Option<S3TablesDestinationResult>
pub fn get_s3_tables_destination_result( &self, ) -> &Option<S3TablesDestinationResult>
The destination information for the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn build(self) -> MetadataTableConfigurationResult
pub fn build(self) -> MetadataTableConfigurationResult
Consumes the builder and constructs a MetadataTableConfigurationResult.