#[non_exhaustive]pub struct MetricsBuilder { /* private fields */ }Expand description
A builder for Metrics.
Implementations
Sourceimpl MetricsBuilder
impl MetricsBuilder
Sourcepub fn status(self, input: MetricsStatus) -> Self
pub fn status(self, input: MetricsStatus) -> Self
Specifies whether the replication metrics are enabled.
This field is required.Sourcepub fn set_status(self, input: Option<MetricsStatus>) -> Self
pub fn set_status(self, input: Option<MetricsStatus>) -> Self
Specifies whether the replication metrics are enabled.
Sourcepub fn get_status(&self) -> &Option<MetricsStatus>
pub fn get_status(&self) -> &Option<MetricsStatus>
Specifies whether the replication metrics are enabled.
Sourcepub fn event_threshold(self, input: ReplicationTimeValue) -> Self
pub fn event_threshold(self, input: ReplicationTimeValue) -> Self
A container specifying the time threshold for emitting the s3:Replication:OperationMissedThreshold event.
Sourcepub fn set_event_threshold(self, input: Option<ReplicationTimeValue>) -> Self
pub fn set_event_threshold(self, input: Option<ReplicationTimeValue>) -> Self
A container specifying the time threshold for emitting the s3:Replication:OperationMissedThreshold event.
Sourcepub fn get_event_threshold(&self) -> &Option<ReplicationTimeValue>
pub fn get_event_threshold(&self) -> &Option<ReplicationTimeValue>
A container specifying the time threshold for emitting the s3:Replication:OperationMissedThreshold event.