#[non_exhaustive]pub struct MetricsConfigurationBuilder { /* private fields */ }Expand description
A builder for MetricsConfiguration.
Implementations
Sourceimpl MetricsConfigurationBuilder
impl MetricsConfigurationBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
This field is required.Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
Sourcepub fn get_id(&self) -> &Option<String>
pub fn get_id(&self) -> &Option<String>
The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
Sourcepub fn filter(self, input: MetricsFilter) -> Self
pub fn filter(self, input: MetricsFilter) -> Self
Specifies a metrics configuration filter. The metrics configuration will only include objects that meet the filter's criteria. A filter must be a prefix, an object tag, an access point ARN, or a conjunction (MetricsAndOperator).
Sourcepub fn set_filter(self, input: Option<MetricsFilter>) -> Self
pub fn set_filter(self, input: Option<MetricsFilter>) -> Self
Specifies a metrics configuration filter. The metrics configuration will only include objects that meet the filter's criteria. A filter must be a prefix, an object tag, an access point ARN, or a conjunction (MetricsAndOperator).
Sourcepub fn get_filter(&self) -> &Option<MetricsFilter>
pub fn get_filter(&self) -> &Option<MetricsFilter>
Specifies a metrics configuration filter. The metrics configuration will only include objects that meet the filter's criteria. A filter must be a prefix, an object tag, an access point ARN, or a conjunction (MetricsAndOperator).
Sourcepub fn build(self) -> Result<MetricsConfiguration, BuildError>
pub fn build(self) -> Result<MetricsConfiguration, BuildError>
Consumes the builder and constructs a MetricsConfiguration.
This method will fail if any of the following fields are not set: