#[non_exhaustive]pub struct NoncurrentVersionExpirationBuilder { /* private fields */ }Expand description
A builder for NoncurrentVersionExpiration.
Implementations
Sourceimpl NoncurrentVersionExpirationBuilder
impl NoncurrentVersionExpirationBuilder
Sourcepub fn noncurrent_days(self, input: i32) -> Self
pub fn noncurrent_days(self, input: i32) -> Self
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. The value must be a non-zero positive integer. For information about the noncurrent days calculations, see How Amazon S3 Calculates When an Object Became Noncurrent in the Amazon S3 User Guide.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn set_noncurrent_days(self, input: Option<i32>) -> Self
pub fn set_noncurrent_days(self, input: Option<i32>) -> Self
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. The value must be a non-zero positive integer. For information about the noncurrent days calculations, see How Amazon S3 Calculates When an Object Became Noncurrent in the Amazon S3 User Guide.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn get_noncurrent_days(&self) -> &Option<i32>
pub fn get_noncurrent_days(&self) -> &Option<i32>
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. The value must be a non-zero positive integer. For information about the noncurrent days calculations, see How Amazon S3 Calculates When an Object Became Noncurrent in the Amazon S3 User Guide.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn newer_noncurrent_versions(self, input: i32) -> Self
pub fn newer_noncurrent_versions(self, input: i32) -> Self
Specifies how many noncurrent versions Amazon S3 will retain. You can specify up to 100 noncurrent versions to retain. Amazon S3 will permanently delete any additional noncurrent versions beyond the specified number to retain. For more information about noncurrent versions, see Lifecycle configuration elements in the Amazon S3 User Guide.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn set_newer_noncurrent_versions(self, input: Option<i32>) -> Self
pub fn set_newer_noncurrent_versions(self, input: Option<i32>) -> Self
Specifies how many noncurrent versions Amazon S3 will retain. You can specify up to 100 noncurrent versions to retain. Amazon S3 will permanently delete any additional noncurrent versions beyond the specified number to retain. For more information about noncurrent versions, see Lifecycle configuration elements in the Amazon S3 User Guide.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn get_newer_noncurrent_versions(&self) -> &Option<i32>
pub fn get_newer_noncurrent_versions(&self) -> &Option<i32>
Specifies how many noncurrent versions Amazon S3 will retain. You can specify up to 100 noncurrent versions to retain. Amazon S3 will permanently delete any additional noncurrent versions beyond the specified number to retain. For more information about noncurrent versions, see Lifecycle configuration elements in the Amazon S3 User Guide.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn build(self) -> NoncurrentVersionExpiration
pub fn build(self) -> NoncurrentVersionExpiration
Consumes the builder and constructs a NoncurrentVersionExpiration.