#[non_exhaustive]pub struct ObjectIdentifierBuilder { /* private fields */ }Expand description
A builder for ObjectIdentifier.
Implementations
Sourceimpl ObjectIdentifierBuilder
impl ObjectIdentifierBuilder
Sourcepub fn key(self, input: impl Into<String>) -> Self
pub fn key(self, input: impl Into<String>) -> Self
Key name of the object.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourcepub fn set_key(self, input: Option<String>) -> Self
pub fn set_key(self, input: Option<String>) -> Self
Key name of the object.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourcepub fn get_key(&self) -> &Option<String>
pub fn get_key(&self) -> &Option<String>
Key name of the object.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourcepub fn version_id(self, input: impl Into<String>) -> Self
pub fn version_id(self, input: impl Into<String>) -> Self
Version ID for the specific version of the object to delete.
This functionality is not supported for directory buckets.
Sourcepub fn set_version_id(self, input: Option<String>) -> Self
pub fn set_version_id(self, input: Option<String>) -> Self
Version ID for the specific version of the object to delete.
This functionality is not supported for directory buckets.
Sourcepub fn get_version_id(&self) -> &Option<String>
pub fn get_version_id(&self) -> &Option<String>
Version ID for the specific version of the object to delete.
This functionality is not supported for directory buckets.
Sourcepub fn e_tag(self, input: impl Into<String>) -> Self
pub fn e_tag(self, input: impl Into<String>) -> Self
An entity tag (ETag) is an identifier assigned by a web server to a specific version of a resource found at a URL. This header field makes the request method conditional on ETags.
Entity tags (ETags) for S3 Express One Zone are random alphanumeric strings unique to the object.
Sourcepub fn set_e_tag(self, input: Option<String>) -> Self
pub fn set_e_tag(self, input: Option<String>) -> Self
An entity tag (ETag) is an identifier assigned by a web server to a specific version of a resource found at a URL. This header field makes the request method conditional on ETags.
Entity tags (ETags) for S3 Express One Zone are random alphanumeric strings unique to the object.
Sourcepub fn get_e_tag(&self) -> &Option<String>
pub fn get_e_tag(&self) -> &Option<String>
An entity tag (ETag) is an identifier assigned by a web server to a specific version of a resource found at a URL. This header field makes the request method conditional on ETags.
Entity tags (ETags) for S3 Express One Zone are random alphanumeric strings unique to the object.
Sourcepub fn last_modified_time(self, input: DateTime) -> Self
pub fn last_modified_time(self, input: DateTime) -> Self
If present, the objects are deleted only if its modification times matches the provided Timestamp.
This functionality is only supported for directory buckets.
Sourcepub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
If present, the objects are deleted only if its modification times matches the provided Timestamp.
This functionality is only supported for directory buckets.
Sourcepub fn get_last_modified_time(&self) -> &Option<DateTime>
pub fn get_last_modified_time(&self) -> &Option<DateTime>
If present, the objects are deleted only if its modification times matches the provided Timestamp.
This functionality is only supported for directory buckets.
Sourcepub fn size(self, input: i64) -> Self
pub fn size(self, input: i64) -> Self
If present, the objects are deleted only if its size matches the provided size in bytes.
This functionality is only supported for directory buckets.
Sourcepub fn set_size(self, input: Option<i64>) -> Self
pub fn set_size(self, input: Option<i64>) -> Self
If present, the objects are deleted only if its size matches the provided size in bytes.
This functionality is only supported for directory buckets.
Sourcepub fn get_size(&self) -> &Option<i64>
pub fn get_size(&self) -> &Option<i64>
If present, the objects are deleted only if its size matches the provided size in bytes.
This functionality is only supported for directory buckets.
Sourcepub fn build(self) -> Result<ObjectIdentifier, BuildError>
pub fn build(self) -> Result<ObjectIdentifier, BuildError>
Consumes the builder and constructs a ObjectIdentifier.
This method will fail if any of the following fields are not set: