#[non_exhaustive]pub struct ObjectLockRetentionBuilder { /* private fields */ }Expand description
A builder for ObjectLockRetention.
Implementations
Sourceimpl ObjectLockRetentionBuilder
impl ObjectLockRetentionBuilder
Sourcepub fn mode(self, input: ObjectLockRetentionMode) -> Self
pub fn mode(self, input: ObjectLockRetentionMode) -> Self
Indicates the Retention mode for the specified object.
Sourcepub fn set_mode(self, input: Option<ObjectLockRetentionMode>) -> Self
pub fn set_mode(self, input: Option<ObjectLockRetentionMode>) -> Self
Indicates the Retention mode for the specified object.
Sourcepub fn get_mode(&self) -> &Option<ObjectLockRetentionMode>
pub fn get_mode(&self) -> &Option<ObjectLockRetentionMode>
Indicates the Retention mode for the specified object.
Sourcepub fn retain_until_date(self, input: DateTime) -> Self
pub fn retain_until_date(self, input: DateTime) -> Self
The date on which this Object Lock Retention will expire.
Sourcepub fn set_retain_until_date(self, input: Option<DateTime>) -> Self
pub fn set_retain_until_date(self, input: Option<DateTime>) -> Self
The date on which this Object Lock Retention will expire.
Sourcepub fn get_retain_until_date(&self) -> &Option<DateTime>
pub fn get_retain_until_date(&self) -> &Option<DateTime>
The date on which this Object Lock Retention will expire.
Sourcepub fn build(self) -> ObjectLockRetention
pub fn build(self) -> ObjectLockRetention
Consumes the builder and constructs a ObjectLockRetention.