#[non_exhaustive]pub struct PartBuilder { /* private fields */ }Expand description
A builder for Part.
Implementations
Sourceimpl PartBuilder
impl PartBuilder
Sourcepub fn part_number(self, input: i32) -> Self
pub fn part_number(self, input: i32) -> Self
Part number identifying the part. This is a positive integer between 1 and 10,000.
Sourcepub fn set_part_number(self, input: Option<i32>) -> Self
pub fn set_part_number(self, input: Option<i32>) -> Self
Part number identifying the part. This is a positive integer between 1 and 10,000.
Sourcepub fn get_part_number(&self) -> &Option<i32>
pub fn get_part_number(&self) -> &Option<i32>
Part number identifying the part. This is a positive integer between 1 and 10,000.
Sourcepub fn last_modified(self, input: DateTime) -> Self
pub fn last_modified(self, input: DateTime) -> Self
Date and time at which the part was uploaded.
Sourcepub fn set_last_modified(self, input: Option<DateTime>) -> Self
pub fn set_last_modified(self, input: Option<DateTime>) -> Self
Date and time at which the part was uploaded.
Sourcepub fn get_last_modified(&self) -> &Option<DateTime>
pub fn get_last_modified(&self) -> &Option<DateTime>
Date and time at which the part was uploaded.
Sourcepub fn e_tag(self, input: impl Into<String>) -> Self
pub fn e_tag(self, input: impl Into<String>) -> Self
Entity tag returned when the part was uploaded.
Sourcepub fn set_e_tag(self, input: Option<String>) -> Self
pub fn set_e_tag(self, input: Option<String>) -> Self
Entity tag returned when the part was uploaded.
Sourcepub fn checksum_crc32(self, input: impl Into<String>) -> Self
pub fn checksum_crc32(self, input: impl Into<String>) -> Self
The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the object was uploaded with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_crc32(self, input: Option<String>) -> Self
pub fn set_checksum_crc32(self, input: Option<String>) -> Self
The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the object was uploaded with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_crc32(&self) -> &Option<String>
pub fn get_checksum_crc32(&self) -> &Option<String>
The Base64 encoded, 32-bit CRC32 checksum of the part. This checksum is present if the object was uploaded with the CRC32 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
pub fn checksum_crc32_c(self, input: impl Into<String>) -> Self
The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the object was uploaded with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
pub fn set_checksum_crc32_c(self, input: Option<String>) -> Self
The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the object was uploaded with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_crc32_c(&self) -> &Option<String>
pub fn get_checksum_crc32_c(&self) -> &Option<String>
The Base64 encoded, 32-bit CRC32C checksum of the part. This checksum is present if the object was uploaded with the CRC32C checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
pub fn checksum_crc64_nvme(self, input: impl Into<String>) -> Self
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, CRC64NVME, to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
pub fn set_checksum_crc64_nvme(self, input: Option<String>) -> Self
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, CRC64NVME, to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_crc64_nvme(&self) -> &Option<String>
pub fn get_checksum_crc64_nvme(&self) -> &Option<String>
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, CRC64NVME, to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha1(self, input: impl Into<String>) -> Self
pub fn checksum_sha1(self, input: impl Into<String>) -> Self
The Base64 encoded, 160-bit SHA1 checksum of the part. This checksum is present if the object was uploaded with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_sha1(self, input: Option<String>) -> Self
pub fn set_checksum_sha1(self, input: Option<String>) -> Self
The Base64 encoded, 160-bit SHA1 checksum of the part. This checksum is present if the object was uploaded with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_sha1(&self) -> &Option<String>
pub fn get_checksum_sha1(&self) -> &Option<String>
The Base64 encoded, 160-bit SHA1 checksum of the part. This checksum is present if the object was uploaded with the SHA1 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha256(self, input: impl Into<String>) -> Self
pub fn checksum_sha256(self, input: impl Into<String>) -> Self
The Base64 encoded, 256-bit SHA256 checksum of the part. This checksum is present if the object was uploaded with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn set_checksum_sha256(self, input: Option<String>) -> Self
pub fn set_checksum_sha256(self, input: Option<String>) -> Self
The Base64 encoded, 256-bit SHA256 checksum of the part. This checksum is present if the object was uploaded with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn get_checksum_sha256(&self) -> &Option<String>
pub fn get_checksum_sha256(&self) -> &Option<String>
The Base64 encoded, 256-bit SHA256 checksum of the part. This checksum is present if the object was uploaded with the SHA256 checksum algorithm. For more information, see Checking object integrity in the Amazon S3 User Guide.