#[non_exhaustive]pub struct PublicAccessBlockConfigurationBuilder { /* private fields */ }Expand description
A builder for PublicAccessBlockConfiguration.
Implementations
Sourceimpl PublicAccessBlockConfigurationBuilder
impl PublicAccessBlockConfigurationBuilder
Sourcepub fn block_public_acls(self, input: bool) -> Self
pub fn block_public_acls(self, input: bool) -> Self
Specifies whether Amazon S3 should block public access control lists (ACLs) for this bucket and objects in this bucket. Setting this element to TRUE causes the following behavior:
-
PUT Bucket ACL and PUT Object ACL calls fail if the specified ACL is public.
-
PUT Object calls fail if the request includes a public ACL.
-
PUT Bucket calls fail if the request includes a public ACL.
Enabling this setting doesn't affect existing policies or ACLs.
Sourcepub fn set_block_public_acls(self, input: Option<bool>) -> Self
pub fn set_block_public_acls(self, input: Option<bool>) -> Self
Specifies whether Amazon S3 should block public access control lists (ACLs) for this bucket and objects in this bucket. Setting this element to TRUE causes the following behavior:
-
PUT Bucket ACL and PUT Object ACL calls fail if the specified ACL is public.
-
PUT Object calls fail if the request includes a public ACL.
-
PUT Bucket calls fail if the request includes a public ACL.
Enabling this setting doesn't affect existing policies or ACLs.
Sourcepub fn get_block_public_acls(&self) -> &Option<bool>
pub fn get_block_public_acls(&self) -> &Option<bool>
Specifies whether Amazon S3 should block public access control lists (ACLs) for this bucket and objects in this bucket. Setting this element to TRUE causes the following behavior:
-
PUT Bucket ACL and PUT Object ACL calls fail if the specified ACL is public.
-
PUT Object calls fail if the request includes a public ACL.
-
PUT Bucket calls fail if the request includes a public ACL.
Enabling this setting doesn't affect existing policies or ACLs.
Sourcepub fn ignore_public_acls(self, input: bool) -> Self
pub fn ignore_public_acls(self, input: bool) -> Self
Specifies whether Amazon S3 should ignore public ACLs for this bucket and objects in this bucket. Setting this element to TRUE causes Amazon S3 to ignore all public ACLs on this bucket and objects in this bucket.
Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
Sourcepub fn set_ignore_public_acls(self, input: Option<bool>) -> Self
pub fn set_ignore_public_acls(self, input: Option<bool>) -> Self
Specifies whether Amazon S3 should ignore public ACLs for this bucket and objects in this bucket. Setting this element to TRUE causes Amazon S3 to ignore all public ACLs on this bucket and objects in this bucket.
Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
Sourcepub fn get_ignore_public_acls(&self) -> &Option<bool>
pub fn get_ignore_public_acls(&self) -> &Option<bool>
Specifies whether Amazon S3 should ignore public ACLs for this bucket and objects in this bucket. Setting this element to TRUE causes Amazon S3 to ignore all public ACLs on this bucket and objects in this bucket.
Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
Sourcepub fn block_public_policy(self, input: bool) -> Self
pub fn block_public_policy(self, input: bool) -> Self
Specifies whether Amazon S3 should block public bucket policies for this bucket. Setting this element to TRUE causes Amazon S3 to reject calls to PUT Bucket policy if the specified bucket policy allows public access.
Enabling this setting doesn't affect existing bucket policies.
Sourcepub fn set_block_public_policy(self, input: Option<bool>) -> Self
pub fn set_block_public_policy(self, input: Option<bool>) -> Self
Specifies whether Amazon S3 should block public bucket policies for this bucket. Setting this element to TRUE causes Amazon S3 to reject calls to PUT Bucket policy if the specified bucket policy allows public access.
Enabling this setting doesn't affect existing bucket policies.
Sourcepub fn get_block_public_policy(&self) -> &Option<bool>
pub fn get_block_public_policy(&self) -> &Option<bool>
Specifies whether Amazon S3 should block public bucket policies for this bucket. Setting this element to TRUE causes Amazon S3 to reject calls to PUT Bucket policy if the specified bucket policy allows public access.
Enabling this setting doesn't affect existing bucket policies.
Sourcepub fn restrict_public_buckets(self, input: bool) -> Self
pub fn restrict_public_buckets(self, input: bool) -> Self
Specifies whether Amazon S3 should restrict public bucket policies for this bucket. Setting this element to TRUE restricts access to this bucket to only Amazon Web Services service principals and authorized users within this account if the bucket has a public policy.
Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
Sourcepub fn set_restrict_public_buckets(self, input: Option<bool>) -> Self
pub fn set_restrict_public_buckets(self, input: Option<bool>) -> Self
Specifies whether Amazon S3 should restrict public bucket policies for this bucket. Setting this element to TRUE restricts access to this bucket to only Amazon Web Services service principals and authorized users within this account if the bucket has a public policy.
Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
Sourcepub fn get_restrict_public_buckets(&self) -> &Option<bool>
pub fn get_restrict_public_buckets(&self) -> &Option<bool>
Specifies whether Amazon S3 should restrict public bucket policies for this bucket. Setting this element to TRUE restricts access to this bucket to only Amazon Web Services service principals and authorized users within this account if the bucket has a public policy.
Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
Sourcepub fn build(self) -> PublicAccessBlockConfiguration
pub fn build(self) -> PublicAccessBlockConfiguration
Consumes the builder and constructs a PublicAccessBlockConfiguration.