#[non_exhaustive]pub struct S3TablesDestinationBuilder { /* private fields */ }Expand description
A builder for S3TablesDestination.
Implementations
Sourceimpl S3TablesDestinationBuilder
impl S3TablesDestinationBuilder
Sourcepub fn table_bucket_arn(self, input: impl Into<String>) -> Self
pub fn table_bucket_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
This field is required.Sourcepub fn set_table_bucket_arn(self, input: Option<String>) -> Self
pub fn set_table_bucket_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
Sourcepub fn get_table_bucket_arn(&self) -> &Option<String>
pub fn get_table_bucket_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn build(self) -> Result<S3TablesDestination, BuildError>
pub fn build(self) -> Result<S3TablesDestination, BuildError>
Consumes the builder and constructs a S3TablesDestination.
This method will fail if any of the following fields are not set: