#[non_exhaustive]pub struct ScanRangeBuilder { /* private fields */ }Expand description
A builder for ScanRange.
Implementations
Sourceimpl ScanRangeBuilder
impl ScanRangeBuilder
Sourcepub fn start(self, input: i64) -> Self
pub fn start(self, input: i64) -> Self
Specifies the start of the byte range. This parameter is optional. Valid values: non-negative integers. The default value is 0. If only start is supplied, it means scan from that point to the end of the file. For example, means scan from byte 50 until the end of the file.
Sourcepub fn set_start(self, input: Option<i64>) -> Self
pub fn set_start(self, input: Option<i64>) -> Self
Specifies the start of the byte range. This parameter is optional. Valid values: non-negative integers. The default value is 0. If only start is supplied, it means scan from that point to the end of the file. For example, means scan from byte 50 until the end of the file.
Sourcepub fn get_start(&self) -> &Option<i64>
pub fn get_start(&self) -> &Option<i64>
Specifies the start of the byte range. This parameter is optional. Valid values: non-negative integers. The default value is 0. If only start is supplied, it means scan from that point to the end of the file. For example, means scan from byte 50 until the end of the file.
Sourcepub fn end(self, input: i64) -> Self
pub fn end(self, input: i64) -> Self
Specifies the end of the byte range. This parameter is optional. Valid values: non-negative integers. The default value is one less than the size of the object being queried. If only the End parameter is supplied, it is interpreted to mean scan the last N bytes of the file. For example, means scan the last 50 bytes.
Sourcepub fn set_end(self, input: Option<i64>) -> Self
pub fn set_end(self, input: Option<i64>) -> Self
Specifies the end of the byte range. This parameter is optional. Valid values: non-negative integers. The default value is one less than the size of the object being queried. If only the End parameter is supplied, it is interpreted to mean scan the last N bytes of the file. For example, means scan the last 50 bytes.
Sourcepub fn get_end(&self) -> &Option<i64>
pub fn get_end(&self) -> &Option<i64>
Specifies the end of the byte range. This parameter is optional. Valid values: non-negative integers. The default value is one less than the size of the object being queried. If only the End parameter is supplied, it is interpreted to mean scan the last N bytes of the file. For example, means scan the last 50 bytes.