#[non_exhaustive]pub struct SelectParametersBuilder { /* private fields */ }Expand description
A builder for SelectParameters.
Implementations
Sourceimpl SelectParametersBuilder
impl SelectParametersBuilder
Sourcepub fn input_serialization(self, input: InputSerialization) -> Self
pub fn input_serialization(self, input: InputSerialization) -> Self
Describes the serialization format of the object.
This field is required.Sourcepub fn set_input_serialization(self, input: Option<InputSerialization>) -> Self
pub fn set_input_serialization(self, input: Option<InputSerialization>) -> Self
Describes the serialization format of the object.
Sourcepub fn get_input_serialization(&self) -> &Option<InputSerialization>
pub fn get_input_serialization(&self) -> &Option<InputSerialization>
Describes the serialization format of the object.
Sourcepub fn expression_type(self, input: ExpressionType) -> Self
pub fn expression_type(self, input: ExpressionType) -> Self
The type of the provided expression (for example, SQL).
This field is required.Sourcepub fn set_expression_type(self, input: Option<ExpressionType>) -> Self
pub fn set_expression_type(self, input: Option<ExpressionType>) -> Self
The type of the provided expression (for example, SQL).
Sourcepub fn get_expression_type(&self) -> &Option<ExpressionType>
pub fn get_expression_type(&self) -> &Option<ExpressionType>
The type of the provided expression (for example, SQL).
Sourcepub fn expression(self, input: impl Into<String>) -> Self
pub fn expression(self, input: impl Into<String>) -> Self
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
The expression that is used to query the object.
This field is required.Sourcepub fn set_expression(self, input: Option<String>) -> Self
pub fn set_expression(self, input: Option<String>) -> Self
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
The expression that is used to query the object.
Sourcepub fn get_expression(&self) -> &Option<String>
pub fn get_expression(&self) -> &Option<String>
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
The expression that is used to query the object.
Sourcepub fn output_serialization(self, input: OutputSerialization) -> Self
pub fn output_serialization(self, input: OutputSerialization) -> Self
Describes how the results of the Select job are serialized.
This field is required.Sourcepub fn set_output_serialization(
self,
input: Option<OutputSerialization>,
) -> Self
pub fn set_output_serialization( self, input: Option<OutputSerialization>, ) -> Self
Describes how the results of the Select job are serialized.
Sourcepub fn get_output_serialization(&self) -> &Option<OutputSerialization>
pub fn get_output_serialization(&self) -> &Option<OutputSerialization>
Describes how the results of the Select job are serialized.
Sourcepub fn build(self) -> Result<SelectParameters, BuildError>
pub fn build(self) -> Result<SelectParameters, BuildError>
Consumes the builder and constructs a SelectParameters.
This method will fail if any of the following fields are not set: