#[non_exhaustive]pub struct ServerSideEncryptionRuleBuilder { /* private fields */ }Expand description
A builder for ServerSideEncryptionRule.
Implementations
Sourceimpl ServerSideEncryptionRuleBuilder
impl ServerSideEncryptionRuleBuilder
Sourcepub fn apply_server_side_encryption_by_default(
self,
input: ServerSideEncryptionByDefault,
) -> Self
pub fn apply_server_side_encryption_by_default( self, input: ServerSideEncryptionByDefault, ) -> Self
Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
Sourcepub fn set_apply_server_side_encryption_by_default(
self,
input: Option<ServerSideEncryptionByDefault>,
) -> Self
pub fn set_apply_server_side_encryption_by_default( self, input: Option<ServerSideEncryptionByDefault>, ) -> Self
Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
Sourcepub fn get_apply_server_side_encryption_by_default(
&self,
) -> &Option<ServerSideEncryptionByDefault>
pub fn get_apply_server_side_encryption_by_default( &self, ) -> &Option<ServerSideEncryptionByDefault>
Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
Sourcepub fn bucket_key_enabled(self, input: bool) -> Self
pub fn bucket_key_enabled(self, input: bool) -> Self
Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Setting the BucketKeyEnabled element to true causes Amazon S3 to use an S3 Bucket Key.
-
General purpose buckets - By default, S3 Bucket Key is not enabled. For more information, see Amazon S3 Bucket Keys in the Amazon S3 User Guide.
-
Directory buckets - S3 Bucket Keys are always enabled for
GETandPUToperations in a directory bucket and can’t be disabled. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through CopyObject, UploadPartCopy, the Copy operation in Batch Operations, or the import jobs. In this case, Amazon S3 makes a call to KMS every time a copy request is made for a KMS-encrypted object.
Sourcepub fn set_bucket_key_enabled(self, input: Option<bool>) -> Self
pub fn set_bucket_key_enabled(self, input: Option<bool>) -> Self
Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Setting the BucketKeyEnabled element to true causes Amazon S3 to use an S3 Bucket Key.
-
General purpose buckets - By default, S3 Bucket Key is not enabled. For more information, see Amazon S3 Bucket Keys in the Amazon S3 User Guide.
-
Directory buckets - S3 Bucket Keys are always enabled for
GETandPUToperations in a directory bucket and can’t be disabled. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through CopyObject, UploadPartCopy, the Copy operation in Batch Operations, or the import jobs. In this case, Amazon S3 makes a call to KMS every time a copy request is made for a KMS-encrypted object.
Sourcepub fn get_bucket_key_enabled(&self) -> &Option<bool>
pub fn get_bucket_key_enabled(&self) -> &Option<bool>
Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Setting the BucketKeyEnabled element to true causes Amazon S3 to use an S3 Bucket Key.
-
General purpose buckets - By default, S3 Bucket Key is not enabled. For more information, see Amazon S3 Bucket Keys in the Amazon S3 User Guide.
-
Directory buckets - S3 Bucket Keys are always enabled for
GETandPUToperations in a directory bucket and can’t be disabled. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through CopyObject, UploadPartCopy, the Copy operation in Batch Operations, or the import jobs. In this case, Amazon S3 makes a call to KMS every time a copy request is made for a KMS-encrypted object.
Sourcepub fn blocked_encryption_types(self, input: BlockedEncryptionTypes) -> Self
pub fn blocked_encryption_types(self, input: BlockedEncryptionTypes) -> Self
A bucket-level setting for Amazon S3 general purpose buckets used to prevent the upload of new objects encrypted with the specified server-side encryption type. For example, blocking an encryption type will block PutObject, CopyObject, PostObject, multipart upload, and replication requests to the bucket for objects with the specified encryption type. However, you can continue to read and list any pre-existing objects already encrypted with the specified encryption type. For more information, see Blocking or unblocking SSE-C for a general purpose bucket.
Currently, this parameter only supports blocking or unblocking server-side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
Sourcepub fn set_blocked_encryption_types(
self,
input: Option<BlockedEncryptionTypes>,
) -> Self
pub fn set_blocked_encryption_types( self, input: Option<BlockedEncryptionTypes>, ) -> Self
A bucket-level setting for Amazon S3 general purpose buckets used to prevent the upload of new objects encrypted with the specified server-side encryption type. For example, blocking an encryption type will block PutObject, CopyObject, PostObject, multipart upload, and replication requests to the bucket for objects with the specified encryption type. However, you can continue to read and list any pre-existing objects already encrypted with the specified encryption type. For more information, see Blocking or unblocking SSE-C for a general purpose bucket.
Currently, this parameter only supports blocking or unblocking server-side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
Sourcepub fn get_blocked_encryption_types(&self) -> &Option<BlockedEncryptionTypes>
pub fn get_blocked_encryption_types(&self) -> &Option<BlockedEncryptionTypes>
A bucket-level setting for Amazon S3 general purpose buckets used to prevent the upload of new objects encrypted with the specified server-side encryption type. For example, blocking an encryption type will block PutObject, CopyObject, PostObject, multipart upload, and replication requests to the bucket for objects with the specified encryption type. However, you can continue to read and list any pre-existing objects already encrypted with the specified encryption type. For more information, see Blocking or unblocking SSE-C for a general purpose bucket.
Currently, this parameter only supports blocking or unblocking server-side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
Sourcepub fn build(self) -> ServerSideEncryptionRule
pub fn build(self) -> ServerSideEncryptionRule
Consumes the builder and constructs a ServerSideEncryptionRule.