#[non_exhaustive]pub struct StatsBuilder { /* private fields */ }Expand description
A builder for Stats.
Implementations
Sourceimpl StatsBuilder
impl StatsBuilder
Sourcepub fn bytes_scanned(self, input: i64) -> Self
pub fn bytes_scanned(self, input: i64) -> Self
The total number of object bytes scanned.
Sourcepub fn set_bytes_scanned(self, input: Option<i64>) -> Self
pub fn set_bytes_scanned(self, input: Option<i64>) -> Self
The total number of object bytes scanned.
Sourcepub fn get_bytes_scanned(&self) -> &Option<i64>
pub fn get_bytes_scanned(&self) -> &Option<i64>
The total number of object bytes scanned.
Sourcepub fn bytes_processed(self, input: i64) -> Self
pub fn bytes_processed(self, input: i64) -> Self
The total number of uncompressed object bytes processed.
Sourcepub fn set_bytes_processed(self, input: Option<i64>) -> Self
pub fn set_bytes_processed(self, input: Option<i64>) -> Self
The total number of uncompressed object bytes processed.
Sourcepub fn get_bytes_processed(&self) -> &Option<i64>
pub fn get_bytes_processed(&self) -> &Option<i64>
The total number of uncompressed object bytes processed.
Sourcepub fn bytes_returned(self, input: i64) -> Self
pub fn bytes_returned(self, input: i64) -> Self
The total number of bytes of records payload data returned.
Sourcepub fn set_bytes_returned(self, input: Option<i64>) -> Self
pub fn set_bytes_returned(self, input: Option<i64>) -> Self
The total number of bytes of records payload data returned.
Sourcepub fn get_bytes_returned(&self) -> &Option<i64>
pub fn get_bytes_returned(&self) -> &Option<i64>
The total number of bytes of records payload data returned.