#[non_exhaustive]pub struct TransitionBuilder { /* private fields */ }Expand description
A builder for Transition.
Implementations
Sourceimpl TransitionBuilder
impl TransitionBuilder
Sourcepub fn date(self, input: DateTime) -> Self
pub fn date(self, input: DateTime) -> Self
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
Sourcepub fn set_date(self, input: Option<DateTime>) -> Self
pub fn set_date(self, input: Option<DateTime>) -> Self
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
Sourcepub fn get_date(&self) -> &Option<DateTime>
pub fn get_date(&self) -> &Option<DateTime>
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
Sourcepub fn days(self, input: i32) -> Self
pub fn days(self, input: i32) -> Self
Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE, valid values are 0 or positive integers. If the specified storage class is STANDARD_IA or ONEZONE_IA, valid values are positive integers greater than 30. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see Constraints and considerations for transitions in the Amazon S3 User Guide.
Sourcepub fn set_days(self, input: Option<i32>) -> Self
pub fn set_days(self, input: Option<i32>) -> Self
Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE, valid values are 0 or positive integers. If the specified storage class is STANDARD_IA or ONEZONE_IA, valid values are positive integers greater than 30. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see Constraints and considerations for transitions in the Amazon S3 User Guide.
Sourcepub fn get_days(&self) -> &Option<i32>
pub fn get_days(&self) -> &Option<i32>
Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE, valid values are 0 or positive integers. If the specified storage class is STANDARD_IA or ONEZONE_IA, valid values are positive integers greater than 30. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see Constraints and considerations for transitions in the Amazon S3 User Guide.
Sourcepub fn storage_class(self, input: TransitionStorageClass) -> Self
pub fn storage_class(self, input: TransitionStorageClass) -> Self
The storage class to which you want the object to transition.
Sourcepub fn set_storage_class(self, input: Option<TransitionStorageClass>) -> Self
pub fn set_storage_class(self, input: Option<TransitionStorageClass>) -> Self
The storage class to which you want the object to transition.
Sourcepub fn get_storage_class(&self) -> &Option<TransitionStorageClass>
pub fn get_storage_class(&self) -> &Option<TransitionStorageClass>
The storage class to which you want the object to transition.
Sourcepub fn build(self) -> Transition
pub fn build(self) -> Transition
Consumes the builder and constructs a Transition.