#[non_exhaustive]pub enum Event {
Show 28 variants
S3IntelligentTiering,
S3LifecycleExpiration,
S3LifecycleExpirationDelete,
S3LifecycleExpirationDeleteMarkerCreated,
S3LifecycleTransition,
S3ObjectAclPut,
S3ObjectCreated,
S3ObjectCreatedCompleteMultipartUpload,
S3ObjectCreatedCopy,
S3ObjectCreatedPost,
S3ObjectCreatedPut,
S3ObjectRemoved,
S3ObjectRemovedDelete,
S3ObjectRemovedDeleteMarkerCreated,
S3ObjectRestore,
S3ObjectRestoreCompleted,
S3ObjectRestoreDelete,
S3ObjectRestorePost,
S3ObjectTagging,
S3ObjectTaggingDelete,
S3ObjectTaggingPut,
S3ReducedRedundancyLostObject,
S3Replication,
S3ReplicationOperationFailedReplication,
S3ReplicationOperationMissedThreshold,
S3ReplicationOperationNotTracked,
S3ReplicationOperationReplicatedAfterThreshold,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against Event, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let event = unimplemented!();
match event {
Event::S3IntelligentTiering => { /* ... */ },
Event::S3LifecycleExpiration => { /* ... */ },
Event::S3LifecycleExpirationDelete => { /* ... */ },
Event::S3LifecycleExpirationDeleteMarkerCreated => { /* ... */ },
Event::S3LifecycleTransition => { /* ... */ },
Event::S3ObjectAclPut => { /* ... */ },
Event::S3ObjectCreated => { /* ... */ },
Event::S3ObjectCreatedCompleteMultipartUpload => { /* ... */ },
Event::S3ObjectCreatedCopy => { /* ... */ },
Event::S3ObjectCreatedPost => { /* ... */ },
Event::S3ObjectCreatedPut => { /* ... */ },
Event::S3ObjectRemoved => { /* ... */ },
Event::S3ObjectRemovedDelete => { /* ... */ },
Event::S3ObjectRemovedDeleteMarkerCreated => { /* ... */ },
Event::S3ObjectRestore => { /* ... */ },
Event::S3ObjectRestoreCompleted => { /* ... */ },
Event::S3ObjectRestoreDelete => { /* ... */ },
Event::S3ObjectRestorePost => { /* ... */ },
Event::S3ObjectTagging => { /* ... */ },
Event::S3ObjectTaggingDelete => { /* ... */ },
Event::S3ObjectTaggingPut => { /* ... */ },
Event::S3ReducedRedundancyLostObject => { /* ... */ },
Event::S3Replication => { /* ... */ },
Event::S3ReplicationOperationFailedReplication => { /* ... */ },
Event::S3ReplicationOperationMissedThreshold => { /* ... */ },
Event::S3ReplicationOperationNotTracked => { /* ... */ },
Event::S3ReplicationOperationReplicatedAfterThreshold => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when event represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant Event::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
Event::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant Event::NewFeature is defined.
Specifically, when event represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on Event::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
The bucket event for which to send notifications.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
S3IntelligentTiering
S3LifecycleExpiration
S3LifecycleExpirationDelete
S3LifecycleExpirationDeleteMarkerCreated
S3LifecycleTransition
S3ObjectAclPut
S3ObjectCreated
S3ObjectCreatedCompleteMultipartUpload
S3ObjectCreatedCopy
S3ObjectCreatedPost
S3ObjectCreatedPut
S3ObjectRemoved
S3ObjectRemovedDelete
S3ObjectRemovedDeleteMarkerCreated
S3ObjectRestore
S3ObjectRestoreCompleted
S3ObjectRestoreDelete
S3ObjectRestorePost
S3ObjectTagging
S3ObjectTaggingDelete
S3ObjectTaggingPut
S3ReducedRedundancyLostObject
S3Replication
S3ReplicationOperationFailedReplication
S3ReplicationOperationMissedThreshold
S3ReplicationOperationNotTracked
S3ReplicationOperationReplicatedAfterThreshold
Unknown(UnknownVariantValue)
Unknown. See the docs on this enum for the correct way to handle unknown variants.Unknown contains new variants that have been added since this code was generated.
Implementations