#[non_exhaustive]pub enum SelectObjectContentEventStream {
Cont(ContinuationEvent),
End(EndEvent),
Progress(ProgressEvent),
Records(RecordsEvent),
Stats(StatsEvent),
#[non_exhaustive]
Unknown,
}Expand description
The container for selecting objects from a content event stream.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Cont(ContinuationEvent)
The Continuation Event.
End(EndEvent)
The End Event.
Progress(ProgressEvent)
The Progress Event.
Records(RecordsEvent)
The Records Event.
Stats(StatsEvent)
The Stats Event.
Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl SelectObjectContentEventStream
impl SelectObjectContentEventStream
Sourcepub fn as_cont(&self) -> Result<&ContinuationEvent, &Self>
pub fn as_cont(&self) -> Result<&ContinuationEvent, &Self>
Tries to convert the enum instance into Cont, extracting the inner ContinuationEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_progress(&self) -> Result<&ProgressEvent, &Self>
pub fn as_progress(&self) -> Result<&ProgressEvent, &Self>
Tries to convert the enum instance into Progress, extracting the inner ProgressEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_progress(&self) -> bool
pub fn is_progress(&self) -> bool
Returns true if this is a Progress.
Sourcepub fn as_records(&self) -> Result<&RecordsEvent, &Self>
pub fn as_records(&self) -> Result<&RecordsEvent, &Self>
Tries to convert the enum instance into Records, extracting the inner RecordsEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_records(&self) -> bool
pub fn is_records(&self) -> bool
Returns true if this is a Records.
Sourcepub fn as_stats(&self) -> Result<&StatsEvent, &Self>
pub fn as_stats(&self) -> Result<&StatsEvent, &Self>
Tries to convert the enum instance into Stats, extracting the inner StatsEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.