#[non_exhaustive]pub struct AnalyticsConfiguration {
pub id: String,
pub filter: Option<AnalyticsFilter>,
pub storage_class_analysis: Option<StorageClassAnalysis>,
}Expand description
Specifies the configuration and any analyses for the analytics filter of an Amazon S3 bucket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe ID that identifies the analytics configuration.
filter: Option<AnalyticsFilter>The filter used to describe a set of objects for analyses. A filter must have exactly one prefix, one tag, or one conjunction (AnalyticsAndOperator). If no filter is provided, all objects will be considered in any analysis.
storage_class_analysis: Option<StorageClassAnalysis>Contains data related to access patterns to be collected and made available to analyze the tradeoffs between different storage classes.
Implementations
Sourceimpl AnalyticsConfiguration
impl AnalyticsConfiguration
Sourcepub fn filter(&self) -> Option<&AnalyticsFilter>
pub fn filter(&self) -> Option<&AnalyticsFilter>
The filter used to describe a set of objects for analyses. A filter must have exactly one prefix, one tag, or one conjunction (AnalyticsAndOperator). If no filter is provided, all objects will be considered in any analysis.
Sourcepub fn storage_class_analysis(&self) -> Option<&StorageClassAnalysis>
pub fn storage_class_analysis(&self) -> Option<&StorageClassAnalysis>
Contains data related to access patterns to be collected and made available to analyze the tradeoffs between different storage classes.
Sourceimpl AnalyticsConfiguration
impl AnalyticsConfiguration
Sourcepub fn builder() -> AnalyticsConfigurationBuilder
pub fn builder() -> AnalyticsConfigurationBuilder
Creates a new builder-style object to manufacture AnalyticsConfiguration.