#[non_exhaustive]pub struct BlockedEncryptionTypes {
pub encryption_type: Option<Vec<EncryptionType>>,
}Expand description
A bucket-level setting for Amazon S3 general purpose buckets used to prevent the upload of new objects encrypted with the specified server-side encryption type. For example, blocking an encryption type will block PutObject, CopyObject, PostObject, multipart upload, and replication requests to the bucket for objects with the specified encryption type. However, you can continue to read and list any pre-existing objects already encrypted with the specified encryption type. For more information, see Blocking or unblocking SSE-C for a general purpose bucket.
This data type is used with the following actions:
- Permissions
-
You must have the
s3:PutEncryptionConfigurationpermission to block or unblock an encryption type for a bucket.You must have the
s3:GetEncryptionConfigurationpermission to view a bucket's encryption type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encryption_type: Option<Vec<EncryptionType>>The object encryption type that you want to block or unblock for an Amazon S3 general purpose bucket.
Currently, this parameter only supports blocking or unblocking server side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
Implementations
Sourceimpl BlockedEncryptionTypes
impl BlockedEncryptionTypes
Sourcepub fn encryption_type(&self) -> &[EncryptionType]
pub fn encryption_type(&self) -> &[EncryptionType]
The object encryption type that you want to block or unblock for an Amazon S3 general purpose bucket.
Currently, this parameter only supports blocking or unblocking server side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .encryption_type.is_none().
Sourceimpl BlockedEncryptionTypes
impl BlockedEncryptionTypes
Sourcepub fn builder() -> BlockedEncryptionTypesBuilder
pub fn builder() -> BlockedEncryptionTypesBuilder
Creates a new builder-style object to manufacture BlockedEncryptionTypes.