Struct Bucket

#[non_exhaustive]
pub struct Bucket { pub name: Option<String>, pub creation_date: Option<DateTime>, pub bucket_region: Option<String>, pub bucket_arn: Option<String>, }
In terms of implementation, a Bucket is a resource.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

The name of the bucket.

creation_date: Option<DateTime>

Date the bucket was created. This date can change when making changes to your bucket, such as editing its bucket policy.

bucket_region: Option<String>

BucketRegion indicates the Amazon Web Services region where the bucket is located. If the request contains at least one valid parameter, it is included in the response.

bucket_arn: Option<String>

The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.

This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.

Implementations

Source

impl Bucket

pub fn name(&self) -> Option<&str>

The name of the bucket.

pub fn creation_date(&self) -> Option<&DateTime>

Date the bucket was created. This date can change when making changes to your bucket, such as editing its bucket policy.

pub fn bucket_region(&self) -> Option<&str>

BucketRegion indicates the Amazon Web Services region where the bucket is located. If the request contains at least one valid parameter, it is included in the response.

pub fn bucket_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.

This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.

Source

impl Bucket

pub fn builder() -> BucketBuilder

Creates a new builder-style object to manufacture Bucket.