#[non_exhaustive]pub struct BucketInfo {
pub data_redundancy: Option<DataRedundancy>,
pub type: Option<BucketType>,
}Expand description
Specifies the information about the bucket that will be created. For more information about directory buckets, see Directory buckets in the Amazon S3 User Guide.
This functionality is only supported by directory buckets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_redundancy: Option<DataRedundancy>The number of Zone (Availability Zone or Local Zone) that's used for redundancy for the bucket.
type: Option<BucketType>The type of bucket.
Implementations
Sourceimpl BucketInfo
impl BucketInfo
Sourcepub fn data_redundancy(&self) -> Option<&DataRedundancy>
pub fn data_redundancy(&self) -> Option<&DataRedundancy>
The number of Zone (Availability Zone or Local Zone) that's used for redundancy for the bucket.
Sourcepub fn type(&self) -> Option<&BucketType>
pub fn type(&self) -> Option<&BucketType>
The type of bucket.
Sourceimpl BucketInfo
impl BucketInfo
Sourcepub fn builder() -> BucketInfoBuilder
pub fn builder() -> BucketInfoBuilder
Creates a new builder-style object to manufacture BucketInfo.