#[non_exhaustive]pub struct CommonPrefix {
pub prefix: Option<String>,
}Expand description
Container for all (if there are any) keys between Prefix and the next occurrence of the string specified by a delimiter. CommonPrefixes lists keys that act like subdirectories in the directory specified by Prefix. For example, if the prefix is notes/ and the delimiter is a slash (/) as in notes/summer/july, the common prefix is notes/summer/.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prefix: Option<String>Container for the specified common prefix.
Implementations
Sourceimpl CommonPrefix
impl CommonPrefix
Sourceimpl CommonPrefix
impl CommonPrefix
Sourcepub fn builder() -> CommonPrefixBuilder
pub fn builder() -> CommonPrefixBuilder
Creates a new builder-style object to manufacture CommonPrefix.