#[non_exhaustive]pub struct CopyPartResult {
pub e_tag: Option<String>,
pub last_modified: Option<DateTime>,
pub checksum_crc32: Option<String>,
pub checksum_crc32_c: Option<String>,
pub checksum_crc64_nvme: Option<String>,
pub checksum_sha1: Option<String>,
pub checksum_sha256: Option<String>,
}Expand description
Container for all response elements.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.e_tag: Option<String>Entity tag of the object.
last_modified: Option<DateTime>Date and time at which the object was uploaded.
checksum_crc32: Option<String>This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_crc32_c: Option<String>This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32C checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_crc64_nvme: Option<String>The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha1: Option<String>This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA1 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
checksum_sha256: Option<String>This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA256 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Implementations
Sourceimpl CopyPartResult
impl CopyPartResult
Sourcepub fn last_modified(&self) -> Option<&DateTime>
pub fn last_modified(&self) -> Option<&DateTime>
Date and time at which the object was uploaded.
Sourcepub fn checksum_crc32(&self) -> Option<&str>
pub fn checksum_crc32(&self) -> Option<&str>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc32_c(&self) -> Option<&str>
pub fn checksum_crc32_c(&self) -> Option<&str>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32C checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_crc64_nvme(&self) -> Option<&str>
pub fn checksum_crc64_nvme(&self) -> Option<&str>
The Base64 encoded, 64-bit CRC64NVME checksum of the part. This checksum is present if the multipart upload request was created with the CRC64NVME checksum algorithm to the uploaded object). For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha1(&self) -> Option<&str>
pub fn checksum_sha1(&self) -> Option<&str>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA1 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn checksum_sha256(&self) -> Option<&str>
pub fn checksum_sha256(&self) -> Option<&str>
This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA256 checksum of the part. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourceimpl CopyPartResult
impl CopyPartResult
Sourcepub fn builder() -> CopyPartResultBuilder
pub fn builder() -> CopyPartResultBuilder
Creates a new builder-style object to manufacture CopyPartResult.