#[non_exhaustive]pub struct CsvInput {
pub file_header_info: Option<FileHeaderInfo>,
pub comments: Option<String>,
pub quote_escape_character: Option<String>,
pub record_delimiter: Option<String>,
pub field_delimiter: Option<String>,
pub quote_character: Option<String>,
pub allow_quoted_record_delimiter: Option<bool>,
}Expand description
Describes how an uncompressed comma-separated values (CSV)-formatted input object is formatted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_header_info: Option<FileHeaderInfo>Describes the first line of input. Valid values are:
-
NONE: First line is not a header. -
IGNORE: First line is a header, but you can't use the header values to indicate the column in an expression. You can use column position (such as _1, _2, …) to indicate the column (SELECT s._1 FROM OBJECT s). -
Use: First line is a header, and you can use the header value to identify a column in an expression (SELECT "name" FROM OBJECT).
comments: Option<String>A single character used to indicate that a row should be ignored when the character is present at the start of that row. You can specify any character to indicate a comment line. The default character is #.
Default: #
quote_escape_character: Option<String>A single character used for escaping the quotation mark character inside an already escaped value. For example, the value """ a , b """ is parsed as " a , b ".
record_delimiter: Option<String>A single character used to separate individual records in the input. Instead of the default value, you can specify an arbitrary delimiter.
field_delimiter: Option<String>A single character used to separate individual fields in a record. You can specify an arbitrary delimiter.
quote_character: Option<String>A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Type: String
Default: "
Ancestors: CSV
allow_quoted_record_delimiter: Option<bool>Specifies that CSV field values may contain quoted record delimiters and such records should be allowed. Default value is FALSE. Setting this value to TRUE may lower performance.
Implementations
Sourceimpl CsvInput
impl CsvInput
Sourcepub fn file_header_info(&self) -> Option<&FileHeaderInfo>
pub fn file_header_info(&self) -> Option<&FileHeaderInfo>
Describes the first line of input. Valid values are:
-
NONE: First line is not a header. -
IGNORE: First line is a header, but you can't use the header values to indicate the column in an expression. You can use column position (such as _1, _2, …) to indicate the column (SELECT s._1 FROM OBJECT s). -
Use: First line is a header, and you can use the header value to identify a column in an expression (SELECT "name" FROM OBJECT).
Sourcepub fn comments(&self) -> Option<&str>
pub fn comments(&self) -> Option<&str>
A single character used to indicate that a row should be ignored when the character is present at the start of that row. You can specify any character to indicate a comment line. The default character is #.
Default: #
Sourcepub fn quote_escape_character(&self) -> Option<&str>
pub fn quote_escape_character(&self) -> Option<&str>
A single character used for escaping the quotation mark character inside an already escaped value. For example, the value """ a , b """ is parsed as " a , b ".
Sourcepub fn record_delimiter(&self) -> Option<&str>
pub fn record_delimiter(&self) -> Option<&str>
A single character used to separate individual records in the input. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn field_delimiter(&self) -> Option<&str>
pub fn field_delimiter(&self) -> Option<&str>
A single character used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn quote_character(&self) -> Option<&str>
pub fn quote_character(&self) -> Option<&str>
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Type: String
Default: "
Ancestors: CSV
Sourcepub fn allow_quoted_record_delimiter(&self) -> Option<bool>
pub fn allow_quoted_record_delimiter(&self) -> Option<bool>
Specifies that CSV field values may contain quoted record delimiters and such records should be allowed. Default value is FALSE. Setting this value to TRUE may lower performance.