#[non_exhaustive]pub struct CsvOutput {
pub quote_fields: Option<QuoteFields>,
pub quote_escape_character: Option<String>,
pub record_delimiter: Option<String>,
pub field_delimiter: Option<String>,
pub quote_character: Option<String>,
}Expand description
Describes how uncompressed comma-separated values (CSV)-formatted results are formatted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quote_fields: Option<QuoteFields>Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
quote_escape_character: Option<String>The single character used for escaping the quote character inside an already escaped value.
record_delimiter: Option<String>A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
field_delimiter: Option<String>The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
quote_character: Option<String>A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
Implementations
Sourceimpl CsvOutput
impl CsvOutput
Sourcepub fn quote_fields(&self) -> Option<&QuoteFields>
pub fn quote_fields(&self) -> Option<&QuoteFields>
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
Sourcepub fn quote_escape_character(&self) -> Option<&str>
pub fn quote_escape_character(&self) -> Option<&str>
The single character used for escaping the quote character inside an already escaped value.
Sourcepub fn record_delimiter(&self) -> Option<&str>
pub fn record_delimiter(&self) -> Option<&str>
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
Sourcepub fn field_delimiter(&self) -> Option<&str>
pub fn field_delimiter(&self) -> Option<&str>
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
Sourcepub fn quote_character(&self) -> Option<&str>
pub fn quote_character(&self) -> Option<&str>
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".