#[non_exhaustive]pub struct DefaultRetention {
pub mode: Option<ObjectLockRetentionMode>,
pub days: Option<i32>,
pub years: Option<i32>,
}Expand description
The container element for optionally specifying the default Object Lock retention settings for new objects placed in the specified bucket.
-
The
DefaultRetentionsettings require both a mode and a period. -
The
DefaultRetentionperiod can be eitherDaysorYearsbut you must select one. You cannot specifyDaysandYearsat the same time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: Option<ObjectLockRetentionMode>The default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Must be used with either Days or Years.
days: Option<i32>The number of days that you want to specify for the default retention period. Must be used with Mode.
years: Option<i32>The number of years that you want to specify for the default retention period. Must be used with Mode.
Implementations
Sourceimpl DefaultRetention
impl DefaultRetention
Sourcepub fn mode(&self) -> Option<&ObjectLockRetentionMode>
pub fn mode(&self) -> Option<&ObjectLockRetentionMode>
The default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Must be used with either Days or Years.
Sourceimpl DefaultRetention
impl DefaultRetention
Sourcepub fn builder() -> DefaultRetentionBuilder
pub fn builder() -> DefaultRetentionBuilder
Creates a new builder-style object to manufacture DefaultRetention.