#[non_exhaustive]pub struct Destination {
pub bucket: String,
pub account: Option<String>,
pub storage_class: Option<StorageClass>,
pub access_control_translation: Option<AccessControlTranslation>,
pub encryption_configuration: Option<EncryptionConfiguration>,
pub replication_time: Option<ReplicationTime>,
pub metrics: Option<Metrics>,
}Expand description
Specifies information about where to publish analysis or configuration results for an Amazon S3 bucket and S3 Replication Time Control (S3 RTC).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: StringThe Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
account: Option<String>Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to change replica ownership to the Amazon Web Services account that owns the destination bucket by specifying the AccessControlTranslation property, this is the account ID of the destination bucket owner. For more information, see Replication Additional Configuration: Changing the Replica Owner in the Amazon S3 User Guide.
storage_class: Option<StorageClass>The storage class to use when replicating objects, such as S3 Standard or reduced redundancy. By default, Amazon S3 uses the storage class of the source object to create the object replica.
For valid values, see the StorageClass element of the PUT Bucket replication action in the Amazon S3 API Reference.
FSX_OPENZFS is not an accepted value when replicating objects.
access_control_translation: Option<AccessControlTranslation>Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the Amazon Web Services account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same Amazon Web Services account that owns the source object.
encryption_configuration: Option<EncryptionConfiguration>A container that provides information about encryption. If SourceSelectionCriteria is specified, you must specify this element.
replication_time: Option<ReplicationTime>A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a Metrics block.
metrics: Option<Metrics>A container specifying replication metrics-related settings enabling replication metrics and events.
Implementations
Sourceimpl Destination
impl Destination
Sourcepub fn bucket(&self) -> &str
pub fn bucket(&self) -> &str
The Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
Sourcepub fn account(&self) -> Option<&str>
pub fn account(&self) -> Option<&str>
Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to change replica ownership to the Amazon Web Services account that owns the destination bucket by specifying the AccessControlTranslation property, this is the account ID of the destination bucket owner. For more information, see Replication Additional Configuration: Changing the Replica Owner in the Amazon S3 User Guide.
Sourcepub fn storage_class(&self) -> Option<&StorageClass>
pub fn storage_class(&self) -> Option<&StorageClass>
The storage class to use when replicating objects, such as S3 Standard or reduced redundancy. By default, Amazon S3 uses the storage class of the source object to create the object replica.
For valid values, see the StorageClass element of the PUT Bucket replication action in the Amazon S3 API Reference.
FSX_OPENZFS is not an accepted value when replicating objects.
Sourcepub fn access_control_translation(&self) -> Option<&AccessControlTranslation>
pub fn access_control_translation(&self) -> Option<&AccessControlTranslation>
Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the Amazon Web Services account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same Amazon Web Services account that owns the source object.
Sourcepub fn encryption_configuration(&self) -> Option<&EncryptionConfiguration>
pub fn encryption_configuration(&self) -> Option<&EncryptionConfiguration>
A container that provides information about encryption. If SourceSelectionCriteria is specified, you must specify this element.
Sourcepub fn replication_time(&self) -> Option<&ReplicationTime>
pub fn replication_time(&self) -> Option<&ReplicationTime>
A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a Metrics block.
Sourceimpl Destination
impl Destination
Sourcepub fn builder() -> DestinationBuilder
pub fn builder() -> DestinationBuilder
Creates a new builder-style object to manufacture Destination.