#[non_exhaustive]pub struct DestinationResult {
pub table_bucket_type: Option<S3TablesBucketType>,
pub table_bucket_arn: Option<String>,
pub table_namespace: Option<String>,
}Expand description
The destination information for the S3 Metadata configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_bucket_type: Option<S3TablesBucketType>The type of the table bucket where the metadata configuration is stored. The aws value indicates an Amazon Web Services managed table bucket, and the customer value indicates a customer-managed table bucket. V2 metadata configurations are stored in Amazon Web Services managed table buckets, and V1 metadata configurations are stored in customer-managed table buckets.
table_bucket_arn: Option<String>The Amazon Resource Name (ARN) of the table bucket where the metadata configuration is stored.
table_namespace: Option<String>The namespace in the table bucket where the metadata tables for a metadata configuration are stored.
Implementations
Sourceimpl DestinationResult
impl DestinationResult
Sourcepub fn table_bucket_type(&self) -> Option<&S3TablesBucketType>
pub fn table_bucket_type(&self) -> Option<&S3TablesBucketType>
The type of the table bucket where the metadata configuration is stored. The aws value indicates an Amazon Web Services managed table bucket, and the customer value indicates a customer-managed table bucket. V2 metadata configurations are stored in Amazon Web Services managed table buckets, and V1 metadata configurations are stored in customer-managed table buckets.
Sourcepub fn table_bucket_arn(&self) -> Option<&str>
pub fn table_bucket_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the table bucket where the metadata configuration is stored.
Sourcepub fn table_namespace(&self) -> Option<&str>
pub fn table_namespace(&self) -> Option<&str>
The namespace in the table bucket where the metadata tables for a metadata configuration are stored.
Sourceimpl DestinationResult
impl DestinationResult
Sourcepub fn builder() -> DestinationResultBuilder
pub fn builder() -> DestinationResultBuilder
Creates a new builder-style object to manufacture DestinationResult.