#[non_exhaustive]pub struct Encryption {
pub encryption_type: ServerSideEncryption,
pub kms_key_id: Option<String>,
pub kms_context: Option<String>,
}Expand description
Contains the type of server-side encryption used.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encryption_type: ServerSideEncryptionThe server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256, aws:kms).
kms_key_id: Option<String>If the encryption type is aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in KMS in the Amazon Web Services Key Management Service Developer Guide.
kms_context: Option<String>If the encryption type is aws:kms, this optional value can be used to specify the encryption context for the restore results.
Implementations
Sourceimpl Encryption
impl Encryption
Sourcepub fn encryption_type(&self) -> &ServerSideEncryption
pub fn encryption_type(&self) -> &ServerSideEncryption
The server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256, aws:kms).
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
If the encryption type is aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourcepub fn kms_context(&self) -> Option<&str>
pub fn kms_context(&self) -> Option<&str>
If the encryption type is aws:kms, this optional value can be used to specify the encryption context for the restore results.
Sourceimpl Encryption
impl Encryption
Sourcepub fn builder() -> EncryptionBuilder
pub fn builder() -> EncryptionBuilder
Creates a new builder-style object to manufacture Encryption.