#[non_exhaustive]pub struct EncryptionConfiguration {
pub replica_kms_key_id: Option<String>,
}Expand description
Specifies encryption-related information for an Amazon S3 bucket that is a destination for replicated objects.
If you're specifying a customer managed KMS key, we recommend using a fully qualified KMS key ARN. If you use a KMS key alias instead, then KMS resolves the key within the requester’s account. This behavior can result in data that's encrypted with a KMS key that belongs to the requester, and not the bucket owner.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replica_kms_key_id: Option<String>Specifies the ID (Key ARN or Alias ARN) of the customer managed Amazon Web Services KMS key stored in Amazon Web Services Key Management Service (KMS) for the destination bucket. Amazon S3 uses this key to encrypt replica objects. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in Amazon Web Services KMS in the Amazon Web Services Key Management Service Developer Guide.
Implementations
Sourceimpl EncryptionConfiguration
impl EncryptionConfiguration
Sourcepub fn replica_kms_key_id(&self) -> Option<&str>
pub fn replica_kms_key_id(&self) -> Option<&str>
Specifies the ID (Key ARN or Alias ARN) of the customer managed Amazon Web Services KMS key stored in Amazon Web Services Key Management Service (KMS) for the destination bucket. Amazon S3 uses this key to encrypt replica objects. Amazon S3 only supports symmetric encryption KMS keys. For more information, see Asymmetric keys in Amazon Web Services KMS in the Amazon Web Services Key Management Service Developer Guide.
Sourceimpl EncryptionConfiguration
impl EncryptionConfiguration
Sourcepub fn builder() -> EncryptionConfigurationBuilder
pub fn builder() -> EncryptionConfigurationBuilder
Creates a new builder-style object to manufacture EncryptionConfiguration.