#[non_exhaustive]pub struct ErrorDetails {
pub error_code: Option<String>,
pub error_message: Option<String>,
}Expand description
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_code: Option<String>If the V1 CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTableands3tables:PutTablePolicypermissions, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableAlreadyExists- The table that you specified already exists in the table bucket's namespace. Specify a different table name. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableBucketNotFound- The table bucket that you specified doesn't exist in this Amazon Web Services Region and account. Create or choose a different table bucket. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration.
If the V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateTableBucket,s3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTable,s3tables:PutTablePolicy,kms:DescribeKey, ands3tables:PutTableEncryptionpermissions. Additionally, ensure that the KMS key used to encrypt the table still exists, is active and has a resource policy granting access to the S3 service principals 'maintenance.s3tables.amazonaws.com' and 'metadata.s3.amazonaws.com'. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableAlreadyExists- A journal table already exists in the Amazon Web Services managed table bucket's namespace. Delete the journal table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
InventoryTableAlreadyExists- An inventory table already exists in the Amazon Web Services managed table bucket's namespace. Delete the inventory table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableNotAvailable- The journal table that the inventory table relies on has aFAILEDstatus. An inventory table requires a journal table with anACTIVEstatus. To create a new journal or inventory table, you must delete the metadata configuration for this bucket, along with any journal or inventory tables, and then create a new metadata configuration. -
NoSuchBucket- The specified general purpose bucket does not exist.
error_message: Option<String>If the V1 CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error message. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTableands3tables:PutTablePolicypermissions, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableAlreadyExists- The table that you specified already exists in the table bucket's namespace. Specify a different table name. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableBucketNotFound- The table bucket that you specified doesn't exist in this Amazon Web Services Region and account. Create or choose a different table bucket. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration.
If the V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateTableBucket,s3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTable,s3tables:PutTablePolicy,kms:DescribeKey, ands3tables:PutTableEncryptionpermissions. Additionally, ensure that the KMS key used to encrypt the table still exists, is active and has a resource policy granting access to the S3 service principals 'maintenance.s3tables.amazonaws.com' and 'metadata.s3.amazonaws.com'. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableAlreadyExists- A journal table already exists in the Amazon Web Services managed table bucket's namespace. Delete the journal table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
InventoryTableAlreadyExists- An inventory table already exists in the Amazon Web Services managed table bucket's namespace. Delete the inventory table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableNotAvailable- The journal table that the inventory table relies on has aFAILEDstatus. An inventory table requires a journal table with anACTIVEstatus. To create a new journal or inventory table, you must delete the metadata configuration for this bucket, along with any journal or inventory tables, and then create a new metadata configuration. -
NoSuchBucket- The specified general purpose bucket does not exist.
Implementations
Sourceimpl ErrorDetails
impl ErrorDetails
Sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
If the V1 CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTableands3tables:PutTablePolicypermissions, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableAlreadyExists- The table that you specified already exists in the table bucket's namespace. Specify a different table name. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableBucketNotFound- The table bucket that you specified doesn't exist in this Amazon Web Services Region and account. Create or choose a different table bucket. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration.
If the V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateTableBucket,s3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTable,s3tables:PutTablePolicy,kms:DescribeKey, ands3tables:PutTableEncryptionpermissions. Additionally, ensure that the KMS key used to encrypt the table still exists, is active and has a resource policy granting access to the S3 service principals 'maintenance.s3tables.amazonaws.com' and 'metadata.s3.amazonaws.com'. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableAlreadyExists- A journal table already exists in the Amazon Web Services managed table bucket's namespace. Delete the journal table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
InventoryTableAlreadyExists- An inventory table already exists in the Amazon Web Services managed table bucket's namespace. Delete the inventory table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableNotAvailable- The journal table that the inventory table relies on has aFAILEDstatus. An inventory table requires a journal table with anACTIVEstatus. To create a new journal or inventory table, you must delete the metadata configuration for this bucket, along with any journal or inventory tables, and then create a new metadata configuration. -
NoSuchBucket- The specified general purpose bucket does not exist.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
If the V1 CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error message. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTableands3tables:PutTablePolicypermissions, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableAlreadyExists- The table that you specified already exists in the table bucket's namespace. Specify a different table name. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
TableBucketNotFound- The table bucket that you specified doesn't exist in this Amazon Web Services Region and account. Create or choose a different table bucket. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration.
If the V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code. The possible error codes and error messages are as follows:
-
AccessDeniedCreatingResources- You don't have sufficient permissions to create the required resources. Make sure that you haves3tables:CreateTableBucket,s3tables:CreateNamespace,s3tables:CreateTable,s3tables:GetTable,s3tables:PutTablePolicy,kms:DescribeKey, ands3tables:PutTableEncryptionpermissions. Additionally, ensure that the KMS key used to encrypt the table still exists, is active and has a resource policy granting access to the S3 service principals 'maintenance.s3tables.amazonaws.com' and 'metadata.s3.amazonaws.com'. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
AccessDeniedWritingToTable- Unable to write to the metadata table because of missing resource permissions. To fix the resource policy, Amazon S3 needs to create a new metadata table. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
DestinationTableNotFound- The destination table doesn't exist. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
ServerInternalError- An internal error has occurred. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableAlreadyExists- A journal table already exists in the Amazon Web Services managed table bucket's namespace. Delete the journal table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
InventoryTableAlreadyExists- An inventory table already exists in the Amazon Web Services managed table bucket's namespace. Delete the inventory table, and then try again. To create a new metadata table, you must delete the metadata configuration for this bucket, and then create a new metadata configuration. -
JournalTableNotAvailable- The journal table that the inventory table relies on has aFAILEDstatus. An inventory table requires a journal table with anACTIVEstatus. To create a new journal or inventory table, you must delete the metadata configuration for this bucket, along with any journal or inventory tables, and then create a new metadata configuration. -
NoSuchBucket- The specified general purpose bucket does not exist.
Sourceimpl ErrorDetails
impl ErrorDetails
Sourcepub fn builder() -> ErrorDetailsBuilder
pub fn builder() -> ErrorDetailsBuilder
Creates a new builder-style object to manufacture ErrorDetails.