#[non_exhaustive]pub struct GetObjectAttributesParts {
pub total_parts_count: Option<i32>,
pub part_number_marker: Option<String>,
pub next_part_number_marker: Option<String>,
pub max_parts: Option<i32>,
pub is_truncated: Option<bool>,
pub parts: Option<Vec<ObjectPart>>,
}Expand description
A collection of parts associated with a multipart upload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_parts_count: Option<i32>The total number of parts.
part_number_marker: Option<String>The marker for the current part.
next_part_number_marker: Option<String>When a list is truncated, this element specifies the last part in the list, as well as the value to use for the PartNumberMarker request parameter in a subsequent request.
max_parts: Option<i32>The maximum number of parts allowed in the response.
is_truncated: Option<bool>Indicates whether the returned list of parts is truncated. A value of true indicates that the list was truncated. A list can be truncated if the number of parts exceeds the limit returned in the MaxParts element.
parts: Option<Vec<ObjectPart>>A container for elements related to a particular part. A response can contain zero or more Parts elements.
-
General purpose buckets - For
GetObjectAttributes, if an additional checksum (includingx-amz-checksum-crc32,x-amz-checksum-crc32c,x-amz-checksum-sha1, orx-amz-checksum-sha256) isn't applied to the object specified in the request, the response doesn't return thePartelement. -
Directory buckets - For
GetObjectAttributes, regardless of whether an additional checksum is applied to the object specified in the request, the response returns thePartelement.
Implementations
Sourceimpl GetObjectAttributesParts
impl GetObjectAttributesParts
Sourcepub fn total_parts_count(&self) -> Option<i32>
pub fn total_parts_count(&self) -> Option<i32>
The total number of parts.
Sourcepub fn part_number_marker(&self) -> Option<&str>
pub fn part_number_marker(&self) -> Option<&str>
The marker for the current part.
Sourcepub fn next_part_number_marker(&self) -> Option<&str>
pub fn next_part_number_marker(&self) -> Option<&str>
When a list is truncated, this element specifies the last part in the list, as well as the value to use for the PartNumberMarker request parameter in a subsequent request.
Sourcepub fn is_truncated(&self) -> Option<bool>
pub fn is_truncated(&self) -> Option<bool>
Indicates whether the returned list of parts is truncated. A value of true indicates that the list was truncated. A list can be truncated if the number of parts exceeds the limit returned in the MaxParts element.
Sourcepub fn parts(&self) -> &[ObjectPart]
pub fn parts(&self) -> &[ObjectPart]
A container for elements related to a particular part. A response can contain zero or more Parts elements.
-
General purpose buckets - For
GetObjectAttributes, if an additional checksum (includingx-amz-checksum-crc32,x-amz-checksum-crc32c,x-amz-checksum-sha1, orx-amz-checksum-sha256) isn't applied to the object specified in the request, the response doesn't return thePartelement. -
Directory buckets - For
GetObjectAttributes, regardless of whether an additional checksum is applied to the object specified in the request, the response returns thePartelement.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .parts.is_none().
Sourceimpl GetObjectAttributesParts
impl GetObjectAttributesParts
Sourcepub fn builder() -> GetObjectAttributesPartsBuilder
pub fn builder() -> GetObjectAttributesPartsBuilder
Creates a new builder-style object to manufacture GetObjectAttributesParts.