#[non_exhaustive]pub struct IndexDocument {
pub suffix: String,
}Expand description
Container for the Suffix element.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.suffix: StringA suffix that is appended to a request that is for a directory on the website endpoint. (For example, if the suffix is index.html and you make a request to samplebucket/images/, the data that is returned will be for the object with the key name images/index.html.) The suffix must not be empty and must not include a slash character.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Implementations
Sourceimpl IndexDocument
impl IndexDocument
Sourcepub fn suffix(&self) -> &str
pub fn suffix(&self) -> &str
A suffix that is appended to a request that is for a directory on the website endpoint. (For example, if the suffix is index.html and you make a request to samplebucket/images/, the data that is returned will be for the object with the key name images/index.html.) The suffix must not be empty and must not include a slash character.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
Sourceimpl IndexDocument
impl IndexDocument
Sourcepub fn builder() -> IndexDocumentBuilder
pub fn builder() -> IndexDocumentBuilder
Creates a new builder-style object to manufacture IndexDocument.