#[non_exhaustive]pub struct Initiator {
pub id: Option<String>,
pub display_name: Option<String>,
}Expand description
Container element that identifies who initiated the multipart upload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>If the principal is an Amazon Web Services account, it provides the Canonical User ID. If the principal is an IAM User, it provides a user ARN value.
Directory buckets - If the principal is an Amazon Web Services account, it provides the Amazon Web Services account ID. If the principal is an IAM User, it provides a user ARN value.
display_name: Option<String>This functionality is not supported for directory buckets.
Implementations
Sourceimpl Initiator
impl Initiator
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
If the principal is an Amazon Web Services account, it provides the Canonical User ID. If the principal is an IAM User, it provides a user ARN value.
Directory buckets - If the principal is an Amazon Web Services account, it provides the Amazon Web Services account ID. If the principal is an IAM User, it provides a user ARN value.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
This functionality is not supported for directory buckets.