#[non_exhaustive]pub struct InventoryConfiguration {
pub destination: Option<InventoryDestination>,
pub is_enabled: bool,
pub filter: Option<InventoryFilter>,
pub id: String,
pub included_object_versions: InventoryIncludedObjectVersions,
pub optional_fields: Option<Vec<InventoryOptionalField>>,
pub schedule: Option<InventorySchedule>,
}Expand description
Specifies the S3 Inventory configuration for an Amazon S3 bucket. For more information, see GET Bucket inventory in the Amazon S3 API Reference.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<InventoryDestination>Contains information about where to publish the inventory results.
is_enabled: boolSpecifies whether the inventory is enabled or disabled. If set to True, an inventory list is generated. If set to False, no inventory list is generated.
filter: Option<InventoryFilter>Specifies an inventory filter. The inventory only includes objects that meet the filter's criteria.
id: StringThe ID used to identify the inventory configuration.
included_object_versions: InventoryIncludedObjectVersionsObject versions to include in the inventory list. If set to All, the list includes all the object versions, which adds the version-related fields VersionId, IsLatest, and DeleteMarker to the list. If set to Current, the list does not contain these version-related fields.
optional_fields: Option<Vec<InventoryOptionalField>>Contains the optional fields that are included in the inventory results.
schedule: Option<InventorySchedule>Specifies the schedule for generating inventory results.
Implementations
Sourceimpl InventoryConfiguration
impl InventoryConfiguration
Sourcepub fn destination(&self) -> Option<&InventoryDestination>
pub fn destination(&self) -> Option<&InventoryDestination>
Contains information about where to publish the inventory results.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Specifies whether the inventory is enabled or disabled. If set to True, an inventory list is generated. If set to False, no inventory list is generated.
Sourcepub fn filter(&self) -> Option<&InventoryFilter>
pub fn filter(&self) -> Option<&InventoryFilter>
Specifies an inventory filter. The inventory only includes objects that meet the filter's criteria.
Sourcepub fn included_object_versions(&self) -> &InventoryIncludedObjectVersions
pub fn included_object_versions(&self) -> &InventoryIncludedObjectVersions
Object versions to include in the inventory list. If set to All, the list includes all the object versions, which adds the version-related fields VersionId, IsLatest, and DeleteMarker to the list. If set to Current, the list does not contain these version-related fields.
Sourcepub fn optional_fields(&self) -> &[InventoryOptionalField]
pub fn optional_fields(&self) -> &[InventoryOptionalField]
Contains the optional fields that are included in the inventory results.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .optional_fields.is_none().
Sourcepub fn schedule(&self) -> Option<&InventorySchedule>
pub fn schedule(&self) -> Option<&InventorySchedule>
Specifies the schedule for generating inventory results.
Sourceimpl InventoryConfiguration
impl InventoryConfiguration
Sourcepub fn builder() -> InventoryConfigurationBuilder
pub fn builder() -> InventoryConfigurationBuilder
Creates a new builder-style object to manufacture InventoryConfiguration.