#[non_exhaustive]pub struct JournalTableConfigurationResult {
pub table_status: String,
pub error: Option<ErrorDetails>,
pub table_name: String,
pub table_arn: Option<String>,
pub record_expiration: Option<RecordExpiration>,
}Expand description
The journal table configuration for the S3 Metadata configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_status: StringThe status of the journal table. The status values are:
-
CREATING- The journal table is in the process of being created in the specified table bucket. -
ACTIVE- The journal table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the journal table, or Amazon S3 is unable to deliver records.
error: Option<ErrorDetails>If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
table_name: StringThe name of the journal table.
table_arn: Option<String>The Amazon Resource Name (ARN) for the journal table.
record_expiration: Option<RecordExpiration>The journal table record expiration settings for the journal table.
Implementations
Sourceimpl JournalTableConfigurationResult
impl JournalTableConfigurationResult
Sourcepub fn table_status(&self) -> &str
pub fn table_status(&self) -> &str
The status of the journal table. The status values are:
-
CREATING- The journal table is in the process of being created in the specified table bucket. -
ACTIVE- The journal table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the journal table, or Amazon S3 is unable to deliver records.
Sourcepub fn error(&self) -> Option<&ErrorDetails>
pub fn error(&self) -> Option<&ErrorDetails>
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
The name of the journal table.
Sourcepub fn record_expiration(&self) -> Option<&RecordExpiration>
pub fn record_expiration(&self) -> Option<&RecordExpiration>
The journal table record expiration settings for the journal table.
Sourceimpl JournalTableConfigurationResult
impl JournalTableConfigurationResult
Sourcepub fn builder() -> JournalTableConfigurationResultBuilder
pub fn builder() -> JournalTableConfigurationResultBuilder
Creates a new builder-style object to manufacture JournalTableConfigurationResult.