#[non_exhaustive]pub struct JournalTableConfigurationUpdates {
pub record_expiration: Option<RecordExpiration>,
}Expand description
The specified updates to the S3 Metadata journal table configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.record_expiration: Option<RecordExpiration>The journal table record expiration settings for the journal table.
Implementations
Sourceimpl JournalTableConfigurationUpdates
impl JournalTableConfigurationUpdates
Sourcepub fn record_expiration(&self) -> Option<&RecordExpiration>
pub fn record_expiration(&self) -> Option<&RecordExpiration>
The journal table record expiration settings for the journal table.
Sourceimpl JournalTableConfigurationUpdates
impl JournalTableConfigurationUpdates
Sourcepub fn builder() -> JournalTableConfigurationUpdatesBuilder
pub fn builder() -> JournalTableConfigurationUpdatesBuilder
Creates a new builder-style object to manufacture JournalTableConfigurationUpdates.