#[non_exhaustive]pub struct LambdaFunctionConfiguration {
pub id: Option<String>,
pub lambda_function_arn: String,
pub events: Vec<Event>,
pub filter: Option<NotificationConfigurationFilter>,
}Expand description
A container for specifying the configuration for Lambda notifications.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
lambda_function_arn: StringThe Amazon Resource Name (ARN) of the Lambda function that Amazon S3 invokes when the specified event type occurs.
events: Vec<Event>The Amazon S3 bucket event for which to invoke the Lambda function. For more information, see Supported Event Types in the Amazon S3 User Guide.
filter: Option<NotificationConfigurationFilter>Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
Implementations
Sourceimpl LambdaFunctionConfiguration
impl LambdaFunctionConfiguration
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
Sourcepub fn lambda_function_arn(&self) -> &str
pub fn lambda_function_arn(&self) -> &str
The Amazon Resource Name (ARN) of the Lambda function that Amazon S3 invokes when the specified event type occurs.
Sourcepub fn events(&self) -> &[Event]
pub fn events(&self) -> &[Event]
The Amazon S3 bucket event for which to invoke the Lambda function. For more information, see Supported Event Types in the Amazon S3 User Guide.
Sourcepub fn filter(&self) -> Option<&NotificationConfigurationFilter>
pub fn filter(&self) -> Option<&NotificationConfigurationFilter>
Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
Sourceimpl LambdaFunctionConfiguration
impl LambdaFunctionConfiguration
Sourcepub fn builder() -> LambdaFunctionConfigurationBuilder
pub fn builder() -> LambdaFunctionConfigurationBuilder
Creates a new builder-style object to manufacture LambdaFunctionConfiguration.