#[non_exhaustive]pub struct LifecycleExpiration {
pub date: Option<DateTime>,
pub days: Option<i32>,
pub expired_object_delete_marker: Option<bool>,
}Expand description
Container for the expiration for the lifecycle of the object.
For more information see, Managing your storage lifecycle in the Amazon S3 User Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.date: Option<DateTime>Indicates at what date the object is to be moved or deleted. The date value must conform to the ISO 8601 format. The time is always midnight UTC.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
days: Option<i32>Indicates the lifetime, in days, of the objects that are subject to the rule. The value must be a non-zero positive integer.
expired_object_delete_marker: Option<bool>Indicates whether Amazon S3 will remove a delete marker with no noncurrent versions. If set to true, the delete marker will be expired; if set to false the policy takes no action. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Implementations
Sourceimpl LifecycleExpiration
impl LifecycleExpiration
Sourcepub fn date(&self) -> Option<&DateTime>
pub fn date(&self) -> Option<&DateTime>
Indicates at what date the object is to be moved or deleted. The date value must conform to the ISO 8601 format. The time is always midnight UTC.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn days(&self) -> Option<i32>
pub fn days(&self) -> Option<i32>
Indicates the lifetime, in days, of the objects that are subject to the rule. The value must be a non-zero positive integer.
Sourcepub fn expired_object_delete_marker(&self) -> Option<bool>
pub fn expired_object_delete_marker(&self) -> Option<bool>
Indicates whether Amazon S3 will remove a delete marker with no noncurrent versions. If set to true, the delete marker will be expired; if set to false the policy takes no action. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourceimpl LifecycleExpiration
impl LifecycleExpiration
Sourcepub fn builder() -> LifecycleExpirationBuilder
pub fn builder() -> LifecycleExpirationBuilder
Creates a new builder-style object to manufacture LifecycleExpiration.