#[non_exhaustive]pub struct LifecycleRuleAndOperator {
pub prefix: Option<String>,
pub tags: Option<Vec<Tag>>,
pub object_size_greater_than: Option<i64>,
pub object_size_less_than: Option<i64>,
}Expand description
This is used in a Lifecycle Rule Filter to apply a logical AND to two or more predicates. The Lifecycle Rule will apply to any object matching all of the predicates configured inside the And operator.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prefix: Option<String>Prefix identifying one or more objects to which the rule applies.
All of these tags must exist in the object's tag set in order for the rule to apply.
object_size_greater_than: Option<i64>Minimum object size to which the rule applies.
object_size_less_than: Option<i64>Maximum object size to which the rule applies.
Implementations
Sourceimpl LifecycleRuleAndOperator
impl LifecycleRuleAndOperator
Sourcepub fn prefix(&self) -> Option<&str>
pub fn prefix(&self) -> Option<&str>
Prefix identifying one or more objects to which the rule applies.
All of these tags must exist in the object's tag set in order for the rule to apply.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn object_size_greater_than(&self) -> Option<i64>
pub fn object_size_greater_than(&self) -> Option<i64>
Minimum object size to which the rule applies.
Sourcepub fn object_size_less_than(&self) -> Option<i64>
pub fn object_size_less_than(&self) -> Option<i64>
Maximum object size to which the rule applies.
Sourceimpl LifecycleRuleAndOperator
impl LifecycleRuleAndOperator
Sourcepub fn builder() -> LifecycleRuleAndOperatorBuilder
pub fn builder() -> LifecycleRuleAndOperatorBuilder
Creates a new builder-style object to manufacture LifecycleRuleAndOperator.