#[non_exhaustive]pub struct LocationInfo {
pub type: Option<LocationType>,
pub name: Option<String>,
}Expand description
Specifies the location where the bucket will be created.
For directory buckets, the location type is Availability Zone or Local Zone. For more information about directory buckets, see Working with directory buckets in the Amazon S3 User Guide.
This functionality is only supported by directory buckets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<LocationType>The type of location where the bucket will be created.
name: Option<String>The name of the location where the bucket will be created.
For directory buckets, the name of the location is the Zone ID of the Availability Zone (AZ) or Local Zone (LZ) where the bucket will be created. An example AZ ID value is usw2-az1.
Implementations
Sourceimpl LocationInfo
impl LocationInfo
Sourcepub fn type(&self) -> Option<&LocationType>
pub fn type(&self) -> Option<&LocationType>
The type of location where the bucket will be created.
Sourceimpl LocationInfo
impl LocationInfo
Sourcepub fn builder() -> LocationInfoBuilder
pub fn builder() -> LocationInfoBuilder
Creates a new builder-style object to manufacture LocationInfo.