#[non_exhaustive]pub struct MetadataTableEncryptionConfiguration {
pub sse_algorithm: TableSseAlgorithm,
pub kms_key_arn: Option<String>,
}Expand description
The encryption settings for an S3 Metadata journal table or inventory table configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sse_algorithm: TableSseAlgorithmThe encryption type specified for a metadata table. To specify server-side encryption with Key Management Service (KMS) keys (SSE-KMS), use the aws:kms value. To specify server-side encryption with Amazon S3 managed keys (SSE-S3), use the AES256 value.
kms_key_arn: Option<String>If server-side encryption with Key Management Service (KMS) keys (SSE-KMS) is specified, you must also specify the KMS key Amazon Resource Name (ARN). You must specify a customer-managed KMS key that's located in the same Region as the general purpose bucket that corresponds to the metadata table configuration.
Implementations
Sourceimpl MetadataTableEncryptionConfiguration
impl MetadataTableEncryptionConfiguration
Sourcepub fn sse_algorithm(&self) -> &TableSseAlgorithm
pub fn sse_algorithm(&self) -> &TableSseAlgorithm
The encryption type specified for a metadata table. To specify server-side encryption with Key Management Service (KMS) keys (SSE-KMS), use the aws:kms value. To specify server-side encryption with Amazon S3 managed keys (SSE-S3), use the AES256 value.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
If server-side encryption with Key Management Service (KMS) keys (SSE-KMS) is specified, you must also specify the KMS key Amazon Resource Name (ARN). You must specify a customer-managed KMS key that's located in the same Region as the general purpose bucket that corresponds to the metadata table configuration.
Sourceimpl MetadataTableEncryptionConfiguration
impl MetadataTableEncryptionConfiguration
Sourcepub fn builder() -> MetadataTableEncryptionConfigurationBuilder
pub fn builder() -> MetadataTableEncryptionConfigurationBuilder
Creates a new builder-style object to manufacture MetadataTableEncryptionConfiguration.