#[non_exhaustive]pub struct MetricsAndOperator {
pub prefix: Option<String>,
pub tags: Option<Vec<Tag>>,
pub access_point_arn: Option<String>,
}Expand description
A conjunction (logical AND) of predicates, which is used in evaluating a metrics filter. The operator must have at least two predicates, and an object must match all of the predicates in order for the filter to apply.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prefix: Option<String>The prefix used when evaluating an AND predicate.
The list of tags used when evaluating an AND predicate.
access_point_arn: Option<String>The access point ARN used when evaluating an AND predicate.
Implementations
Sourceimpl MetricsAndOperator
impl MetricsAndOperator
The list of tags used when evaluating an AND predicate.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn access_point_arn(&self) -> Option<&str>
pub fn access_point_arn(&self) -> Option<&str>
The access point ARN used when evaluating an AND predicate.
Sourceimpl MetricsAndOperator
impl MetricsAndOperator
Sourcepub fn builder() -> MetricsAndOperatorBuilder
pub fn builder() -> MetricsAndOperatorBuilder
Creates a new builder-style object to manufacture MetricsAndOperator.