#[non_exhaustive]pub struct MetricsConfiguration {
pub id: String,
pub filter: Option<MetricsFilter>,
}Expand description
Specifies a metrics configuration for the CloudWatch request metrics (specified by the metrics configuration ID) from an Amazon S3 bucket. If you're updating an existing metrics configuration, note that this is a full replacement of the existing metrics configuration. If you don't include the elements you want to keep, they are erased. For more information, see PutBucketMetricsConfiguration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
filter: Option<MetricsFilter>Specifies a metrics configuration filter. The metrics configuration will only include objects that meet the filter's criteria. A filter must be a prefix, an object tag, an access point ARN, or a conjunction (MetricsAndOperator).
Implementations
Sourceimpl MetricsConfiguration
impl MetricsConfiguration
Sourcepub fn id(&self) -> &str
pub fn id(&self) -> &str
The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
Sourcepub fn filter(&self) -> Option<&MetricsFilter>
pub fn filter(&self) -> Option<&MetricsFilter>
Specifies a metrics configuration filter. The metrics configuration will only include objects that meet the filter's criteria. A filter must be a prefix, an object tag, an access point ARN, or a conjunction (MetricsAndOperator).
Sourceimpl MetricsConfiguration
impl MetricsConfiguration
Sourcepub fn builder() -> MetricsConfigurationBuilder
pub fn builder() -> MetricsConfigurationBuilder
Creates a new builder-style object to manufacture MetricsConfiguration.