#[non_exhaustive]pub struct NoncurrentVersionTransition {
pub noncurrent_days: Option<i32>,
pub storage_class: Option<TransitionStorageClass>,
pub newer_noncurrent_versions: Option<i32>,
}Expand description
Container for the transition rule that describes when noncurrent objects transition to the STANDARD_IA, ONEZONE_IA, INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE storage class. If your bucket is versioning-enabled (or versioning is suspended), you can set this action to request that Amazon S3 transition noncurrent object versions to the STANDARD_IA, ONEZONE_IA, INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE storage class at a specific period in the object's lifetime.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.noncurrent_days: Option<i32>Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. For information about the noncurrent days calculations, see How Amazon S3 Calculates How Long an Object Has Been Noncurrent in the Amazon S3 User Guide.
storage_class: Option<TransitionStorageClass>The class of storage used to store the object.
newer_noncurrent_versions: Option<i32>Specifies how many noncurrent versions Amazon S3 will retain in the same storage class before transitioning objects. You can specify up to 100 noncurrent versions to retain. Amazon S3 will transition any additional noncurrent versions beyond the specified number to retain. For more information about noncurrent versions, see Lifecycle configuration elements in the Amazon S3 User Guide.
Implementations
Sourceimpl NoncurrentVersionTransition
impl NoncurrentVersionTransition
Sourcepub fn noncurrent_days(&self) -> Option<i32>
pub fn noncurrent_days(&self) -> Option<i32>
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. For information about the noncurrent days calculations, see How Amazon S3 Calculates How Long an Object Has Been Noncurrent in the Amazon S3 User Guide.
Sourcepub fn storage_class(&self) -> Option<&TransitionStorageClass>
pub fn storage_class(&self) -> Option<&TransitionStorageClass>
The class of storage used to store the object.
Sourcepub fn newer_noncurrent_versions(&self) -> Option<i32>
pub fn newer_noncurrent_versions(&self) -> Option<i32>
Specifies how many noncurrent versions Amazon S3 will retain in the same storage class before transitioning objects. You can specify up to 100 noncurrent versions to retain. Amazon S3 will transition any additional noncurrent versions beyond the specified number to retain. For more information about noncurrent versions, see Lifecycle configuration elements in the Amazon S3 User Guide.
Sourceimpl NoncurrentVersionTransition
impl NoncurrentVersionTransition
Sourcepub fn builder() -> NoncurrentVersionTransitionBuilder
pub fn builder() -> NoncurrentVersionTransitionBuilder
Creates a new builder-style object to manufacture NoncurrentVersionTransition.