#[non_exhaustive]pub struct ObjectLockLegalHold {
pub status: Option<ObjectLockLegalHoldStatus>,
}Expand description
A legal hold configuration for an object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<ObjectLockLegalHoldStatus>Indicates whether the specified object has a legal hold in place.
Implementations
Sourceimpl ObjectLockLegalHold
impl ObjectLockLegalHold
Sourcepub fn status(&self) -> Option<&ObjectLockLegalHoldStatus>
pub fn status(&self) -> Option<&ObjectLockLegalHoldStatus>
Indicates whether the specified object has a legal hold in place.
Sourceimpl ObjectLockLegalHold
impl ObjectLockLegalHold
Sourcepub fn builder() -> ObjectLockLegalHoldBuilder
pub fn builder() -> ObjectLockLegalHoldBuilder
Creates a new builder-style object to manufacture ObjectLockLegalHold.