#[non_exhaustive]pub struct ObjectLockRule {
pub default_retention: Option<DefaultRetention>,
}Expand description
The container element for an Object Lock rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default_retention: Option<DefaultRetention>The default Object Lock retention mode and period that you want to apply to new objects placed in the specified bucket. Bucket settings require both a mode and a period. The period can be either Days or Years but you must select one. You cannot specify Days and Years at the same time.
Implementations
Sourceimpl ObjectLockRule
impl ObjectLockRule
Sourcepub fn default_retention(&self) -> Option<&DefaultRetention>
pub fn default_retention(&self) -> Option<&DefaultRetention>
The default Object Lock retention mode and period that you want to apply to new objects placed in the specified bucket. Bucket settings require both a mode and a period. The period can be either Days or Years but you must select one. You cannot specify Days and Years at the same time.
Sourceimpl ObjectLockRule
impl ObjectLockRule
Sourcepub fn builder() -> ObjectLockRuleBuilder
pub fn builder() -> ObjectLockRuleBuilder
Creates a new builder-style object to manufacture ObjectLockRule.