#[non_exhaustive]pub struct ObjectVersion {
pub e_tag: Option<String>,
pub checksum_algorithm: Option<Vec<ChecksumAlgorithm>>,
pub checksum_type: Option<ChecksumType>,
pub size: Option<i64>,
pub storage_class: Option<ObjectVersionStorageClass>,
pub key: Option<String>,
pub version_id: Option<String>,
pub is_latest: Option<bool>,
pub last_modified: Option<DateTime>,
pub owner: Option<Owner>,
pub restore_status: Option<RestoreStatus>,
}Expand description
The version of an object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.e_tag: Option<String>The entity tag is an MD5 hash of that version of the object.
checksum_algorithm: Option<Vec<ChecksumAlgorithm>>The algorithm that was used to create a checksum of the object.
checksum_type: Option<ChecksumType>The checksum type that is used to calculate the object’s checksum value. For more information, see Checking object integrity in the Amazon S3 User Guide.
size: Option<i64>Size in bytes of the object.
storage_class: Option<ObjectVersionStorageClass>The class of storage used to store the object.
key: Option<String>The object key.
version_id: Option<String>Version ID of an object.
is_latest: Option<bool>Specifies whether the object is (true) or is not (false) the latest version of an object.
last_modified: Option<DateTime>Date and time when the object was last modified.
owner: Option<Owner>Specifies the owner of the object.
restore_status: Option<RestoreStatus>Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved. For more information about these storage classes and how to work with archived objects, see Working with archived objects in the Amazon S3 User Guide.
Implementations
Sourceimpl ObjectVersion
impl ObjectVersion
Sourcepub fn e_tag(&self) -> Option<&str>
pub fn e_tag(&self) -> Option<&str>
The entity tag is an MD5 hash of that version of the object.
Sourcepub fn checksum_algorithm(&self) -> &[ChecksumAlgorithm]
pub fn checksum_algorithm(&self) -> &[ChecksumAlgorithm]
The algorithm that was used to create a checksum of the object.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .checksum_algorithm.is_none().
Sourcepub fn checksum_type(&self) -> Option<&ChecksumType>
pub fn checksum_type(&self) -> Option<&ChecksumType>
The checksum type that is used to calculate the object’s checksum value. For more information, see Checking object integrity in the Amazon S3 User Guide.
Sourcepub fn storage_class(&self) -> Option<&ObjectVersionStorageClass>
pub fn storage_class(&self) -> Option<&ObjectVersionStorageClass>
The class of storage used to store the object.
Sourcepub fn version_id(&self) -> Option<&str>
pub fn version_id(&self) -> Option<&str>
Version ID of an object.
Sourcepub fn is_latest(&self) -> Option<bool>
pub fn is_latest(&self) -> Option<bool>
Specifies whether the object is (true) or is not (false) the latest version of an object.
Sourcepub fn last_modified(&self) -> Option<&DateTime>
pub fn last_modified(&self) -> Option<&DateTime>
Date and time when the object was last modified.
Sourcepub fn restore_status(&self) -> Option<&RestoreStatus>
pub fn restore_status(&self) -> Option<&RestoreStatus>
Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved. For more information about these storage classes and how to work with archived objects, see Working with archived objects in the Amazon S3 User Guide.
Sourceimpl ObjectVersion
impl ObjectVersion
Sourcepub fn builder() -> ObjectVersionBuilder
pub fn builder() -> ObjectVersionBuilder
Creates a new builder-style object to manufacture ObjectVersion.