#[non_exhaustive]pub struct QueueConfiguration {
pub id: Option<String>,
pub queue_arn: String,
pub events: Vec<Event>,
pub filter: Option<NotificationConfigurationFilter>,
}Expand description
Specifies the configuration for publishing messages to an Amazon Simple Queue Service (Amazon SQS) queue when Amazon S3 detects specified events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
queue_arn: StringThe Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 publishes a message when it detects events of the specified type.
events: Vec<Event>A collection of bucket events for which to send notifications
filter: Option<NotificationConfigurationFilter>Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
Implementations
Sourceimpl QueueConfiguration
impl QueueConfiguration
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
Sourcepub fn queue_arn(&self) -> &str
pub fn queue_arn(&self) -> &str
The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 publishes a message when it detects events of the specified type.
Sourcepub fn filter(&self) -> Option<&NotificationConfigurationFilter>
pub fn filter(&self) -> Option<&NotificationConfigurationFilter>
Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
Sourceimpl QueueConfiguration
impl QueueConfiguration
Sourcepub fn builder() -> QueueConfigurationBuilder
pub fn builder() -> QueueConfigurationBuilder
Creates a new builder-style object to manufacture QueueConfiguration.