#[non_exhaustive]pub struct ReplicaModifications {
pub status: ReplicaModificationsStatus,
}Expand description
A filter that you can specify for selection for modifications on replicas. Amazon S3 doesn't replicate replica modifications by default. In the latest version of replication configuration (when Filter is specified), you can specify this element and set the status to Enabled to replicate modifications on replicas.
If you don't specify the Filter element, Amazon S3 assumes that the replication configuration is the earlier version, V1. In the earlier version, this element is not allowed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: ReplicaModificationsStatusSpecifies whether Amazon S3 replicates modifications on replicas.
Implementations
Sourceimpl ReplicaModifications
impl ReplicaModifications
Sourcepub fn status(&self) -> &ReplicaModificationsStatus
pub fn status(&self) -> &ReplicaModificationsStatus
Specifies whether Amazon S3 replicates modifications on replicas.
Sourceimpl ReplicaModifications
impl ReplicaModifications
Sourcepub fn builder() -> ReplicaModificationsBuilder
pub fn builder() -> ReplicaModificationsBuilder
Creates a new builder-style object to manufacture ReplicaModifications.