#[non_exhaustive]pub struct ReplicationConfiguration {
pub role: String,
pub rules: Vec<ReplicationRule>,
}Expand description
A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role: StringThe Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that Amazon S3 assumes when replicating objects. For more information, see How to Set Up Replication in the Amazon S3 User Guide.
rules: Vec<ReplicationRule>A container for one or more replication rules. A replication configuration must have at least one rule and can contain a maximum of 1,000 rules.
Implementations
Sourceimpl ReplicationConfiguration
impl ReplicationConfiguration
Sourcepub fn role(&self) -> &str
pub fn role(&self) -> &str
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that Amazon S3 assumes when replicating objects. For more information, see How to Set Up Replication in the Amazon S3 User Guide.
Sourcepub fn rules(&self) -> &[ReplicationRule]
pub fn rules(&self) -> &[ReplicationRule]
A container for one or more replication rules. A replication configuration must have at least one rule and can contain a maximum of 1,000 rules.
Sourceimpl ReplicationConfiguration
impl ReplicationConfiguration
Sourcepub fn builder() -> ReplicationConfigurationBuilder
pub fn builder() -> ReplicationConfigurationBuilder
Creates a new builder-style object to manufacture ReplicationConfiguration.