#[non_exhaustive]pub struct ReplicationRuleAndOperator {
pub prefix: Option<String>,
pub tags: Option<Vec<Tag>>,
}Expand description
A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter.
For example:
-
If you specify both a
Prefixand aTagfilter, wrap these filters in anAndtag. -
If you specify a filter based on multiple tags, wrap the
Tagelements in anAndtag.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prefix: Option<String>An object key name prefix that identifies the subset of objects to which the rule applies.
An array of tags containing key and value pairs.
Implementations
Sourceimpl ReplicationRuleAndOperator
impl ReplicationRuleAndOperator
Sourcepub fn prefix(&self) -> Option<&str>
pub fn prefix(&self) -> Option<&str>
An object key name prefix that identifies the subset of objects to which the rule applies.
An array of tags containing key and value pairs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl ReplicationRuleAndOperator
impl ReplicationRuleAndOperator
Sourcepub fn builder() -> ReplicationRuleAndOperatorBuilder
pub fn builder() -> ReplicationRuleAndOperatorBuilder
Creates a new builder-style object to manufacture ReplicationRuleAndOperator.