#[non_exhaustive]pub struct RestoreRequest {
pub days: Option<i32>,
pub glacier_job_parameters: Option<GlacierJobParameters>,
pub type: Option<RestoreRequestType>,
pub tier: Option<Tier>,
pub description: Option<String>,
pub select_parameters: Option<SelectParameters>,
pub output_location: Option<OutputLocation>,
}Expand description
Container for restore job parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.days: Option<i32>Lifetime of the active copy in days. Do not use with restores that specify OutputLocation.
The Days element is required for regular restores, and must not be provided for select requests.
glacier_job_parameters: Option<GlacierJobParameters>S3 Glacier related parameters pertaining to this job. Do not use with restores that specify OutputLocation.
type: Option<RestoreRequestType>Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
Type of restore request.
tier: Option<Tier>Retrieval tier at which the restore will be processed.
description: Option<String>The optional description for the job.
select_parameters: Option<SelectParameters>Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
Describes the parameters for Select job types.
output_location: Option<OutputLocation>Describes the location where the restore job's output is stored.
Implementations
Sourceimpl RestoreRequest
impl RestoreRequest
Sourcepub fn days(&self) -> Option<i32>
pub fn days(&self) -> Option<i32>
Lifetime of the active copy in days. Do not use with restores that specify OutputLocation.
The Days element is required for regular restores, and must not be provided for select requests.
Sourcepub fn glacier_job_parameters(&self) -> Option<&GlacierJobParameters>
pub fn glacier_job_parameters(&self) -> Option<&GlacierJobParameters>
S3 Glacier related parameters pertaining to this job. Do not use with restores that specify OutputLocation.
Sourcepub fn type(&self) -> Option<&RestoreRequestType>
pub fn type(&self) -> Option<&RestoreRequestType>
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
Type of restore request.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The optional description for the job.
Sourcepub fn select_parameters(&self) -> Option<&SelectParameters>
pub fn select_parameters(&self) -> Option<&SelectParameters>
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
Describes the parameters for Select job types.
Sourcepub fn output_location(&self) -> Option<&OutputLocation>
pub fn output_location(&self) -> Option<&OutputLocation>
Describes the location where the restore job's output is stored.
Sourceimpl RestoreRequest
impl RestoreRequest
Sourcepub fn builder() -> RestoreRequestBuilder
pub fn builder() -> RestoreRequestBuilder
Creates a new builder-style object to manufacture RestoreRequest.