#[non_exhaustive]pub struct RestoreStatus {
pub is_restore_in_progress: Option<bool>,
pub restore_expiry_date: Option<DateTime>,
}Expand description
Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved. For more information about these storage classes and how to work with archived objects, see Working with archived objects in the Amazon S3 User Guide.
This functionality is not supported for directory buckets. Directory buckets only support EXPRESS_ONEZONE (the S3 Express One Zone storage class) in Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent Access storage class) in Dedicated Local Zones.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_restore_in_progress: Option<bool>Specifies whether the object is currently being restored. If the object restoration is in progress, the header returns the value TRUE. For example:
x-amz-optional-object-attributes: IsRestoreInProgress="true"
If the object restoration has completed, the header returns the value FALSE. For example:
x-amz-optional-object-attributes: IsRestoreInProgress="false", RestoreExpiryDate="2012-12-21T00:00:00.000Z"
If the object hasn't been restored, there is no header response.
restore_expiry_date: Option<DateTime>Indicates when the restored copy will expire. This value is populated only if the object has already been restored. For example:
x-amz-optional-object-attributes: IsRestoreInProgress="false", RestoreExpiryDate="2012-12-21T00:00:00.000Z"
Implementations
Sourceimpl RestoreStatus
impl RestoreStatus
Sourcepub fn is_restore_in_progress(&self) -> Option<bool>
pub fn is_restore_in_progress(&self) -> Option<bool>
Specifies whether the object is currently being restored. If the object restoration is in progress, the header returns the value TRUE. For example:
x-amz-optional-object-attributes: IsRestoreInProgress="true"
If the object restoration has completed, the header returns the value FALSE. For example:
x-amz-optional-object-attributes: IsRestoreInProgress="false", RestoreExpiryDate="2012-12-21T00:00:00.000Z"
If the object hasn't been restored, there is no header response.
Sourcepub fn restore_expiry_date(&self) -> Option<&DateTime>
pub fn restore_expiry_date(&self) -> Option<&DateTime>
Indicates when the restored copy will expire. This value is populated only if the object has already been restored. For example:
x-amz-optional-object-attributes: IsRestoreInProgress="false", RestoreExpiryDate="2012-12-21T00:00:00.000Z"
Sourceimpl RestoreStatus
impl RestoreStatus
Sourcepub fn builder() -> RestoreStatusBuilder
pub fn builder() -> RestoreStatusBuilder
Creates a new builder-style object to manufacture RestoreStatus.