#[non_exhaustive]pub struct RoutingRule {
pub condition: Option<Condition>,
pub redirect: Option<Redirect>,
}Expand description
Specifies the redirect behavior and when a redirect is applied. For more information about routing rules, see Configuring advanced conditional redirects in the Amazon S3 User Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.condition: Option<Condition>A container for describing a condition that must be met for the specified redirect to apply. For example, 1. If request is for pages in the /docs folder, redirect to the /documents folder. 2. If request results in HTTP error 4xx, redirect request to another host where you might process the error.
redirect: Option<Redirect>Container for redirect information. You can redirect requests to another host, to another page, or with another protocol. In the event of an error, you can specify a different error code to return.
Implementations
Sourceimpl RoutingRule
impl RoutingRule
Sourcepub fn condition(&self) -> Option<&Condition>
pub fn condition(&self) -> Option<&Condition>
A container for describing a condition that must be met for the specified redirect to apply. For example, 1. If request is for pages in the /docs folder, redirect to the /documents folder. 2. If request results in HTTP error 4xx, redirect request to another host where you might process the error.
Sourceimpl RoutingRule
impl RoutingRule
Sourcepub fn builder() -> RoutingRuleBuilder
pub fn builder() -> RoutingRuleBuilder
Creates a new builder-style object to manufacture RoutingRule.