#[non_exhaustive]pub struct S3Location {
pub bucket_name: String,
pub prefix: String,
pub encryption: Option<Encryption>,
pub canned_acl: Option<ObjectCannedAcl>,
pub access_control_list: Option<Vec<Grant>>,
pub tagging: Option<Tagging>,
pub user_metadata: Option<Vec<MetadataEntry>>,
pub storage_class: Option<StorageClass>,
}Expand description
Describes an Amazon S3 location that will receive the results of the restore request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket_name: StringThe name of the bucket where the restore results will be placed.
prefix: StringThe prefix that is prepended to the restore results for this request.
encryption: Option<Encryption>Contains the type of server-side encryption used.
canned_acl: Option<ObjectCannedAcl>The canned ACL to apply to the restore results.
access_control_list: Option<Vec<Grant>>A list of grants that control access to the staged results.
tagging: Option<Tagging>The tag-set that is applied to the restore results.
user_metadata: Option<Vec<MetadataEntry>>A list of metadata to store with the restore results in S3.
storage_class: Option<StorageClass>The class of storage used to store the restore results.
Implementations
Sourceimpl S3Location
impl S3Location
Sourcepub fn bucket_name(&self) -> &str
pub fn bucket_name(&self) -> &str
The name of the bucket where the restore results will be placed.
Sourcepub fn prefix(&self) -> &str
pub fn prefix(&self) -> &str
The prefix that is prepended to the restore results for this request.
Sourcepub fn encryption(&self) -> Option<&Encryption>
pub fn encryption(&self) -> Option<&Encryption>
Contains the type of server-side encryption used.
Sourcepub fn canned_acl(&self) -> Option<&ObjectCannedAcl>
pub fn canned_acl(&self) -> Option<&ObjectCannedAcl>
The canned ACL to apply to the restore results.
Sourcepub fn access_control_list(&self) -> &[Grant]
pub fn access_control_list(&self) -> &[Grant]
A list of grants that control access to the staged results.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .access_control_list.is_none().
Sourcepub fn user_metadata(&self) -> &[MetadataEntry]
pub fn user_metadata(&self) -> &[MetadataEntry]
A list of metadata to store with the restore results in S3.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .user_metadata.is_none().
Sourcepub fn storage_class(&self) -> Option<&StorageClass>
pub fn storage_class(&self) -> Option<&StorageClass>
The class of storage used to store the restore results.
Sourceimpl S3Location
impl S3Location
Sourcepub fn builder() -> S3LocationBuilder
pub fn builder() -> S3LocationBuilder
Creates a new builder-style object to manufacture S3Location.