#[non_exhaustive]pub struct S3TablesDestination {
pub table_bucket_arn: String,
pub table_name: String,
}Expand description
The destination information for a V1 S3 Metadata configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_bucket_arn: StringThe Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
table_name: StringThe name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Implementations
Sourceimpl S3TablesDestination
impl S3TablesDestination
Sourcepub fn table_bucket_arn(&self) -> &str
pub fn table_bucket_arn(&self) -> &str
The Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
The name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourceimpl S3TablesDestination
impl S3TablesDestination
Sourcepub fn builder() -> S3TablesDestinationBuilder
pub fn builder() -> S3TablesDestinationBuilder
Creates a new builder-style object to manufacture S3TablesDestination.