#[non_exhaustive]pub struct S3TablesDestinationResult {
pub table_bucket_arn: String,
pub table_name: String,
pub table_arn: String,
pub table_namespace: String,
}Expand description
The destination information for a V1 S3 Metadata configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_bucket_arn: StringThe Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
table_name: StringThe name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
table_arn: StringThe Amazon Resource Name (ARN) for the metadata table in the metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
table_namespace: StringThe table bucket namespace for the metadata table in your metadata table configuration. This value is always aws_s3_metadata.
Implementations
Sourceimpl S3TablesDestinationResult
impl S3TablesDestinationResult
Sourcepub fn table_bucket_arn(&self) -> &str
pub fn table_bucket_arn(&self) -> &str
The Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket.
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
The name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn table_arn(&self) -> &str
pub fn table_arn(&self) -> &str
The Amazon Resource Name (ARN) for the metadata table in the metadata table configuration. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.
Sourcepub fn table_namespace(&self) -> &str
pub fn table_namespace(&self) -> &str
The table bucket namespace for the metadata table in your metadata table configuration. This value is always aws_s3_metadata.
Sourceimpl S3TablesDestinationResult
impl S3TablesDestinationResult
Sourcepub fn builder() -> S3TablesDestinationResultBuilder
pub fn builder() -> S3TablesDestinationResultBuilder
Creates a new builder-style object to manufacture S3TablesDestinationResult.