#[non_exhaustive]pub struct ServerSideEncryptionRule {
pub apply_server_side_encryption_by_default: Option<ServerSideEncryptionByDefault>,
pub bucket_key_enabled: Option<bool>,
pub blocked_encryption_types: Option<BlockedEncryptionTypes>,
}Expand description
Specifies the default server-side encryption configuration.
-
General purpose buckets - If you're specifying a customer managed KMS key, we recommend using a fully qualified KMS key ARN. If you use a KMS key alias instead, then KMS resolves the key within the requester’s account. This behavior can result in data that's encrypted with a KMS key that belongs to the requester, and not the bucket owner.
-
Directory buckets - When you specify an KMS customer managed key for encryption in your directory bucket, only use the key ID or key ARN. The key alias format of the KMS key isn't supported.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.apply_server_side_encryption_by_default: Option<ServerSideEncryptionByDefault>Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
bucket_key_enabled: Option<bool>Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Setting the BucketKeyEnabled element to true causes Amazon S3 to use an S3 Bucket Key.
-
General purpose buckets - By default, S3 Bucket Key is not enabled. For more information, see Amazon S3 Bucket Keys in the Amazon S3 User Guide.
-
Directory buckets - S3 Bucket Keys are always enabled for
GETandPUToperations in a directory bucket and can’t be disabled. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through CopyObject, UploadPartCopy, the Copy operation in Batch Operations, or the import jobs. In this case, Amazon S3 makes a call to KMS every time a copy request is made for a KMS-encrypted object.
blocked_encryption_types: Option<BlockedEncryptionTypes>A bucket-level setting for Amazon S3 general purpose buckets used to prevent the upload of new objects encrypted with the specified server-side encryption type. For example, blocking an encryption type will block PutObject, CopyObject, PostObject, multipart upload, and replication requests to the bucket for objects with the specified encryption type. However, you can continue to read and list any pre-existing objects already encrypted with the specified encryption type. For more information, see Blocking or unblocking SSE-C for a general purpose bucket.
Currently, this parameter only supports blocking or unblocking server-side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
Implementations
Sourceimpl ServerSideEncryptionRule
impl ServerSideEncryptionRule
Sourcepub fn apply_server_side_encryption_by_default(
&self,
) -> Option<&ServerSideEncryptionByDefault>
pub fn apply_server_side_encryption_by_default( &self, ) -> Option<&ServerSideEncryptionByDefault>
Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
Sourcepub fn bucket_key_enabled(&self) -> Option<bool>
pub fn bucket_key_enabled(&self) -> Option<bool>
Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Setting the BucketKeyEnabled element to true causes Amazon S3 to use an S3 Bucket Key.
-
General purpose buckets - By default, S3 Bucket Key is not enabled. For more information, see Amazon S3 Bucket Keys in the Amazon S3 User Guide.
-
Directory buckets - S3 Bucket Keys are always enabled for
GETandPUToperations in a directory bucket and can’t be disabled. S3 Bucket Keys aren't supported, when you copy SSE-KMS encrypted objects from general purpose buckets to directory buckets, from directory buckets to general purpose buckets, or between directory buckets, through CopyObject, UploadPartCopy, the Copy operation in Batch Operations, or the import jobs. In this case, Amazon S3 makes a call to KMS every time a copy request is made for a KMS-encrypted object.
Sourcepub fn blocked_encryption_types(&self) -> Option<&BlockedEncryptionTypes>
pub fn blocked_encryption_types(&self) -> Option<&BlockedEncryptionTypes>
A bucket-level setting for Amazon S3 general purpose buckets used to prevent the upload of new objects encrypted with the specified server-side encryption type. For example, blocking an encryption type will block PutObject, CopyObject, PostObject, multipart upload, and replication requests to the bucket for objects with the specified encryption type. However, you can continue to read and list any pre-existing objects already encrypted with the specified encryption type. For more information, see Blocking or unblocking SSE-C for a general purpose bucket.
Currently, this parameter only supports blocking or unblocking server-side encryption with customer-provided keys (SSE-C). For more information about SSE-C, see Using server-side encryption with customer-provided keys (SSE-C).
Sourceimpl ServerSideEncryptionRule
impl ServerSideEncryptionRule
Sourcepub fn builder() -> ServerSideEncryptionRuleBuilder
pub fn builder() -> ServerSideEncryptionRuleBuilder
Creates a new builder-style object to manufacture ServerSideEncryptionRule.