#[non_exhaustive]pub struct SourceSelectionCriteria {
pub sse_kms_encrypted_objects: Option<SseKmsEncryptedObjects>,
pub replica_modifications: Option<ReplicaModifications>,
}Expand description
A container that describes additional filters for identifying the source objects that you want to replicate. You can choose to enable or disable the replication of these objects. Currently, Amazon S3 supports only the filter that you can specify for objects created with server-side encryption using a customer managed key stored in Amazon Web Services Key Management Service (SSE-KMS).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sse_kms_encrypted_objects: Option<SseKmsEncryptedObjects>A container for filter information for the selection of Amazon S3 objects encrypted with Amazon Web Services KMS. If you include SourceSelectionCriteria in the replication configuration, this element is required.
replica_modifications: Option<ReplicaModifications>A filter that you can specify for selections for modifications on replicas. Amazon S3 doesn't replicate replica modifications by default. In the latest version of replication configuration (when Filter is specified), you can specify this element and set the status to Enabled to replicate modifications on replicas.
If you don't specify the Filter element, Amazon S3 assumes that the replication configuration is the earlier version, V1. In the earlier version, this element is not allowed
Implementations
Sourceimpl SourceSelectionCriteria
impl SourceSelectionCriteria
Sourcepub fn sse_kms_encrypted_objects(&self) -> Option<&SseKmsEncryptedObjects>
pub fn sse_kms_encrypted_objects(&self) -> Option<&SseKmsEncryptedObjects>
A container for filter information for the selection of Amazon S3 objects encrypted with Amazon Web Services KMS. If you include SourceSelectionCriteria in the replication configuration, this element is required.
Sourcepub fn replica_modifications(&self) -> Option<&ReplicaModifications>
pub fn replica_modifications(&self) -> Option<&ReplicaModifications>
A filter that you can specify for selections for modifications on replicas. Amazon S3 doesn't replicate replica modifications by default. In the latest version of replication configuration (when Filter is specified), you can specify this element and set the status to Enabled to replicate modifications on replicas.
If you don't specify the Filter element, Amazon S3 assumes that the replication configuration is the earlier version, V1. In the earlier version, this element is not allowed
Sourceimpl SourceSelectionCriteria
impl SourceSelectionCriteria
Sourcepub fn builder() -> SourceSelectionCriteriaBuilder
pub fn builder() -> SourceSelectionCriteriaBuilder
Creates a new builder-style object to manufacture SourceSelectionCriteria.