#[non_exhaustive]pub struct Stats {
pub bytes_scanned: Option<i64>,
pub bytes_processed: Option<i64>,
pub bytes_returned: Option<i64>,
}Expand description
Container for the stats details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bytes_scanned: Option<i64>The total number of object bytes scanned.
bytes_processed: Option<i64>The total number of uncompressed object bytes processed.
bytes_returned: Option<i64>The total number of bytes of records payload data returned.
Implementations
Sourceimpl Stats
impl Stats
Sourcepub fn bytes_scanned(&self) -> Option<i64>
pub fn bytes_scanned(&self) -> Option<i64>
The total number of object bytes scanned.
Sourcepub fn bytes_processed(&self) -> Option<i64>
pub fn bytes_processed(&self) -> Option<i64>
The total number of uncompressed object bytes processed.
Sourcepub fn bytes_returned(&self) -> Option<i64>
pub fn bytes_returned(&self) -> Option<i64>
The total number of bytes of records payload data returned.