#[non_exhaustive]pub struct TopicConfiguration {
pub id: Option<String>,
pub topic_arn: String,
pub events: Vec<Event>,
pub filter: Option<NotificationConfigurationFilter>,
}Expand description
A container for specifying the configuration for publication of messages to an Amazon Simple Notification Service (Amazon SNS) topic when Amazon S3 detects specified events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
topic_arn: StringThe Amazon Resource Name (ARN) of the Amazon SNS topic to which Amazon S3 publishes a message when it detects events of the specified type.
events: Vec<Event>The Amazon S3 bucket event about which to send notifications. For more information, see Supported Event Types in the Amazon S3 User Guide.
filter: Option<NotificationConfigurationFilter>Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
Implementations
Sourceimpl TopicConfiguration
impl TopicConfiguration
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
Sourcepub fn topic_arn(&self) -> &str
pub fn topic_arn(&self) -> &str
The Amazon Resource Name (ARN) of the Amazon SNS topic to which Amazon S3 publishes a message when it detects events of the specified type.
Sourcepub fn events(&self) -> &[Event]
pub fn events(&self) -> &[Event]
The Amazon S3 bucket event about which to send notifications. For more information, see Supported Event Types in the Amazon S3 User Guide.
Sourcepub fn filter(&self) -> Option<&NotificationConfigurationFilter>
pub fn filter(&self) -> Option<&NotificationConfigurationFilter>
Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
Sourceimpl TopicConfiguration
impl TopicConfiguration
Sourcepub fn builder() -> TopicConfigurationBuilder
pub fn builder() -> TopicConfigurationBuilder
Creates a new builder-style object to manufacture TopicConfiguration.