#[non_exhaustive]pub struct Transition {
pub date: Option<DateTime>,
pub days: Option<i32>,
pub storage_class: Option<TransitionStorageClass>,
}Expand description
Specifies when an object transitions to a specified storage class. For more information about Amazon S3 lifecycle configuration rules, see Transitioning Objects Using Amazon S3 Lifecycle in the Amazon S3 User Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.date: Option<DateTime>Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
days: Option<i32>Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE, valid values are 0 or positive integers. If the specified storage class is STANDARD_IA or ONEZONE_IA, valid values are positive integers greater than 30. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see Constraints and considerations for transitions in the Amazon S3 User Guide.
storage_class: Option<TransitionStorageClass>The storage class to which you want the object to transition.
Implementations
Sourceimpl Transition
impl Transition
Sourcepub fn date(&self) -> Option<&DateTime>
pub fn date(&self) -> Option<&DateTime>
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
Sourcepub fn days(&self) -> Option<i32>
pub fn days(&self) -> Option<i32>
Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE, valid values are 0 or positive integers. If the specified storage class is STANDARD_IA or ONEZONE_IA, valid values are positive integers greater than 30. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see Constraints and considerations for transitions in the Amazon S3 User Guide.
Sourcepub fn storage_class(&self) -> Option<&TransitionStorageClass>
pub fn storage_class(&self) -> Option<&TransitionStorageClass>
The storage class to which you want the object to transition.
Sourceimpl Transition
impl Transition
Sourcepub fn builder() -> TransitionBuilder
pub fn builder() -> TransitionBuilder
Creates a new builder-style object to manufacture Transition.