#[non_exhaustive]pub struct WebsiteConfiguration {
pub error_document: Option<ErrorDocument>,
pub index_document: Option<IndexDocument>,
pub redirect_all_requests_to: Option<RedirectAllRequestsTo>,
pub routing_rules: Option<Vec<RoutingRule>>,
}Expand description
Specifies website configuration parameters for an Amazon S3 bucket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_document: Option<ErrorDocument>The name of the error document for the website.
index_document: Option<IndexDocument>The name of the index document for the website.
redirect_all_requests_to: Option<RedirectAllRequestsTo>The redirect behavior for every request to this bucket's website endpoint.
If you specify this property, you can't specify any other property.
routing_rules: Option<Vec<RoutingRule>>Rules that define when a redirect is applied and the redirect behavior.
Implementations
Sourceimpl WebsiteConfiguration
impl WebsiteConfiguration
Sourcepub fn error_document(&self) -> Option<&ErrorDocument>
pub fn error_document(&self) -> Option<&ErrorDocument>
The name of the error document for the website.
Sourcepub fn index_document(&self) -> Option<&IndexDocument>
pub fn index_document(&self) -> Option<&IndexDocument>
The name of the index document for the website.
Sourcepub fn redirect_all_requests_to(&self) -> Option<&RedirectAllRequestsTo>
pub fn redirect_all_requests_to(&self) -> Option<&RedirectAllRequestsTo>
The redirect behavior for every request to this bucket's website endpoint.
If you specify this property, you can't specify any other property.
Sourcepub fn routing_rules(&self) -> &[RoutingRule]
pub fn routing_rules(&self) -> &[RoutingRule]
Rules that define when a redirect is applied and the redirect behavior.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .routing_rules.is_none().
Sourceimpl WebsiteConfiguration
impl WebsiteConfiguration
Sourcepub fn builder() -> WebsiteConfigurationBuilder
pub fn builder() -> WebsiteConfigurationBuilder
Creates a new builder-style object to manufacture WebsiteConfiguration.