AirInventory

Struct AirInventory 

pub struct AirInventory<SC: StarkProtocolConfig> { /* private fields */ }

Implementations

Source

impl<SC: StarkProtocolConfig> AirInventory<SC>

pub fn config(&self) -> &SystemConfig

pub fn system(&self) -> &SystemAirInventory

The system AIRs required by the circuit architecture.

pub fn ext_airs(&self) -> &Vec<AirRefWithColumns<SC>>

List of all non-system AIRs in the circuit, in insertion order, which is the reverse of the order they appear in the verifying key.

Note that the system will ensure that the first AIR in the list is always the [VariableRangeCheckerAir].

Source

impl<SC: StarkProtocolConfig> AirInventory<SC>

pub fn start_new_extension(&mut self)

This should be called exactly once at the start of the declaration of a new extension.

pub fn new_bus_idx(&mut self) -> BusIndex

pub fn find_air<A: 'static>(&self) -> impl Iterator<Item = &A>

Looks through already-defined AIRs to see if there exists any of type A by downcasting. Returns all chips of type A in the circuit.

This should not be used to look for system AIRs.

pub fn add_air<A: AnyAirWithColumns<SC> + 'static>(&mut self, air: A)

pub fn add_air_ref(&mut self, air: AirRefWithColumns<SC>)

pub fn range_checker(&self) -> &VariableRangeCheckerAir

pub fn into_airs(self) -> impl Iterator<Item = AirRefWithColumns<SC>>

The AIRs in the order they appear in the verifying key. This is the system AIRs, followed by the other AIRs in the reverse of the order they were added in the VM extension definitions. In particular, the AIRs that have dependencies appear later. The system guarantees that the last AIR is the [VariableRangeCheckerAir].

pub fn keygen(self, config: &SC) -> MultiStarkProvingKey<SC>

Generates the proving key for this circuit, marking the system AIRs that must be present in any valid proof (see SystemConfig::is_required_air_id) as required.

pub fn num_airs(&self) -> usize

This is O(1). Returns the total number of AIRs and equals the length of Self::into_airs.

pub fn pointer_max_bits(&self) -> usize

Returns the maximum number of bits used to represent addresses in memory