ChipInventory

Struct ChipInventory 

pub struct ChipInventory<SC, RA, PB>
where SC: StarkProtocolConfig, PB: ProverBackend,
{ pub executor_idx_to_insertion_idx: Vec<usize>, /* private fields */ }

Fields

executor_idx_to_insertion_idx: Vec<usize>

Mapping from executor index to chip insertion index. Chips must be added in order so the chip insertion index matches the AIR insertion index. Reminder: this is in reverse order of the verifying key AIR ordering.

Note: if public values chip exists, then it will be the first entry and point to usize::MAX. This entry should never be used.

Implementations

Source

impl<SC, RA, PB> ChipInventory<SC, RA, PB>
where SC: StarkProtocolConfig, PB: ProverBackend,

pub fn airs(&self) -> &AirInventory<SC>

Read-only view of AIRs, as constructed via the VmCircuitExtension trait.

pub fn chips(&self) -> &Vec<Box<dyn AnyChip<RA, PB>>>

Chips that are being built.

Source

impl<SC, RA, PB> ChipInventory<SC, RA, PB>
where SC: StarkProtocolConfig, PB: ProverBackend,

pub fn new(airs: AirInventory<SC>) -> Self

pub fn config(&self) -> &SystemConfig

pub fn start_new_extension(&mut self) -> Result<(), ChipInventoryError>

pub fn next_air<A: 'static>(&self) -> Result<&A, ChipInventoryError>

Gets the next AIR from the pre-existing AIR inventory according to the index of the next chip to be built.

pub fn find_chip<C: 'static>(&self) -> impl Iterator<Item = &C>

Looks through built chips to see if there exists any of type C by downcasting. Returns all chips of type C in the chipset.

Note: the type C will usually be a smart pointer to a chip.

pub fn add_periphery_chip<C: Chip<RA, PB> + 'static>(&mut self, chip: C)

Adds a chip that is not associated with any executor, as defined by the VmExecutionExtension trait.

pub fn add_executor_chip<C: Chip<RA, PB> + 'static>(&mut self, chip: C)

Adds a chip and associates it to the next executor. Caution: you must add chips in the order matching the order that executors were added in the VmExecutionExtension implementation.

pub fn executor_idx_to_air_idx(&self) -> Vec<usize>

Returns the mapping from executor index to the AIR index, where AIR index is the index of the AIR within the verifying key.

This should only be called after the ChipInventory is fully built.

pub fn timestamp_max_bits(&self) -> usize

pub fn constant_trace_heights(&self) -> Vec<Option<usize>>

Returns constant trace heights for all AIRs in verifying key order. System AIRs get None (their constant heights are handled separately). Extension chips follow in the same order as AIRs in the verifying key (reversed insertion order).

Source

impl<SC, RA> ChipInventory<SC, RA, CpuBackend<SC>>
where SC: StarkProtocolConfig,

pub fn range_checker( &self, ) -> Result<&SharedVariableRangeCheckerChip, ChipInventoryError>