pub struct DenseRecordArena {
pub records_buffer: Cursor<Vec<u8>>,
}Fields
records_buffer: Cursor<Vec<u8>>Implementations
Sourceimpl DenseRecordArena
impl DenseRecordArena
Sourcepub fn with_byte_capacity(size_bytes: usize) -> Self
pub fn with_byte_capacity(size_bytes: usize) -> Self
Creates a new DenseRecordArena with the given capacity in bytes.
pub fn set_byte_capacity(&mut self, size_bytes: usize)
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the allocated size of the arena in bytes.
Note: This may include additional bytes for alignment.
Sourcepub fn alloc_bytes<'a>(&mut self, count: usize) -> &'a mut [u8] ⓘ
pub fn alloc_bytes<'a>(&mut self, count: usize) -> &'a mut [u8] ⓘ
Allocates count bytes and returns as a mutable slice.
pub fn allocated(&self) -> &[u8] ⓘ
pub fn allocated_mut(&mut self) -> &mut [u8] ⓘ
pub fn align_to(&mut self, alignment: usize)
pub fn get_record_seeker<R, L>( &mut self, ) -> RecordSeeker<'_, DenseRecordArena, R, L>