Arena

Trait Arena 

pub trait Arena {
    // Required methods
    fn with_capacity(height: usize, width: usize) -> Self;
    fn is_empty(&self) -> bool;

    // Provided methods
    fn current_trace_height(&self) -> usize { ... }
    fn allocated_bytes(&self) -> Option<usize> { ... }
}

Required Methods

fn with_capacity(height: usize, width: usize) -> Self

Currently width always refers to the main trace width.

fn is_empty(&self) -> bool

Provided Methods

fn current_trace_height(&self) -> usize

Only used for metric collection purposes. Intended usage is that for a record arena that corresponds to a single trace matrix, this function can extract the current number of used rows of the corresponding trace matrix. This is currently expected to work only for MatrixRecordArena.

fn allocated_bytes(&self) -> Option<usize>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors