pub struct VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,{
pub engine: E,
/* private fields */
}Expand description
The VirtualMachine struct contains the API to generate proofs for arbitrary programs for a
fixed set of OpenVM instructions and a fixed VM circuit corresponding to those instructions. The
API is specific to a particular [StarkEngine], which specifies a fixed [StarkProtocolConfig] and
[ProverBackend] via associated types. The VmBuilder also fixes the choice of
RecordArena associated to the prover backend via an associated type.
In other words, this struct is the zkVM.
Fields
engine: EProving engine
Implementations
Sourceimpl<E, VB> VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,
impl<E, VB> VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,
Sourceimpl<E, VB> VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,
impl<E, VB> VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,
Sourceimpl<E, VB> VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,
impl<E, VB> VirtualMachine<E, VB>where
E: StarkEngine,
VB: VmBuilder<E>,
pub fn new( engine: E, builder: VB, config: VB::VmConfig, d_pk: DeviceMultiStarkProvingKey<E::PB>, ) -> Result<Self, VirtualMachineError>
pub fn new_with_keygen( engine: E, builder: VB, config: VB::VmConfig, ) -> Result<(Self, MultiStarkProvingKey<E::SC>), VirtualMachineError>
pub fn config(&self) -> &VB::VmConfig
Sourcepub fn interpreter(
&self,
exe: &VmExe<Val<E::SC>>,
) -> Result<InterpretedInstance<'_, Val<E::SC>, ExecutionCtx>, StaticProgramError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: Executor<Val<E::SC>>,
pub fn interpreter(
&self,
exe: &VmExe<Val<E::SC>>,
) -> Result<InterpretedInstance<'_, Val<E::SC>, ExecutionCtx>, StaticProgramError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: Executor<Val<E::SC>>,
Pure interpreter.
pub fn metered_interpreter(
&self,
exe: &VmExe<Val<E::SC>>,
) -> Result<InterpretedInstance<'_, Val<E::SC>, MeteredCtx>, StaticProgramError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: MeteredExecutor<Val<E::SC>>,
pub fn metered_cost_interpreter(
&self,
exe: &VmExe<Val<E::SC>>,
) -> Result<InterpretedInstance<'_, Val<E::SC>, MeteredCostCtx>, StaticProgramError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: MeteredExecutor<Val<E::SC>>,
pub fn preflight_interpreter( &self, exe: &VmExe<Val<E::SC>>, ) -> Result<PreflightInterpretedInstance<Val<E::SC>, <VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor>, StaticProgramError>
Sourcepub fn execute_preflight(
&self,
interpreter: &mut PreflightInterpretedInstance<Val<E::SC>, <VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor>,
state: VmState<Val<E::SC>, GuestMemory>,
num_insns: Option<u64>,
trace_heights: &[u32],
) -> Result<PreflightExecutionOutput<Val<E::SC>, VB::RecordArena>, ExecutionError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: PreflightExecutor<Val<E::SC>, VB::RecordArena>,
pub fn execute_preflight(
&self,
interpreter: &mut PreflightInterpretedInstance<Val<E::SC>, <VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor>,
state: VmState<Val<E::SC>, GuestMemory>,
num_insns: Option<u64>,
trace_heights: &[u32],
) -> Result<PreflightExecutionOutput<Val<E::SC>, VB::RecordArena>, ExecutionError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: PreflightExecutor<Val<E::SC>, VB::RecordArena>,
Preflight execution for a single segment. Executes for exactly num_insns instructions
using an interpreter. Preflight execution must be provided with trace_heights
instrumentation data that was collected from a previous run of metered execution so that the
preflight execution knows how much memory to allocate for record arenas.
This function should rarely be called on its own. Users are advised to call
prove directly.
Sourcepub fn create_initial_state(
&self,
exe: &VmExe<Val<E::SC>>,
inputs: impl Into<Streams<Val<E::SC>>>,
) -> VmState<Val<E::SC>, GuestMemory>
pub fn create_initial_state( &self, exe: &VmExe<Val<E::SC>>, inputs: impl Into<Streams<Val<E::SC>>>, ) -> VmState<Val<E::SC>, GuestMemory>
Calls VmState::initial but sets more information for
performance metrics when feature “perf-metrics” is enabled.
Sourcepub fn generate_proving_ctx(
&mut self,
system_records: SystemRecords<Val<E::SC>>,
record_arenas: Vec<VB::RecordArena>,
) -> Result<ProvingContext<E::PB>, GenerationError>
pub fn generate_proving_ctx( &mut self, system_records: SystemRecords<Val<E::SC>>, record_arenas: Vec<VB::RecordArena>, ) -> Result<ProvingContext<E::PB>, GenerationError>
This function mutates self but should only depend on internal state in the sense that:
- program must already be loaded as cached trace via
load_program. - initial memory image was already sent to device via
transport_init_memory_to_device. - all other state should be given by
system_recordsandrecord_arenas
Sourcepub fn prove(
&mut self,
interpreter: &mut PreflightInterpretedInstance<Val<E::SC>, <VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor>,
state: VmState<Val<E::SC>, GuestMemory>,
num_insns: Option<u64>,
trace_heights: &[u32],
) -> Result<(Proof<E::SC>, Option<GuestMemory>), VirtualMachineError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: PreflightExecutor<Val<E::SC>, VB::RecordArena>,
pub fn prove(
&mut self,
interpreter: &mut PreflightInterpretedInstance<Val<E::SC>, <VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor>,
state: VmState<Val<E::SC>, GuestMemory>,
num_insns: Option<u64>,
trace_heights: &[u32],
) -> Result<(Proof<E::SC>, Option<GuestMemory>), VirtualMachineError>where
Val<E::SC>: PrimeField32,
<VB::VmConfig as VmExecutionConfig<Val<E::SC>>>::Executor: PreflightExecutor<Val<E::SC>, VB::RecordArena>,
Generates proof for zkVM execution for exactly num_insns instructions for a given program
and a given starting state.
Note: The cached program trace must be loaded via load_program
before calling this function.
Returns:
- proof for the execution segment
- final memory state only if execution ends in successful termination (exit code 0). This final memory state may be used to extract user public values afterwards.
Sourcepub fn commit_program_on_device(
&self,
program: &Program<Val<E::SC>>,
) -> CommittedTraceData<E::PB>
pub fn commit_program_on_device( &self, program: &Program<Val<E::SC>>, ) -> CommittedTraceData<E::PB>
Transforms the program into a cached trace and commits it on device using the proof system polynomial commitment scheme.
Returns the cached program trace.
Note that load_program must be called separately to load the cached
program trace into the VM itself.
Sourcepub fn load_program(&mut self, cached_program_trace: CommittedTraceData<E::PB>)
pub fn load_program(&mut self, cached_program_trace: CommittedTraceData<E::PB>)
Loads cached program trace into the VM.
pub fn transport_init_memory_to_device(&mut self, memory: &GuestMemory)
Sourcepub fn memory_top_tree(&self) -> Option<&[[Val<E::SC>; 8]]>
pub fn memory_top_tree(&self) -> Option<&[[Val<E::SC>; 8]]>
pub fn executor_idx_to_air_idx(&self) -> Vec<usize>
Sourcepub fn build_metered_ctx(&self, exe: &VmExe<Val<E::SC>>) -> MeteredCtxwhere
Val<E::SC>: PrimeField32,
pub fn build_metered_ctx(&self, exe: &VmExe<Val<E::SC>>) -> MeteredCtxwhere
Val<E::SC>: PrimeField32,
Convenience method to construct a MeteredCtx using data from the stored proving key.
Sourcepub fn build_metered_cost_ctx(&self) -> MeteredCostCtx
pub fn build_metered_cost_ctx(&self) -> MeteredCostCtx
Convenience method to construct a MeteredCostCtx using data from the stored proving key.
pub fn num_airs(&self) -> usize
pub fn air_names(&self) -> impl Iterator<Item = &str>
Sourceimpl<E, VC> VirtualMachine<E, VC>
impl<E, VC> VirtualMachine<E, VC>
Sourcepub fn override_system_trace_heights(&mut self, heights: &[u32])
pub fn override_system_trace_heights(&mut self, heights: &[u32])
Sets fixed trace heights for the system AIRs’ trace matrices.