SystemWithFixedTraceHeights

Trait SystemWithFixedTraceHeights 

pub trait SystemWithFixedTraceHeights {
    // Required method
    fn override_trace_heights(&mut self, heights: &[u32]);
}
Trait meant to be implemented on a SystemChipComplex.

Required Methods

fn override_trace_heights(&mut self, heights: &[u32])

heights will have length equal to number of system AIRs, in AIR ID order. This function must guarantee that the system trace matrices generated have the required heights.

Implementors

Source

impl<SC: StarkProtocolConfig> SystemWithFixedTraceHeights for SystemChipInventory<SC>
where Val<SC>: VmField,