generate_cols_from_leaf_children

Function generate_cols_from_leaf_children 

pub fn generate_cols_from_leaf_children(
    leaf_children: Vec<([F; 8], [F; 8])>,
    tagged: bool,
) -> Vec<MerkleTreeCols<F>>
Build Merkle-tree rows from leaf (left_child, right_child) inputs using Poseidon2 compression over BabyBear.

The number of leaf rows must be a power of two and non-zero. The returned vector has length 2 * num_leaves, with the final row being the terminal row (send_type = receive_type = 0).