hash_slice_trace

Function hash_slice_trace 

pub fn hash_slice_trace(
    elements: &[[F; 8]],
    poseidon2_permute_inputs: Option<&mut Vec<[F; 16]>>,
    poseidon2_compress_inputs: Option<&mut Vec<[F; 16]>>,
) -> (Vec<[F; 16]>, [F; 8])
Given N element digests, compute the N−1 intermediate full permutation states and the final digest, matching the layout of HashSliceCtx.

If provided, the pre-permutation inputs for the first N−1 elements are appended to poseidon2_permute_inputs, and the pre-permutation input for the last element is appended to poseidon2_compress_inputs.