pub struct PublicKey<C: IntrinsicCurve> { /* private fields */ }Implementations
Sourceimpl<C: IntrinsicCurve> PublicKey<C>where
C::Point: WeierstrassPoint + Group + FromCompressed<<<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate>,
<<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate: IntMod,
impl<C: IntrinsicCurve> PublicKey<C>where
C::Point: WeierstrassPoint + Group + FromCompressed<<<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate>,
<<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate: IntMod,
Sourcepub fn from_affine(point: <C as IntrinsicCurve>::Point) -> Result<Self>
pub fn from_affine(point: <C as IntrinsicCurve>::Point) -> Result<Self>
Convert an AffinePoint into a PublicKey.
In addition, for Coordinate<C> implementing IntMod, this function will assert that the
affine coordinates of point are both in canonical form.
This does not check that point is on the curve. Use this only with points that have
already been checked. For public keys from untrusted bytes, use Self::from_sec1_bytes.
Sourcepub fn from_sec1_bytes(bytes: &[u8]) -> Result<Self>where
for<'a> &'a <<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate: Mul<&'a <<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate, Output = <<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate>,
pub fn from_sec1_bytes(bytes: &[u8]) -> Result<Self>where
for<'a> &'a <<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate: Mul<&'a <<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate, Output = <<C as IntrinsicCurve>::Point as WeierstrassPoint>::Coordinate>,
Safety
- The uncompressed deserialization checks that the point is on the curve but does not perform any additional subgroup checks.
pub fn to_sec1_bytes(&self, compress: bool) -> Vec<u8> ⓘ
pub fn as_affine(&self) -> &<C as IntrinsicCurve>::Point
pub fn into_affine(self) -> <C as IntrinsicCurve>::Point