Trait FromCompressed

pub trait FromCompressed<Coordinate> {
    // Required method
    fn decompress(x: Coordinate, rec_id: &u8) -> Option<Self>
       where Self: Sized;
}

Required Methods

fn decompress(x: Coordinate, rec_id: &u8) -> Option<Self>
where Self: Sized,

Given x-coordinate,

Decompresses a point from its x-coordinate and a recovery identifier which indicates the parity of the y-coordinate. Given the x-coordinate, this function attempts to find the corresponding y-coordinate that satisfies the elliptic curve equation. If successful, it returns the point as an instance of Self. If the point cannot be decompressed, it returns None.

Safety

This function does not perform subgroup checks and only checks whether the point is on the curve.

Implementors