#[repr(C)]pub struct KeccakfOpCols<T> {
pub pc: T,
pub is_valid: T,
pub timestamp: T,
pub rd_ptr: T,
pub buffer_ptr_limbs: [T; 4],
pub preimage: [T; 200],
pub postimage: [T; 200],
pub rd_aux: MemoryReadAuxCols<T>,
pub buffer_word_aux: [MemoryBaseAuxCols<T>; 50],
}Fields
pc: TProgram counter
is_valid: TTrue on the row handling execution for an instruction.
timestamp: TThe starting timestamp for execution in this row. A single row will do multiple memory accesses.
rd_ptr: TPointer to address space 1 rd register.
The rd register holds the value of buffer_ptr.
buffer_ptr_limbs: [T; 4]buffer_ptr <- [rd_ptr:4]_1.
Limbs of the pointer to address space 2 buffer.
preimage: [T; 200]The preimage state, to be permuted in the keccakf operation.
postimage: [T; 200]The postimage state after keccakf permute of preimage.
Note: there is 2 row per instruction design where these columns can be shared with
preimage. However due to the interactions necessary for range checks, currently we
determined it is better to minimum number of rows while using more main columns.
rd_aux: MemoryReadAuxCols<T>Auxiliary columns for timestamp checking for the read of [rd_ptr:4]_1.
buffer_word_aux: [MemoryBaseAuxCols<T>; 50]Auxiliary columns for timestamp checking of the writes to buffer. The writes are done one
word at a time, and each write requires a separate previous timestamp.
Implementations