#[repr(C)]pub struct MerkleVerifyBusMessage<T> {
pub merkle_idx_bit_src: T,
pub current_idx_bit_src: T,
pub total_depth: T,
pub height: T,
pub is_leaf: T,
pub leaf_sub_idx: T,
pub value: [T; 8],
pub commit_major: T,
pub commit_minor: T,
}Fields
merkle_idx_bit_src: TThe idx of the merkle proof in the proof, might have additional bits (so not 0 at the root) It will be the same for all the rows in the hashing leaves part.
current_idx_bit_src: TMerkle idx suffix after shifting right max(0, height - k) bits
total_depth: TThe total depth of the merkle proof including the leaves part, equal to merkle_proof.len()
- 1 + k
height: TThe height of this value, [0, k) are for the hashing leaves part, [k, total_depth) are for the merkle proof part.
is_leaf: TBoolean value that indicates if this message is for the hashing leaves or Merkle proof part
leaf_sub_idx: TFor the leaves, it will be 0 ~ 2^k - 1, for the next intermediate values, it will be 0 ~ 2^{k-1} - 1 0 for merkle proof part.
value: [T; 8]Either the leaf hash, or the intermediate hash, or the sibling hash
commit_major: Tcommit_minor: TImplementations