GlobalTraceGenCtx

Trait GlobalTraceGenCtx 

pub trait GlobalTraceGenCtx {
    type ChildVerifyingKey;
    type MultiProof: ?Sized;
    type PreflightRecords: ?Sized;
}
Trait defining the types for the global input shared across modules for trace generation. These types are specialized per hardware backend.

Required Associated Types

type ChildVerifyingKey

Verifying key of the child proof to be verified. This is a multi-trace verifying key.

type MultiProof: ?Sized

Type for a collection of proofs.

type PreflightRecords: ?Sized

Preflight records corresponding to an instance of MultiProof.

Implementors