pub fn write_evm_halo2_verifier_to_folder<P: AsRef<Path>>(
verifier: EvmHalo2Verifier,
folder: P,
version_dir: Option<&str>,
) -> Result<()>Expand description
Writes three Solidity contracts into the following folder structure:
halo2/
└── src/
└── v[OPENVM_VERSION]/
├── interfaces/
│ └── IOpenVmHalo2Verifier.sol
├── OpenVmHalo2Verifier.sol
└── Halo2Verifier.solIf version_dir is Some, it replaces the default v[OPENVM_VERSION] directory name.
If the relevant directories do not exist, they will be created.