compute_deferral_merkle_proofs

Function compute_deferral_merkle_proofs 

pub fn compute_deferral_merkle_proofs(
    memory_dimensions: MemoryDimensions,
    initial_merkle_tree: &MerkleTree<F, DIGEST_SIZE>,
    final_merkle_tree: &MerkleTree<F, DIGEST_SIZE>,
    depth: usize,
) -> DeferralMerkleProofs<F>
Compute deferral merkle proofs from the initial and final memory merkle trees.

Proofs have length overall_height(). When depth > 0, the first depth entries are zeros (skipped levels covered by the deferral subtree). The final deferral subtree is required by the verifier to be rooted at node_idx 0.