pub fn be_limbs_into_word<C: Sha2BlockHasherSubairConfig>(
limbs: &[u32],
) -> C::WordExpand description
Convert a list of limbs in big endian into a Word
pub fn be_limbs_into_word<C: Sha2BlockHasherSubairConfig>(
limbs: &[u32],
) -> C::WordConvert a list of limbs in big endian into a Word