#[repr(C)]pub struct Sha2RoundCols<T, const WORD_BITS: usize, const WORD_U8S: usize, const WORD_U16S: usize, const ROUNDS_PER_ROW: usize, const ROUNDS_PER_ROW_MINUS_ONE: usize, const ROW_VAR_CNT: usize> {
pub flags: Sha2FlagsCols<T, ROW_VAR_CNT>,
pub work_vars: Sha2WorkVarsCols<T, WORD_BITS, ROUNDS_PER_ROW, WORD_U16S>,
pub schedule_helper: Sha2MessageHelperCols<T, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE>,
pub message_schedule: Sha2MessageScheduleCols<T, WORD_BITS, ROUNDS_PER_ROW, WORD_U8S>,
}Expand description
In each SHA block:
- First C::ROUND_ROWS rows use Sha2RoundCols
- Final row uses Sha2DigestCols
For soundness, the AIR enforces that the trace ends in padding rows after the last digest row. Honest traces already satisfy this because the unpadded height is a multiple of 17 (SHA-256) or 21 (SHA-512), and thus not a power of 2.
Sha2RoundCols and Sha2DigestCols share the same first 3 fields:
- flags
- work_vars/hash (same type, different name)
- schedule_helper
This design allows for:
- Common constraints to work on either struct type by accessing these shared fields
- Specific constraints to use the appropriate struct, with flags helping to do conditional constraints
Note that the Sha2WorkVarsCols field is used for different purposes in the two structs.
Fields
flags: Sha2FlagsCols<T, ROW_VAR_CNT>work_vars: Sha2WorkVarsCols<T, WORD_BITS, ROUNDS_PER_ROW, WORD_U16S>schedule_helper: Sha2MessageHelperCols<T, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE>message_schedule: Sha2MessageScheduleCols<T, WORD_BITS, ROUNDS_PER_ROW, WORD_U8S>Trait Implementations
Sourceimpl<T: Clone, const WORD_BITS: usize, const WORD_U8S: usize, const WORD_U16S: usize, const ROUNDS_PER_ROW: usize, const ROUNDS_PER_ROW_MINUS_ONE: usize, const ROW_VAR_CNT: usize> Clone for Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>
impl<T: Clone, const WORD_BITS: usize, const WORD_U8S: usize, const WORD_U16S: usize, const ROUNDS_PER_ROW: usize, const ROUNDS_PER_ROW_MINUS_ONE: usize, const ROW_VAR_CNT: usize> Clone for Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>
Sourcefn clone(
&self,
) -> Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>
fn clone( &self, ) -> Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug, const WORD_BITS: usize, const WORD_U8S: usize, const WORD_U16S: usize, const ROUNDS_PER_ROW: usize, const ROUNDS_PER_ROW_MINUS_ONE: usize, const ROW_VAR_CNT: usize> Debug for Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>
impl<T: Debug, const WORD_BITS: usize, const WORD_U8S: usize, const WORD_U16S: usize, const ROUNDS_PER_ROW: usize, const ROUNDS_PER_ROW_MINUS_ONE: usize, const ROW_VAR_CNT: usize> Debug for Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>
impl<T: Copy, const WORD_BITS: usize, const WORD_U8S: usize, const WORD_U16S: usize, const ROUNDS_PER_ROW: usize, const ROUNDS_PER_ROW_MINUS_ONE: usize, const ROW_VAR_CNT: usize> Copy for Sha2RoundCols<T, WORD_BITS, WORD_U8S, WORD_U16S, ROUNDS_PER_ROW, ROUNDS_PER_ROW_MINUS_ONE, ROW_VAR_CNT>