pub struct SubAirBuilder<'a, AB: AirBuilder, SubAir: BaseAir<T>, T> { /* private fields */ }Expand description
A builder used to eval a sub-air. This will handle enforcing constraints for a subset of a trace matrix. E.g. if a particular air needs to be enforced for a subset of the columns of the trace, then the SubAirBuilder can be used.
Implementations
Sourceimpl<'a, AB: AirBuilder, SubAir: BaseAir<T>, T> SubAirBuilder<'a, AB, SubAir, T>
impl<'a, AB: AirBuilder, SubAir: BaseAir<T>, T> SubAirBuilder<'a, AB, SubAir, T>
pub fn new(inner: &'a mut AB, column_range: Range<usize>) -> Self