pub fn standard_fri_params_with_100_bits_security(
log_blowup: usize,
) -> FriParametersExpand description
Pre-defined FRI parameters with 100 bits of provable security, meaning we do not rely on any conjectures about Reed–Solomon codes (e.g., about proximity gaps) or the ethSTARK Toy Problem Conjecture.
Bits of provable security refers to Fiat-Shamir security, which is obtained from round-by-round soundness analysis.
The value num_queries is chosen so that the verifier accepts a δ-far
codeword for δ = (1 - 2**(-log_blowup)) with probability at most 2^{-80}.
I.e., we target the unique-decoding radius. We require 20 PoW bits
just before the query phase begins to boost the soundness to 100 bits.
Assumes that:
- the challenge field has size at least 2^123
- for
log_blowup = 1, the number of trace polynomials batched in any level of multi-FRI is at most 80000. A trace polynomial over the base field opened at 2 points gets a contribution of 2. A trace polynomial over the extension field opened at 2 points gets a contribution of 8. - for
log_blowup > 1, the number of trace polynomials batched in any level of multi-FRI is at most 4000. - the maximum trace height is 2^27
- for DEEP-ALI, the maximum number of constraints is 15000.