Struct FriParameters

pub struct FriParameters {
    pub log_blowup: usize,
    pub log_final_poly_len: usize,
    pub num_queries: usize,
    pub query_proof_of_work_bits: usize,
    pub commit_proof_of_work_bits: usize,
}

Fields

log_blowup: usizelog_final_poly_len: usizenum_queries: usizequery_proof_of_work_bits: usizecommit_proof_of_work_bits: usize

Implementations

Source

impl FriParameters

pub fn get_conjectured_security_bits( &self, challenge_field_bits: usize, ) -> usize

Conjectured bits of security. See ethSTARK paper (https://eprint.iacr.org/2021/582.pdf) section 5.10.1 equation (19)

challenge_field_bits is the number of bits in the challenge field (extension field) of the STARK config.

pub fn standard_fast() -> Self

pub fn standard_with_100_bits_conjectured_security(log_blowup: usize) -> Self

👎Deprecated: use standard_with_100_bits_security instead
pub fn standard_with_100_bits_security(log_blowup: usize) -> Self

pub fn max_constraint_degree(&self) -> usize

pub fn new_for_testing(log_blowup: usize) -> Self

New FRI parameters for testing usage with the specific log_blowup. If the environment variable OPENVM_FAST_TEST is set to “1”, then the parameters are not secure and meant for fast testing only.

In production, use Self::standard_with_100_bits_security instead.

pub fn security_bits_fri( &self, challenge_field_bits: f64, num_batch_columns: usize, max_log_domain_size: usize, ) -> f64

We (via Plonky3) use multi-FRI, whose security in the unique decoding regime can be bounded above by the security of batch FRI by considering all polynomials in the largest domain.

Following https://eprint.iacr.org/2023/1071.pdf, https://eprint.iacr.org/2025/1993.pdf, we use round-by-round soundness since we use FRI as a non-interactive protocol via Fiat-Shamir.

We use multi-FRI with <=2 opening points (the second point for rotation openings). The num_batch_columns is the maximum number of columns to be batched for any fixed domain size. A trace polynomial over the base field opened at 2 points gets a contribution of 2. A trace polynomial over the extension field opened at 2 points gets a contribution of 8.

pub fn security_bits_fri_commit_phase( &self, challenge_field_bits: f64, num_batch_columns: usize, max_log_domain_size: usize, ) -> f64

Batch FRI error according to https://eprint.iacr.org/2022/1216.pdf in the unique decoding regime. The batch FRI bound is an overestimate because in multi-FRI the error contribution for batching over smaller domain sizes is smaller.

We assume arity-2 folding.

pub fn security_bits_fri_query_phase(&self) -> f64

pub fn security_bits_deep_ali( &self, params: &DeepAliParameters, challenge_field_bits: f64, max_log_domain_size: usize, max_constraint_degree: usize, max_num_constraints: usize, ) -> f64

The bits of security from DEEP-ALI. Note that unlike in Theorem 8 of https://eprint.iacr.org/2022/1216.pdf, we do not include the rotation in the denominator of the quotient polynomial. Instead the quotient polynomial denominator consists only of Z_H(X) = X^{trace_height} - 1. The rotation opening point is handled as part of FRI PCS opening as an additional opening point. This means that for us k^+ = k + 1. We also include degree of selectors within the max_constraint_degree parameter.