pub struct BabyBearChip {
pub range: Arc<RangeChip<Fr>>,
/* private fields */
}Fields
range: Arc<RangeChip<Fr>>Implementations
Sourceimpl BabyBearChip
impl BabyBearChip
pub fn new(range_chip: Arc<RangeChip<Fr>>) -> Self
pub fn gate(&self) -> &GateChip<Fr>
pub fn range(&self) -> &RangeChip<Fr>
Sourcepub fn load_witness(
&self,
ctx: &mut Context<Fr>,
value: BabyBear,
) -> BabyBearWire
pub fn load_witness( &self, ctx: &mut Context<Fr>, value: BabyBear, ) -> BabyBearWire
Loads a BabyBear witness and constrains only that the assigned advice cell fits in 31 bits.
The Rust input is canonicalized for the honest witness assignment, but the
circuit does not prove the advice cell is < p. Use load_reduced_witness
for values that will be absorbed into transcripts or hashes.
Sourcepub fn load_reduced_witness(
&self,
ctx: &mut Context<Fr>,
value: BabyBear,
) -> ReducedBabyBearWire
pub fn load_reduced_witness( &self, ctx: &mut Context<Fr>, value: BabyBear, ) -> ReducedBabyBearWire
Loads a witness and constrains it to the canonical BabyBear range [0, p).
pub fn load_constant( &self, ctx: &mut Context<Fr>, value: BabyBear, ) -> BabyBearWire
Sourcepub fn load_reduced_constant(
&self,
ctx: &mut Context<Fr>,
value: BabyBear,
) -> ReducedBabyBearWire
pub fn load_reduced_constant( &self, ctx: &mut Context<Fr>, value: BabyBear, ) -> ReducedBabyBearWire
Loads a canonical BabyBear constant and returns it with reduced type evidence.
pub fn reduce(&self, ctx: &mut Context<Fr>, a: BabyBearWire) -> BabyBearWire
Sourcepub fn reduce_max_bits(
&self,
ctx: &mut Context<Fr>,
a: BabyBearWire,
) -> BabyBearWire
pub fn reduce_max_bits( &self, ctx: &mut Context<Fr>, a: BabyBearWire, ) -> BabyBearWire
Reduce max_bits if possible. This function doesn’t guarantee that the actual value is within BabyBear.
pub fn add( &self, ctx: &mut Context<Fr>, a: BabyBearWire, b: BabyBearWire, ) -> BabyBearWire
pub fn neg(&self, ctx: &mut Context<Fr>, a: BabyBearWire) -> BabyBearWire
pub fn sub( &self, ctx: &mut Context<Fr>, a: BabyBearWire, b: BabyBearWire, ) -> BabyBearWire
pub fn mul( &self, ctx: &mut Context<Fr>, a: BabyBearWire, b: BabyBearWire, ) -> BabyBearWire
pub fn mul_add( &self, ctx: &mut Context<Fr>, a: BabyBearWire, b: BabyBearWire, c: BabyBearWire, ) -> BabyBearWire
pub fn div( &self, ctx: &mut Context<Fr>, a: BabyBearWire, b: BabyBearWire, ) -> BabyBearWire
pub fn select( &self, ctx: &mut Context<Fr>, cond: SafeBool<Fr>, a: BabyBearWire, b: BabyBearWire, ) -> BabyBearWire
pub fn assert_zero(&self, ctx: &mut Context<Fr>, a: BabyBearWire)
pub fn assert_equal( &self, ctx: &mut Context<Fr>, a: BabyBearWire, b: BabyBearWire, )
pub fn zero(&self, ctx: &mut Context<Fr>) -> BabyBearWire
pub fn one(&self, ctx: &mut Context<Fr>) -> BabyBearWire
pub fn mul_const( &self, ctx: &mut Context<Fr>, a: BabyBearWire, c: BabyBear, ) -> BabyBearWire
pub fn square(&self, ctx: &mut Context<Fr>, a: BabyBearWire) -> BabyBearWire
pub fn pow_power_of_two( &self, ctx: &mut Context<Fr>, a: BabyBearWire, n: usize, ) -> BabyBearWire