Fr

Struct Fr 

pub struct Fr(/* private fields */);
This represents an element of $\mathbb{F}_r$ where

r = 0x30644e72e131a029b85045b68181585d2833e84879b9709143e1f593f0000001

is the scalar field of the BN254 curve.

Implementations



impl Fr

pub const fn zero() -> Fr

Returns zero, the additive identity.

pub const fn one() -> Fr

Returns one, the multiplicative identity.

pub fn invert(&self) -> CtOption<Fr>

Returns the multiplicative inverse of the element. If it is zero, the method fails.

pub fn jacobi(&self) -> i64

pub const fn from_raw(val: [u64; 4]) -> Fr

Converts from an integer represented in little endian into its (congruent) $field representation.

pub fn from_bytes(bytes: &[u8; 32]) -> CtOption<Fr>

Attempts to convert a little-endian byte representation of a scalar into a Fr, failing if the input is not canonical.

pub fn to_bytes(&self) -> [u8; 32]

Converts an element of Fr into a byte representation in little-endian byte order.



impl Fr

pub const fn add(&self, rhs: &Fr) -> Fr

Adds rhs to self, returning the result.



impl Fr

pub const fn double(&self) -> Fr

Doubles this field element.

pub const fn square(&self) -> Fr

Squares this element.

pub const fn mul(&self, rhs: &Fr) -> Fr

Multiplies rhs by self, returning the result.

pub const fn sub(&self, rhs: &Fr) -> Fr

Subtracts rhs from self, returning the result.

pub const fn neg(&self) -> Fr

Negates self.



impl Fr

pub const fn size() -> usize