VerificationBaseline

Struct VerificationBaseline 

pub struct VerificationBaseline {
    pub app_exe_commit: Digest,
    pub memory_dimensions: MemoryDimensions,
    pub num_user_pvs: usize,
    pub app_vk_commit: VkCommit<F>,
    pub leaf_vk_commit: VkCommit<F>,
    pub internal_for_leaf_vk_commit: VkCommit<F>,
    pub internal_recursive_vk_commit: VkCommit<F>,
    pub expected_def_hook_commit: Option<Digest>,
}
Baseline artifacts for a specific VM and fixed executable that are used to verify a final (i.e. internal-recursive) VM STARK proof

Fields

app_exe_commit: Digest

Commit to the app exe (i.e. hash of the program commit, initial memory merkle root, and initial program counter)

memory_dimensions: MemoryDimensions

VM memory metadata used to verify the user public values merkle proof

num_user_pvs: usize

Number of raw user public values

app_vk_commit: VkCommit<F>

Commit to the app_vk’s DAG and its pre-hash, first exposed by the leaf verifier.

leaf_vk_commit: VkCommit<F>

Commit to the leaf_vk’s DAG and its pre-hash, first exposed by the internal-for-leaf verifier.

internal_for_leaf_vk_commit: VkCommit<F>

Commit to the internal_for_leaf_vk’s DAG and its pre-hash, first exposed by the first (i.e. index 0) internal-recursive layer verifier.

internal_recursive_vk_commit: VkCommit<F>

Commit to the internal_recursive_vk’s DAG and its pre-hash, exposed by subsequent (i.e. index > 0) internal-recursive layer verifiers.

expected_def_hook_commit: Option<Digest>

Expected deferral VK commit (hash of the deferral aggregation prover’s vk commits). When Some, the proof must have deferral_flag == 0 || deferral_flag == 2 and valid deferral Merkle proofs. If deferral_flag == 2, def_hook_commit must match this value. If deferral_flag == 0, the deferral public values must be unset and the Merkle proofs must show that the deferral address space is unchanged. When None, there must be no deferral public values.