pub fn add2<AB: AirBuilder>(
builder: &mut AB,
a: &[AB::Var; 2],
b: &[AB::Var; 2],
c: &[AB::Expr; 2],
)Expand description
Verify that a = b + c mod 2^32
We assume that a, b, c are all given as 2, 16 bit limbs (e.g. a = a[0] + 2^16 a[1]) and
each 16 bit limb has been range checked to ensure it contains a value in [0, 2^16).
This function assumes we are working over a field with characteristic P > 2^17.
Panics
The function will panic if the characteristic of the field is less than or equal to 2^16.