pub struct TwoAdicFriFolding<InputProof, InputError>(pub PhantomData<(InputProof, InputError)>);Tuple Fields
0: PhantomData<(InputProof, InputError)>Trait Implementations
Sourceimpl<F: TwoAdicField, InputProof, InputError: Debug, EF: ExtensionField<F>> FriFoldingStrategy<F, EF> for TwoAdicFriFolding<InputProof, InputError>
impl<F: TwoAdicField, InputProof, InputError: Debug, EF: ExtensionField<F>> FriFoldingStrategy<F, EF> for TwoAdicFriFolding<InputProof, InputError>
type InputProof = InputProof
type InputError = InputError
Sourcefn extra_query_index_bits(&self) -> usize
fn extra_query_index_bits(&self) -> usize
We can ask FRI to sample extra query bits (LSB) for our own purposes.
They will be passed to our callbacks, but ignored (shifted off) by FRI.
Sourcefn fold_row(
&self,
index: usize,
log_height: usize,
beta: EF,
evals: impl Iterator<Item = EF>,
) -> EF
fn fold_row( &self, index: usize, log_height: usize, beta: EF, evals: impl Iterator<Item = EF>, ) -> EF
Fold a row, returning a single column.
Right now the input row will always be 2 columns wide,
but we may support higher folding arity in the future.
Sourcefn fold_matrix<M: Matrix<EF>>(&self, beta: EF, m: M) -> Vec<EF>
fn fold_matrix<M: Matrix<EF>>(&self, beta: EF, m: M) -> Vec<EF>
Same as applying fold_row to every row, possibly faster.