Type Alias ProverDataWithOpeningPoints

pub type ProverDataWithOpeningPoints<'a, EF, ProverData> = (&'a ProverData, Vec<Vec<EF>>);
The Prover Data associated to a commitment to a collection of matrices and a list of points to open each matrix at.