pub struct Goldilocks { /* private fields */ }Expand description
The prime field known as Goldilocks, defined as F_p where p = 2^64 - 2^32 + 1.
Note that the safety of deriving Serialize and Deserialize relies on the fact that the internal value can be any u64.
Implementations
Sourceimpl Goldilocks
impl Goldilocks
Sourcepub const TWO_ADIC_GENERATORS: [Self; 33]
pub const TWO_ADIC_GENERATORS: [Self; 33]
A list of generators for the two-adic subgroups of the goldilocks field.
These satisfy the properties that TWO_ADIC_GENERATORS[0] = 1 and TWO_ADIC_GENERATORS[i+1]^2 = TWO_ADIC_GENERATORS[i].