#[non_exhaustive]pub struct ListBucketAnalyticsConfigurationsOutputBuilder { /* private fields */ }Expand description
A builder for ListBucketAnalyticsConfigurationsOutput.
Implementations
Sourceimpl ListBucketAnalyticsConfigurationsOutputBuilder
impl ListBucketAnalyticsConfigurationsOutputBuilder
Sourcepub fn is_truncated(self, input: bool) -> Self
pub fn is_truncated(self, input: bool) -> Self
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn set_is_truncated(self, input: Option<bool>) -> Self
pub fn set_is_truncated(self, input: Option<bool>) -> Self
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn get_is_truncated(&self) -> &Option<bool>
pub fn get_is_truncated(&self) -> &Option<bool>
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
Sourcepub fn continuation_token(self, input: impl Into<String>) -> Self
pub fn continuation_token(self, input: impl Into<String>) -> Self
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
Sourcepub fn set_continuation_token(self, input: Option<String>) -> Self
pub fn set_continuation_token(self, input: Option<String>) -> Self
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
Sourcepub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
Sourcepub fn next_continuation_token(self, input: impl Into<String>) -> Self
pub fn next_continuation_token(self, input: impl Into<String>) -> Self
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
Sourcepub fn set_next_continuation_token(self, input: Option<String>) -> Self
pub fn set_next_continuation_token(self, input: Option<String>) -> Self
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
Sourcepub fn get_next_continuation_token(&self) -> &Option<String>
pub fn get_next_continuation_token(&self) -> &Option<String>
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
Sourcepub fn analytics_configuration_list(self, input: AnalyticsConfiguration) -> Self
pub fn analytics_configuration_list(self, input: AnalyticsConfiguration) -> Self
Appends an item to analytics_configuration_list.
To override the contents of this collection use set_analytics_configuration_list.
The list of analytics configurations for a bucket.
Sourcepub fn set_analytics_configuration_list(
self,
input: Option<Vec<AnalyticsConfiguration>>,
) -> Self
pub fn set_analytics_configuration_list( self, input: Option<Vec<AnalyticsConfiguration>>, ) -> Self
The list of analytics configurations for a bucket.
Sourcepub fn get_analytics_configuration_list(
&self,
) -> &Option<Vec<AnalyticsConfiguration>>
pub fn get_analytics_configuration_list( &self, ) -> &Option<Vec<AnalyticsConfiguration>>
The list of analytics configurations for a bucket.
Sourcepub fn build(self) -> ListBucketAnalyticsConfigurationsOutput
pub fn build(self) -> ListBucketAnalyticsConfigurationsOutput
Consumes the builder and constructs a ListBucketAnalyticsConfigurationsOutput.