#[non_exhaustive]pub struct PutBucketLifecycleConfigurationInputBuilder { /* private fields */ }Expand description
A builder for PutBucketLifecycleConfigurationInput.
Implementations
Sourceimpl PutBucketLifecycleConfigurationInputBuilder
impl PutBucketLifecycleConfigurationInputBuilder
Sourcepub fn bucket(self, input: impl Into<String>) -> Self
pub fn bucket(self, input: impl Into<String>) -> Self
The name of the bucket for which to set the configuration.
This field is required.Sourcepub fn set_bucket(self, input: Option<String>) -> Self
pub fn set_bucket(self, input: Option<String>) -> Self
The name of the bucket for which to set the configuration.
Sourcepub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
The name of the bucket for which to set the configuration.
Sourcepub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
pub fn checksum_algorithm(self, input: ChecksumAlgorithm) -> Self
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Sourcepub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
pub fn set_checksum_algorithm(self, input: Option<ChecksumAlgorithm>) -> Self
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Sourcepub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
Sourcepub fn lifecycle_configuration(
self,
input: BucketLifecycleConfiguration,
) -> Self
pub fn lifecycle_configuration( self, input: BucketLifecycleConfiguration, ) -> Self
Container for lifecycle rules. You can add as many as 1,000 rules.
Sourcepub fn set_lifecycle_configuration(
self,
input: Option<BucketLifecycleConfiguration>,
) -> Self
pub fn set_lifecycle_configuration( self, input: Option<BucketLifecycleConfiguration>, ) -> Self
Container for lifecycle rules. You can add as many as 1,000 rules.
Sourcepub fn get_lifecycle_configuration(
&self,
) -> &Option<BucketLifecycleConfiguration>
pub fn get_lifecycle_configuration( &self, ) -> &Option<BucketLifecycleConfiguration>
Container for lifecycle rules. You can add as many as 1,000 rules.
Sourcepub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
pub fn expected_bucket_owner(self, input: impl Into<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
pub fn set_expected_bucket_owner(self, input: Option<String>) -> Self
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Sourcepub fn transition_default_minimum_object_size(
self,
input: TransitionDefaultMinimumObjectSize,
) -> Self
pub fn transition_default_minimum_object_size( self, input: TransitionDefaultMinimumObjectSize, ) -> Self
Indicates which default minimum object size behavior is applied to the lifecycle configuration.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
-
all_storage_classes_128K- Objects smaller than 128 KB will not transition to any storage class by default. -
varies_by_storage_class- Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
Sourcepub fn set_transition_default_minimum_object_size(
self,
input: Option<TransitionDefaultMinimumObjectSize>,
) -> Self
pub fn set_transition_default_minimum_object_size( self, input: Option<TransitionDefaultMinimumObjectSize>, ) -> Self
Indicates which default minimum object size behavior is applied to the lifecycle configuration.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
-
all_storage_classes_128K- Objects smaller than 128 KB will not transition to any storage class by default. -
varies_by_storage_class- Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
Sourcepub fn get_transition_default_minimum_object_size(
&self,
) -> &Option<TransitionDefaultMinimumObjectSize>
pub fn get_transition_default_minimum_object_size( &self, ) -> &Option<TransitionDefaultMinimumObjectSize>
Indicates which default minimum object size behavior is applied to the lifecycle configuration.
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
-
all_storage_classes_128K- Objects smaller than 128 KB will not transition to any storage class by default. -
varies_by_storage_class- Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
Sourcepub fn build(self) -> Result<PutBucketLifecycleConfigurationInput, BuildError>
pub fn build(self) -> Result<PutBucketLifecycleConfigurationInput, BuildError>
Consumes the builder and constructs a PutBucketLifecycleConfigurationInput.
Sourceimpl PutBucketLifecycleConfigurationInputBuilder
impl PutBucketLifecycleConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<PutBucketLifecycleConfigurationOutput, SdkError<PutBucketLifecycleConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<PutBucketLifecycleConfigurationOutput, SdkError<PutBucketLifecycleConfigurationError, HttpResponse>>
Sends a request with this input using the given client.