#[non_exhaustive]pub struct PresignedRequest { /* private fields */ }Expand description
Represents a presigned request. This only includes the HTTP request method, URI, and headers.
This struct has conversion convenience functions:
Implementations
Sourceimpl PresignedRequest
impl PresignedRequest
Sourcepub fn headers(&self) -> impl Iterator<Item = (&str, &str)>
pub fn headers(&self) -> impl Iterator<Item = (&str, &str)>
Returns any HTTP headers that need to go along with the request, except for Host,
which should be sent based on the endpoint in the URI by the HTTP client rather than
added directly.
Sourcepub fn make_http_02x_request<B>(&self, body: B) -> Request<B>
👎Deprecated: Prefer the make_http_1x_request() instead by enabling the http-1x feature.
pub fn make_http_02x_request<B>(&self, body: B) -> Request<B>
make_http_1x_request() instead by enabling the http-1x feature.Given a body, produce an http::Request from this PresignedRequest
Sourcepub fn into_http_02x_request<B>(self, body: B) -> Request<B>
👎Deprecated: Prefer the into_http_1x_request instead by enabling the http-1x feature.
pub fn into_http_02x_request<B>(self, body: B) -> Request<B>
into_http_1x_request instead by enabling the http-1x feature.Converts this PresignedRequest directly into an http request.