#[non_exhaustive]pub struct InventoryTableConfigurationResult {
pub configuration_state: InventoryConfigurationState,
pub table_status: Option<String>,
pub error: Option<ErrorDetails>,
pub table_name: Option<String>,
pub table_arn: Option<String>,
}Expand description
The inventory table configuration for an S3 Metadata configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.configuration_state: InventoryConfigurationStateThe configuration state of the inventory table, indicating whether the inventory table is enabled or disabled.
table_status: Option<String>The status of the inventory table. The status values are:
-
CREATING- The inventory table is in the process of being created in the specified Amazon Web Services managed table bucket. -
BACKFILLING- The inventory table is in the process of being backfilled. When you enable the inventory table for your metadata configuration, the table goes through a process known as backfilling, during which Amazon S3 scans your general purpose bucket to retrieve the initial metadata for all objects in the bucket. Depending on the number of objects in your bucket, this process can take several hours. When the backfilling process is finished, the status of your inventory table changes fromBACKFILLINGtoACTIVE. After backfilling is completed, updates to your objects are reflected in the inventory table within one hour. -
ACTIVE- The inventory table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the inventory table, or Amazon S3 is unable to deliver records.
error: Option<ErrorDetails>If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
table_name: Option<String>The name of the inventory table.
table_arn: Option<String>The Amazon Resource Name (ARN) for the inventory table.
Implementations
Sourceimpl InventoryTableConfigurationResult
impl InventoryTableConfigurationResult
Sourcepub fn configuration_state(&self) -> &InventoryConfigurationState
pub fn configuration_state(&self) -> &InventoryConfigurationState
The configuration state of the inventory table, indicating whether the inventory table is enabled or disabled.
Sourcepub fn table_status(&self) -> Option<&str>
pub fn table_status(&self) -> Option<&str>
The status of the inventory table. The status values are:
-
CREATING- The inventory table is in the process of being created in the specified Amazon Web Services managed table bucket. -
BACKFILLING- The inventory table is in the process of being backfilled. When you enable the inventory table for your metadata configuration, the table goes through a process known as backfilling, during which Amazon S3 scans your general purpose bucket to retrieve the initial metadata for all objects in the bucket. Depending on the number of objects in your bucket, this process can take several hours. When the backfilling process is finished, the status of your inventory table changes fromBACKFILLINGtoACTIVE. After backfilling is completed, updates to your objects are reflected in the inventory table within one hour. -
ACTIVE- The inventory table has been created successfully, and records are being delivered to the table. -
FAILED- Amazon S3 is unable to create the inventory table, or Amazon S3 is unable to deliver records.
Sourcepub fn error(&self) -> Option<&ErrorDetails>
pub fn error(&self) -> Option<&ErrorDetails>
If an S3 Metadata V1 CreateBucketMetadataTableConfiguration or V2 CreateBucketMetadataConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the inventory table.
Sourceimpl InventoryTableConfigurationResult
impl InventoryTableConfigurationResult
Sourcepub fn builder() -> InventoryTableConfigurationResultBuilder
pub fn builder() -> InventoryTableConfigurationResultBuilder
Creates a new builder-style object to manufacture InventoryTableConfigurationResult.