pub struct SystemConfig {
pub max_constraint_degree: usize,
pub memory_config: MemoryConfig,
pub num_public_values: usize,
pub segmentation_max_memory: usize,
}Expand description
System-level configuration for the virtual machine. Contains all configuration parameters that are managed by the architecture.
Fields
max_constraint_degree: usizeThe maximum constraint degree any chip is allowed to use.
memory_config: MemoryConfigMemory configuration
num_public_values: usizePublic values are stored in a special address space.
num_public_values indicates the number of allowed addresses in that address space.
segmentation_max_memory: usizeMax memory in bytes used across all chips for triggering segmentation. This field is skipped in serde as it’s only used in execution and not needed after any serialize/deserialize.
Implementations
Sourceimpl SystemConfig
impl SystemConfig
Sourcepub fn set_segmentation_max_memory(&mut self, val: usize) -> &mut Self
pub fn set_segmentation_max_memory(&mut self, val: usize) -> &mut Self
Max memory in bytes used across all chips for triggering segmentation. This field is skipped in serde as it’s only used in execution and not needed after any serialize/deserialize.
Sourceimpl SystemConfig
impl SystemConfig
Sourcepub fn with_max_constraint_degree(self, val: usize) -> Self
pub fn with_max_constraint_degree(self, val: usize) -> Self
The maximum constraint degree any chip is allowed to use.
Sourceimpl SystemConfig
impl SystemConfig
pub fn new( max_constraint_degree: usize, memory_config: MemoryConfig, num_public_values: usize, ) -> Self
pub fn default_from_memory(memory_config: MemoryConfig) -> Self
pub fn with_public_values(self, num_public_values: usize) -> Self
Sourcepub fn memory_boundary_air_id(&self) -> usize
pub fn memory_boundary_air_id(&self) -> usize
Returns the AIR ID of the memory boundary AIR. Panic if the boundary AIR is not enabled.
Sourcepub fn memory_merkle_air_id(&self) -> usize
pub fn memory_merkle_air_id(&self) -> usize
Returns the AIR ID of the memory merkle AIR.
Sourcepub fn is_required_air_id(&self, air_id: usize) -> bool
pub fn is_required_air_id(&self, air_id: usize) -> bool
Whether the AIR ID must be present in a valid v2 proof.
Sourcepub fn num_airs(&self) -> usize
pub fn num_airs(&self) -> usize
This is O(1) and returns the length of
SystemAirInventory::into_airs.