pub trait Chip<R, PB: ProverBackend> {
// Required method
fn generate_proving_ctx(&self, records: R) -> AirProvingContext<PB>;
// Provided method
fn constant_trace_height(&self) -> Option<usize> { ... }
}Expand description
A chip is a [ProverBackend]-specific object that converts execution logs (also referred to as records) into a trace matrix.
A chip may be stateful and store state on either host or device, although it is preferred that all state is received through records.
Required Methods
Sourcefn generate_proving_ctx(&self, records: R) -> AirProvingContext<PB>
fn generate_proving_ctx(&self, records: R) -> AirProvingContext<PB>
Generate all necessary context for proving a single AIR.
Provided Methods
Sourcefn constant_trace_height(&self) -> Option<usize>
fn constant_trace_height(&self) -> Option<usize>
If this chip always produces a trace with a fixed number of rows (independent of execution), return that height. Used by metered execution to avoid resetting constant-height chips on segment boundaries.