pub trait ColumnsAir {
// Provided method
fn columns(&self) -> Option<Vec<String>> { ... }
}Expand description
Allows AIRs to indicate the names of their columns, for debugging purposes.
A default implementation is provided that returns None, indicating that
column names are not available.