pub fn collapse_flags<F: PrimeCharacteristicRing>(
flags: [F; 4],
is_constraint: F,
) -> FExpand description
Collapse flags and is_constraint into a single field element, which should be the first element of a row’s input digest.
WARNING: To use this in an AIR you MUST constrain that is_constraint is boolean and that each flag is in [0, FLAG_MODULUS). This ensures that the element doesn’t overflow for any 13-bit field or higher.