pub struct SdkVmConfig {
pub system: SdkSystemConfig,
pub rv32i: Option<UnitStruct>,
pub io: Option<UnitStruct>,
pub keccak: Option<UnitStruct>,
pub sha2: Option<UnitStruct>,
pub rv32m: Option<Rv32M>,
pub bigint: Option<Int256>,
pub modular: Option<ModularExtension>,
pub fp2: Option<Fp2Extension>,
pub pairing: Option<PairingExtension>,
pub ecc: Option<WeierstrassExtension>,
pub deferral: Option<DeferralConfig>,
}Expand description
The recommended way to construct SdkVmConfig is using SdkVmConfig::from_toml.
For construction without reliance on deserialization, you can use SdkVmConfigBuilder, which follows a builder pattern. After calling SdkVmConfigBuilder::build, call SdkVmConfig::optimize to apply some default optimizations to built configuration for best performance.
Fields
system: SdkSystemConfigrv32i: Option<UnitStruct>io: Option<UnitStruct>keccak: Option<UnitStruct>sha2: Option<UnitStruct>rv32m: Option<Rv32M>NOTE: if enabling this together with the Int256 extension, you should set the rv32m
field to have the same range_tuple_checker_sizes as the bigint field for best
performance.
bigint: Option<Int256>NOTE: if enabling this together with the Rv32M extension, you should set the rv32m
field to have the same range_tuple_checker_sizes as the bigint field for best
performance.
modular: Option<ModularExtension>fp2: Option<Fp2Extension>pairing: Option<PairingExtension>ecc: Option<WeierstrassExtension>deferral: Option<DeferralConfig>NOTE: Only deferral configurations enumerated by SupportedDeferral are fully serializable and deserializable. For custom deferral circuits stored as SupportedDeferral::Other, the circuit’s DeferralFn must be manually replaced in the extension after deserialization.
Implementations
Sourceimpl SdkVmConfig
impl SdkVmConfig
Sourcepub fn builder() -> SdkVmConfigBuilder
pub fn builder() -> SdkVmConfigBuilder
Create an instance of SdkVmConfig using the builder syntax
Sourceimpl SdkVmConfig
impl SdkVmConfig
Sourcepub fn standard() -> SdkVmConfig
pub fn standard() -> SdkVmConfig
Standard configuration with a set of default VM extensions loaded.
Note: To use this configuration, your openvm.toml must match, including the order of
the moduli and elliptic curve parameters of the respective extensions:
The app_vm_config field of your openvm.toml must exactly match the following:
[app_vm_config.rv32i]
[app_vm_config.rv32m]
[app_vm_config.io]
[app_vm_config.keccak]
[app_vm_config.sha2]
[app_vm_config.bigint]
[app_vm_config.modular]
supported_moduli = [
# bn254 (alt bn128)
"21888242871839275222246405745257275088696311157297823662689037894645226208583", # coordinate field
"21888242871839275222246405745257275088548364400416034343698204186575808495617", # scalar field
# secp256k1 (k256)
"115792089237316195423570985008687907853269984665640564039457584007908834671663", # coordinate field
"115792089237316195423570985008687907852837564279074904382605163141518161494337", # scalar field
# secp256r1 (p256)
"115792089210356248762697446949407573530086143415290314195533631308867097853951", # coordinate
"115792089210356248762697446949407573529996955224135760342422259061068512044369", # scalar
# bls12_381
"4002409555221667393417789825735904156556882819939007885332058136124031650490837864442687629129015664037894272559787", # coordinate field
"52435875175126190479447740508185965837690552500527637822603658699938581184513", # scalar field
]
[app_vm_config.fp2]
supported_moduli = [
[
"Bn254Fp2",
# bn254 (alt bn128)
"21888242871839275222246405745257275088696311157297823662689037894645226208583",
],
# Bls12_381
[
"Bls12_381Fp2",
"4002409555221667393417789825735904156556882819939007885332058136124031650490837864442687629129015664037894272559787",
],
]
# bn254 (alt bn128)
[[app_vm_config.ecc.supported_curves]]
struct_name = "Bn254G1Affine"
modulus = "21888242871839275222246405745257275088696311157297823662689037894645226208583"
scalar = "21888242871839275222246405745257275088548364400416034343698204186575808495617"
a = "0"
b = "3"
# secp256k1 (k256)
[[app_vm_config.ecc.supported_curves]]
struct_name = "Secp256k1Point"
modulus = "115792089237316195423570985008687907853269984665640564039457584007908834671663"
scalar = "115792089237316195423570985008687907852837564279074904382605163141518161494337"
a = "0"
b = "7"
# secp256r1 (p256)
[[app_vm_config.ecc.supported_curves]]
struct_name = "P256Point"
modulus = "115792089210356248762697446949407573530086143415290314195533631308867097853951"
scalar = "115792089210356248762697446949407573529996955224135760342422259061068512044369"
a = "115792089210356248762697446949407573530086143415290314195533631308867097853948"
b = "41058363725152142129326129780047268409114441015993725554835256314039467401291"
# bls12_381
[[app_vm_config.ecc.supported_curves]]
struct_name = "Bls12_381G1Affine"
modulus = "4002409555221667393417789825735904156556882819939007885332058136124031650490837864442687629129015664037894272559787"
scalar = "52435875175126190479447740508185965837690552500527637822603658699938581184513"
a = "0"
b = "4"
[app_vm_config.pairing]
supported_curves = ["Bn254", "Bls12_381"]Sourcepub fn riscv32() -> Self
pub fn riscv32() -> Self
Configuration with RISC-V RV32IM and IO VM extensions loaded.
Note: To use this configuration, your openvm.toml must exactly match the following:
[app_vm_config.rv32i]
[app_vm_config.rv32m]
[app_vm_config.io]Sourcepub fn from_toml(openvm_toml: &str) -> Result<Self, Error>
pub fn from_toml(openvm_toml: &str) -> Result<Self, Error>
openvm_toml should be the TOML string read from an openvm.toml file.
pub fn to_toml(&self) -> Result<String, Error>
Sourceimpl SdkVmConfig
impl SdkVmConfig
pub fn optimize(self) -> Self
Sourcepub fn apply_optimizations(&mut self)
pub fn apply_optimizations(&mut self)
Apply small optimizations to the configuration.
pub fn to_inner(&self) -> SdkVmConfigInner