pub struct Sha2BlockHasherFillerHelper<C: Sha2BlockHasherSubairConfig> {
pub row_idx_encoder: Encoder,
/* private fields */
}Expand description
A helper struct for the SHA-2 trace generation. Also, separates the inner AIR from the trace generation.
Fields
row_idx_encoder: EncoderImplementations
Sourceimpl<C: Sha2BlockHasherSubairConfig> Sha2BlockHasherFillerHelper<C>
The trace generation of SHA-2 should be done in two passes.
The first pass should do get_block_trace for every block and generate the invalid rows through
get_default_row The second pass should go through all the blocks and call
generate_missing_cells
impl<C: Sha2BlockHasherSubairConfig> Sha2BlockHasherFillerHelper<C>
The trace generation of SHA-2 should be done in two passes.
The first pass should do get_block_trace for every block and generate the invalid rows through
get_default_row The second pass should go through all the blocks and call
generate_missing_cells
pub fn new() -> Self
Sourcepub fn get_block_hash(prev_hash: &[C::Word], input: Vec<u8>) -> Vec<C::Word>
pub fn get_block_hash(prev_hash: &[C::Word], input: Vec<u8>) -> Vec<C::Word>
This function takes the input_message (padding not handled), the previous hash, and returns the new hash after processing the block input
Sourcepub fn generate_block_trace<F: PrimeField32>(
&self,
trace: &mut [F],
trace_width: usize,
trace_start_col: usize,
input: &[C::Word],
bitwise_lookup_chip: SharedBitwiseOperationLookupChip<8>,
prev_hash: &[C::Word],
next_block_prev_hash: &[C::Word],
global_block_idx: u32,
)
pub fn generate_block_trace<F: PrimeField32>( &self, trace: &mut [F], trace_width: usize, trace_start_col: usize, input: &[C::Word], bitwise_lookup_chip: SharedBitwiseOperationLookupChip<8>, prev_hash: &[C::Word], next_block_prev_hash: &[C::Word], global_block_idx: u32, )
This function takes a C::BLOCK_BITS-bit chunk of the input message (padding not handled),
the previous hash, a flag indicating if it’s the last block, the global block index, the
local block index, and the buffer values that will be put in rows 0..4.
Will populate the given trace with the trace of the block, where the width of the trace is
trace_width and the starting column for the Sha2Air is trace_start_col.
Note: this function only generates some of the required trace. Another pass is required,
refer to Self::generate_missing_cells for details.
Sourcepub fn generate_missing_cells<F: PrimeField32>(
&self,
trace: &mut [F],
trace_width: usize,
trace_start_col: usize,
)
pub fn generate_missing_cells<F: PrimeField32>( &self, trace: &mut [F], trace_width: usize, trace_start_col: usize, )
This function will fill in the cells that we couldn’t do during the first pass.
This function should be called only after generate_block_trace was called for all blocks
And Self::generate_default_row is called for all invalid rows
Will populate the missing values of trace, where the width of the trace is trace_width
Note: trace needs to be the rows 1..C::ROWS_PER_BLOCK of a block and the first row of the
next block
Sourcepub fn generate_default_row<F: PrimeField32>(
&self,
cols: &mut Sha2RoundColsRefMut<'_, F>,
first_block_prev_hash: &[C::Word],
carry_a: Option<&[F]>,
carry_e: Option<&[F]>,
global_block_idx: u32,
)
pub fn generate_default_row<F: PrimeField32>( &self, cols: &mut Sha2RoundColsRefMut<'_, F>, first_block_prev_hash: &[C::Word], carry_a: Option<&[F]>, carry_e: Option<&[F]>, global_block_idx: u32, )
Fills the cols as a padding row
Note: we still need to correctly fill in the hash values, carries and intermeds
Sourcepub fn generate_carry_ae<F: PrimeField32>(
local_cols: Sha2RoundColsRef<'_, F>,
next_cols: &mut Sha2RoundColsRefMut<'_, F>,
)
pub fn generate_carry_ae<F: PrimeField32>( local_cols: Sha2RoundColsRef<'_, F>, next_cols: &mut Sha2RoundColsRefMut<'_, F>, )
The following functions do the calculations in native field since they will be called on
padding rows which can overflow and we need to make sure it matches the AIR constraints
Puts the correct carries in the next_row, the resulting carries can be out of bounds.
Assumes next.w and next.k are zero, which is the case when constraint_word_addition is
constrained on digest rows or padding rows.
It only looks at local.a, next.a, local.e, next.e.
Sourcepub fn generate_intermed_4<F: PrimeField32>(
local_cols: Sha2RoundColsRef<'_, F>,
next_cols: &mut Sha2RoundColsRefMut<'_, F>,
)
pub fn generate_intermed_4<F: PrimeField32>( local_cols: Sha2RoundColsRef<'_, F>, next_cols: &mut Sha2RoundColsRefMut<'_, F>, )
Puts the correct intermed_4 in the next_row
Sourcepub fn generate_intermed_12<F: PrimeField32>(
local_cols: &mut Sha2RoundColsRefMut<'_, F>,
next_cols: Sha2RoundColsRef<'_, F>,
)
pub fn generate_intermed_12<F: PrimeField32>( local_cols: &mut Sha2RoundColsRefMut<'_, F>, next_cols: Sha2RoundColsRef<'_, F>, )
Puts the needed intermed_12 in the local_row