pub struct StaticVerifierProvingKey {
pub circuit: StaticVerifierCircuit,
pub pinning: Halo2ProvingPinning,
pub shape: StaticVerifierShape,
}Expand description
High-level proving key that owns a StaticVerifierCircuit, Halo2ProvingPinning, and
StaticVerifierShape.
Fields
circuit: StaticVerifierCircuitpinning: Halo2ProvingPinningshape: StaticVerifierShapeImplementations
Sourceimpl StaticVerifierProvingKey
impl StaticVerifierProvingKey
Sourcepub fn keygen(
params: &Halo2Params,
shape: StaticVerifierShape,
circuit: StaticVerifierCircuit,
representative_proof: &Proof<RootConfig>,
) -> Self
pub fn keygen( params: &Halo2Params, shape: StaticVerifierShape, circuit: StaticVerifierCircuit, representative_proof: &Proof<RootConfig>, ) -> Self
Run keygen and return a proving key that can be reused for multiple proofs.
Sourcepub fn prove(
&self,
params: &Halo2Params,
proof: &Proof<RootConfig>,
) -> StaticVerifierProof
pub fn prove( &self, params: &Halo2Params, proof: &Proof<RootConfig>, ) -> StaticVerifierProof
Generate a proof using the stored pinning and shape.
Sourcepub fn verify(&self, params: &Halo2Params, proof: &StaticVerifierProof) -> bool
pub fn verify(&self, params: &Halo2Params, proof: &StaticVerifierProof) -> bool
Verify a proof against this proving key’s verifying key.
Sourceimpl StaticVerifierProvingKey
impl StaticVerifierProvingKey
Sourcepub fn generate_fallback_evm_verifier(&self, params: &Halo2Params) -> String
pub fn generate_fallback_evm_verifier(&self, params: &Halo2Params) -> String
Generate a Solidity verifier contract for this circuit.
Sourcepub fn prove_wrapped(
&self,
params: &Halo2Params,
proof: &Proof<RootConfig>,
) -> Snark
pub fn prove_wrapped( &self, params: &Halo2Params, proof: &Proof<RootConfig>, ) -> Snark
Produce a Snark for consumption by the wrapper circuit.
Unlike prove_for_evm_unwrapped, this
returns a Snark (not a raw EVM proof), which should be fed into
Halo2WrapperProvingKey::prove_for_evm.
Sourcepub fn generate_dummy_snark(&self, reader: &impl Halo2ParamsReader) -> Snark
pub fn generate_dummy_snark(&self, reader: &impl Halo2ParamsReader) -> Snark
Generate a dummy snark for wrapper keygen.
Sourcepub fn prove_for_evm_unwrapped(
&self,
params: &Halo2Params,
proof: &Proof<RootConfig>,
) -> RawEvmProof
pub fn prove_for_evm_unwrapped( &self, params: &Halo2Params, proof: &Proof<RootConfig>, ) -> RawEvmProof
Generate an EVM-compatible proof directly (one-step, no wrapper circuit).