pub type ProverDataWithOpeningPoints<'a, EF, ProverData> = (&'a ProverData, Vec<Vec<EF>>);Expand description
The Prover Data associated to a commitment to a collection of matrices and a list of points to open each matrix at.
pub type ProverDataWithOpeningPoints<'a, EF, ProverData> = (&'a ProverData, Vec<Vec<EF>>);The Prover Data associated to a commitment to a collection of matrices and a list of points to open each matrix at.